@@ -489,7 +489,7 @@ resolve_relative_path(const char *s)
 	if (!s || !*s)
 		return (char *)NULL;
 
-	char *p = realpath(s, NULL);
+	char *p = xrealpath(s, NULL);
 	if (!p)
 		return (char *)NULL;
 
@@ -579,7 +579,7 @@ get_data_dir(void)
 		return;
 
 	err('w', PRINT_PROMPT, _("%s: No data directory found. Data files, "
-		"such as plugins and color schemes, might not be available.\n"),
+		"such as plugins and color schemes, may not be available.\n"),
 		PROGRAM_NAME);
 }
 
@@ -851,7 +851,7 @@ set_alt_config_dir(char *dir)
 		}
 	} else {
 		alt_config_dir = savestring(dir, strlen(dir));
-		err(ERR_NO_LOG, PRINT_PROMPT, _("%s: '%s': Using alternative "
+		err(ERR_NO_LOG, PRINT_PROMPT, _("%s: '%s': Using an alternative "
 			"configuration directory\n"), PROGRAM_NAME, alt_config_dir);
 	}
 
@@ -864,7 +864,8 @@ set_custom_selfile(char *file)
 	if (!file || !*file || *file == '-')
 		err_arg_required("--sel-file"); /* noreturn */
 
-	if ( (sel_file = normalize_path(file, strlen(file))) ) {
+	sel_file = normalize_path(file, strlen(file));
+	if (sel_file) {
 		xargs.sel_file = 1;
 		return;
 	}
@@ -1209,8 +1210,9 @@ set_no_suggestions(void)
 {
 #ifndef _NO_SUGGESTIONS
 	xargs.suggestions = conf.suggestions = 0;
-#endif /* !_NO_SUGGESTIONS */
+#else
 	return;
+#endif /* !_NO_SUGGESTIONS */
 }
 
 static void
@@ -1276,6 +1278,26 @@ xset_prop_fields(const char *optval)
 	}
 #endif /* !ST_BTIME*/
 }
+
+static void
+xset_pager_view(char *arg)
+{
+	if (!arg || !*arg || *arg == '-')
+		err_arg_required("--pager-view");
+
+	if (*arg == 'a' && strcmp(arg, "auto") == 0) {
+		xargs.pager_view = conf.pager_view = PAGER_AUTO;
+	} else if (*arg == 'l' && strcmp(arg, "long") == 0) {
+		xargs.pager_view = conf.pager_view = PAGER_LONG;
+	} else if (*arg == 's' && strcmp(arg, "short") == 0) {
+		xargs.pager_view = conf.pager_view = PAGER_SHORT;
+	} else {
+		fprintf(stderr, _("%s: --pager-view: '%s': Invalid value.\n"
+			"Valid values are 'auto', 'long', and 'short'\n"),
+			PROGRAM_NAME, arg);
+		exit(EXIT_FAILURE);
+	}
+}
 #endif /* !_BE_POSIX */
 
 __attribute__ ((noreturn))
@@ -1312,26 +1334,6 @@ set_tab_mode(const char *opt)
 }
 #endif /* _BE_POSIX */
 
-static void
-xset_pager_view(char *arg)
-{
-	if (!arg || !*arg || *arg == '-')
-		err_arg_required("--pager-view");
-
-	if (*arg == 'a' && strcmp(arg, "auto") == 0) {
-		xargs.pager_view = conf.pager_view = PAGER_AUTO;
-	} else if (*arg == 'l' && strcmp(arg, "long") == 0) {
-		xargs.pager_view = conf.pager_view = PAGER_LONG;
-	} else if (*arg == 's' && strcmp(arg, "short") == 0) {
-		xargs.pager_view = conf.pager_view = PAGER_SHORT;
-	} else {
-		fprintf(stderr, _("%s: --pager-view: '%s': Invalid value.\n"
-			"Valid values are 'auto', 'long', and 'short'\n"),
-			PROGRAM_NAME, arg);
-		exit(EXIT_FAILURE);
-	}
-}
-
 /* Evaluate command line arguments, if any, and change initial variables to
  * their corresponding values. */
 #ifdef _BE_POSIX
