@@ -63,6 +63,21 @@ press_any_key_to_continue(const int init_newline)
 	errno = saved_errno;
 }
 
+/* Return the value of the environment variable S, allocated via malloc if
+ * ALLOC is 1, or just a pointer to the value if 0. */
+char *
+xgetenv(const char *s, const int alloc)
+{
+	if (!s || !*s)
+		return (char *)NULL;
+
+	char *p = getenv(s);
+	if (p && *p)
+		return (alloc == 1 ? strdup(p) : p);
+
+	return (char *)NULL;
+}
+
 /* Print the regex error ERRCODE (returned by either regcomp(3) or regexec(3)),
  * whose compiled regular expression is REGEXP and original pattern PATTERN,
  * in the next prompt if PROMPT_ERR == 1, or immediately otherwise. */
@@ -621,7 +636,7 @@ gen_date_suffix(const struct tm tm)
 int
 xmkdir(char *dir, const mode_t mode)
 {
-	mode_t old_mask = umask(0077);
+	mode_t old_mask = umask(0077); /* flawfinder: ignore */
 	int ret = mkdirat(XAT_FDCWD, dir, mode);
 	umask(old_mask);
 
@@ -836,13 +851,13 @@ get_rgb(char *hex, int *attr, int *r, int *g, int *b)
 	tmp[0] = *(hex + 4); tmp[1] = *(hex + 5);
 	*b = hex2int(tmp);
 
-	*attr = 0;
-	if (*(hex + 6) == '-' && *(hex + 7) && *(hex + 7) >= '1'
+	*attr = -1; /* Attribute unset */
+	if (*(hex + 6) == '-' && *(hex + 7) && *(hex + 7) >= '0'
 	&& *(hex + 7) <= '9' && !*(hex + 8))
 		*attr = *(hex + 7) - '0';
 
 	if (xargs.no_bold == 1 && *attr == 1)
-		*attr = 0;
+		*attr = -1;
 
 	return 0;
 }
@@ -870,11 +885,14 @@ get_rgb(char *hex, int *attr, int *r, int *g, int *b)
 char *
 hex2rgb(char *hex)
 {
-	int attr = 0, r = 0, g = 0, b = 0;
+	int attr = -1, r = 0, g = 0, b = 0;
 	if (get_rgb(hex, &attr, &r, &g, &b) == -1)
 		return (char *)NULL;
 
-	snprintf(tmp_color, sizeof(tmp_color), "%d;38;2;%d;%d;%d", attr, r, g, b);
+	if (attr == -1) /* No attribute */
+		snprintf(tmp_color, sizeof(tmp_color), "38;2;%d;%d;%d", r, g, b);
+	else
+		snprintf(tmp_color, sizeof(tmp_color), "%d;38;2;%d;%d;%d", attr, r, g, b);
 	return tmp_color;
 }
 
@@ -963,7 +981,7 @@ get_cmd_path(const char *cmd)
 		&& *paths[i].path == '.' && !paths[i].path[1])
 			continue;
 
-		snprintf(cmd_path, PATH_MAX + 1, "%s/%s", paths[i].path, cmd); /* NOLINT */
+		snprintf(cmd_path, PATH_MAX + 1, "%s/%s", paths[i].path, cmd);
 		if (access(cmd_path, X_OK) == 0)
 			return cmd_path;
 	}
@@ -1037,16 +1055,30 @@ get_link_ref(const char *link)
 	return (int)(a.st_mode & S_IFMT);
 }
 
+static char const *nums[102] = {
+	"0", "1", "2", "3", "4", "5", "6", "7", "8", "9",
+	"10", "11", "12", "13", "14", "15", "16", "17", "18", "19",
+	"20", "21", "22", "23", "24", "25", "26", "27", "28", "29",
+	"30", "31", "32", "33", "34", "35", "36", "37", "38", "39",
+	"40", "41", "42", "43", "44", "45", "46", "47", "48", "49",
+	"50", "51", "52", "53", "54", "55", "56", "57", "58", "59",
+	"60", "61", "62", "63", "64", "65", "66", "67", "68", "69",
+	"70", "71", "72", "73", "74", "75", "76", "77", "78", "79",
+	"80", "81", "82", "83", "84", "85", "86", "87", "88", "89",
+	"90", "91", "92", "93", "94", "95", "96", "97", "98", "99",
+	"100", NULL
+	};
+
 /* Transform an integer (N) into a string of chars.
  * This exists because most operating systems do not provide itoa(3).
  * It handles integer numbers between 0 and LLONG_MAX. */
-char *
+const char *
 xitoa(long long n)
 {
-	if (n == 0)
-		return "0";
+	if (n >= 0 && n <= 100)
+		return nums[n];
 
-	static char buf[32] = {0};
+	static char buf[MAX_INT_STR] = {0};
 	long long i = 30;
 
 	while (n > 0 && i > 0) {
