@@ -3,7 +3,7 @@
 /*
  * This file is part of CliFM
  *
- * Copyright (C) 2016-2023, L. Abramovich <leo.clifm@outlook.com>
+ * Copyright (C) 2016-2024, L. Abramovich <leo.clifm@outlook.com>
  * All rights reserved.
 
  * CliFM is free software; you can redistribute it and/or modify
@@ -67,7 +67,6 @@ char *bash_builtins[] = {
 	"enable",
 	"eval",
 	"exec",
-	"export",
 	"false",
 	"fg",
 	"function",
@@ -99,7 +98,6 @@ char *bash_builtins[] = {
 	"type",
 	"typeset",
 	"ulimit",
-	"umask",
 	"unalias",
 	"unset",
 	"variables",
@@ -130,7 +128,6 @@ char *dash_builtins[] = {
 	"echo",
 	"eval",
 	"exec",
-	"export",
 	"fg",
 	"getopts",
 	"hash",
@@ -144,7 +141,6 @@ char *dash_builtins[] = {
 	"trap",
 	"type",
 	"ulimit",
-	"umask",
 	"unalias",
 	"unset",
 	"wait",
@@ -267,7 +263,6 @@ char *fish_builtins[] = {
 	"true",
 	"type",
 	"ulimit",
-	"umask",
 	"vared",
 	"wait",
 	NULL
@@ -301,7 +296,6 @@ char *ksh_builtins[] = {
 	"enum",
 	"eval",
 	"exec",
-	"export",
 	"false",
 	"fg",
 	"getopts",
@@ -322,7 +316,6 @@ char *ksh_builtins[] = {
 	"true",
 	"typeset",
 	"ulimit",
-	"umask",
 	"unalias",
 	"unset",
 	"wait",
@@ -405,7 +398,6 @@ char *tcsh_builtins[] = {
 	"telltc",
 	"termname",
 	"time",
-	"umask",
 	"unalias",
 	"uncomplete",
 	"unhash",
@@ -470,7 +462,6 @@ char *zsh_builtins[] = {
 	"enable",
 	"eval",
 	"exec",
-	"export",
 	"false",
 	"fg",
 	"float",
@@ -512,7 +503,6 @@ char *zsh_builtins[] = {
 	"type",
 	"typeset",
 	"ulimit",
-	"umask",
 	"unalias",
 	"unfunction",
 	"unhash",
