@@ -29,6 +29,10 @@
 #include <string.h>
 #include <unistd.h>
 
+#if defined(MAC_OS_X_RENAMEAT_SYS_STDIO_H)
+# include <sys/stdio.h> /* renameat(2) */
+#endif /* MAC_OS_X_RENAMEAT_SYS_STDIO_H */
+
 #if defined(HAVE_FILE_ATTRS)
 # ifdef __TINYC__
 #  undef SYNC_FILE_RANGE_WRITE_AND_WAIT /* Silence redefinition error */
@@ -508,8 +512,10 @@ contains_digit(const char *str)
 static int
 find_cmd(const struct cmdslist_t *cmds_list, const size_t list_size, char *cmd)
 {
-	int found = 0, i = (int)list_size;
-	int c = -1, d = contains_digit(cmd);
+	int found = 0;
+	int i = (int)list_size;
+	char c = 0;
+	const int d = contains_digit(cmd);
 
 	if (d != -1) {
 		c = cmd[d];
@@ -526,7 +532,7 @@ find_cmd(const struct cmdslist_t *cmds_list, const size_t list_size, char *cmd)
 	}
 
 	if (d != -1)
-		cmd[d] = (char)c;
+		cmd[d] = c;
 
 	return found;
 }
@@ -792,19 +798,12 @@ check_regex(char *str)
 char **
 check_for_alias(char **args)
 {
-	/* Do not expand alias if first word is an ELN */
-	if (aliases_n == 0 || !aliases || !args || flags & FIRST_WORD_IS_ELN)
+	/* Do not expand alias if first word is an ELN or the alias name
+	 * starts with a backslash. */
+	if (aliases_n == 0 || !aliases || !args || flags & FIRST_WORD_IS_ELN
+	|| *args[0] == '\\')
 		return (char **)NULL;
 
-	if (conf.autocd == 1 || conf.auto_open == 1) {
-		/* Do not expand alias is first word is a file name in CWD */
-		struct stat a;
-		if (*args[0] == '\\' || (stat(args[0], &a) == 0 && ((S_ISDIR(a.st_mode)
-		&& conf.autocd == 1) || (!S_ISDIR(a.st_mode)
-		&& conf.auto_open == 1) ) ) )
-			return (char **)NULL;
-	}
-
 	int i = (int)aliases_n;
 
 	while (--i >= 0) {
@@ -861,7 +860,8 @@ truncate_file(char *file, const int max, const int check_dups)
 	int orig_fd = 0;
 	if (stat(file, &attr) == -1) {
 		/* File doesn't exist: create it and exit. */
-		if (!(orig_fp = open_fwrite(file, &orig_fd))) {
+		orig_fp = open_fwrite(file, &orig_fd);
+		if (!orig_fp) {
 			err('w', PRINT_PROMPT, "%s: '%s': %s\n", PROGRAM_NAME, file,
 				strerror(errno));
 		} else {
@@ -881,11 +881,17 @@ truncate_file(char *file, const int max, const int check_dups)
 	int n = 0, c;
 
 	/* Count newline chars to get the amount of lines in the file. */
-	while ((c = fgetc(orig_fp)) != EOF && n < INT_MAX) {
+	while ((c = fgetc(orig_fp)) != EOF && n < INT_MAX) { /* Flawfinder: ignore */
 		if (c == '\n')
 			n++;
 	}
 
+	if (c == EOF && ferror(orig_fp)) {
+		err('w', PRINT_PROMPT, _("%s: '%s': Error reading file\n"),
+			PROGRAM_NAME, file);
+		goto EXIT;
+	}
+
 	if (n <= max)
 		goto EXIT;
 
@@ -926,8 +932,9 @@ truncate_file(char *file, const int max, const int check_dups)
 			continue;
 
 		/* Delete old entries, i.e., copy only new ones. */
-		if (i++ >= n - (max - 1))
-			fprintf(tmp_fp, "%s", line);
+		if (i >= n - (max - 1))
+			fputs(line, tmp_fp);
+		i++;
 
 		if (check_dups == 1) {
 			free(prev_line);
