@@ -37,132 +37,11 @@ struct utable_t {
  * printf(1) as folows:
  * $ printf "\UXXXX" # no leading 0x */
 struct utable_t unitable[] = {
-	{0x0020, 0, "_" },
-	{0x0021, 0, "_" },
-	{0x0022, 0, "_" },
-	{0x0023, 0, "_" },
-	{0x0024, 0, "s" },
-	{0x0025, 0, "_" },
-	{0x0026, 0, "_and_" },
-	{0x0027, 0, "_" },
-	{0x0028, 0, "-" },
-	{0x0029, 0, "-" },
-	{0x002a, 0, "_" },
-	{0x002b, 0, "_" },
-	{0x002c, 0, "_" },
-	{0x002d, 0, "-" },
-	{0x002e, 0, "." },
-	{0x002f, 0, "_" },
-	{0x0030, 0, "0" },
-	{0x0031, 0, "1" },
-	{0x0032, 0, "2" },
-	{0x0033, 0, "3" },
-	{0x0034, 0, "4" },
-	{0x0035, 0, "5" },
-	{0x0036, 0, "6" },
-	{0x0037, 0, "7" },
-	{0x0038, 0, "8" },
-	{0x0039, 0, "9" },
-	{0x003a, 0, "_" },
-	{0x003b, 0, "_" },
-	{0x003c, 0, "_" },
-	{0x003d, 0, "_" },
-	{0x003e, 0, "_" },
-	{0x003f, 0, "_" },
-	{0x0040, 0, "_" },
-	{0x0041, 0, "A" },
-	{0x0042, 0, "B" },
-	{0x0043, 0, "C" },
-	{0x0044, 0, "D" },
-	{0x0045, 0, "E" },
-	{0x0046, 0, "F" },
-	{0x0047, 0, "G" },
-	{0x0048, 0, "H" },
-	{0x0049, 0, "I" },
-	{0x004a, 0, "J" },
-	{0x004b, 0, "K" },
-	{0x004c, 0, "L" },
-	{0x004d, 0, "M" },
-	{0x004e, 0, "N" },
-	{0x004f, 0, "O" },
-	{0x0050, 0, "P" },
-	{0x0051, 0, "Q" },
-	{0x0052, 0, "R" },
-	{0x0053, 0, "S" },
-	{0x0054, 0, "T" },
-	{0x0055, 0, "U" },
-	{0x0056, 0, "V" },
-	{0x0057, 0, "W" },
-	{0x0058, 0, "X" },
-	{0x0059, 0, "Y" },
-	{0x005a, 0, "Z" },
-	{0x005b, 0, "-" },
-	{0x005c, 0, "_" },
-	{0x005d, 0, "-" },
-	{0x005e, 0, "_" },
-	{0x005f, 0, "_" },
-	{0x0060, 0, "_" },
-	{0x0061, 0, "a" },
-	{0x0062, 0, "b" },
-	{0x0063, 0, "c" },
-	{0x0064, 0, "d" },
-	{0x0065, 0, "e" },
-	{0x0066, 0, "f" },
-	{0x0067, 0, "g" },
-	{0x0068, 0, "h" },
-	{0x0069, 0, "i" },
-	{0x006a, 0, "j" },
-	{0x006b, 0, "k" },
-	{0x006c, 0, "l" },
-	{0x006d, 0, "m" },
-	{0x006e, 0, "n" },
-	{0x006f, 0, "o" },
-	{0x0070, 0, "p" },
-	{0x0071, 0, "q" },
-	{0x0072, 0, "r" },
-	{0x0073, 0, "s" },
-	{0x0074, 0, "t" },
-	{0x0075, 0, "u" },
-	{0x0076, 0, "v" },
-	{0x0077, 0, "w" },
-	{0x0078, 0, "x" },
-	{0x0079, 0, "y" },
-	{0x007a, 0, "z" },
-	{0x007b, 0, "-" },
-	{0x007c, 0, "_" },
-	{0x007d, 0, "-" },
-	{0x007e, 0, "_" },
-	{0x00a0, 0, "_" },
-	{0x00a1, 0, "_" },
-	{0x00a2, 0, "_cent_" },
-	{0x00a3, 0, "_pound_" },
-	{0x00a4, 0, "s" },
-	{0x00a5, 0, "_yen_" },
-	{0x00a7, 0, "_ss_" },
-	{0x00a8, 0, "_" },
-	{0x00a9, 0, "_copy_" },
-	{0x00aa, 0, "_a_" },
-	{0x00ab, 0, "_" },
-	{0x00ad, 0, "-" },
-	{0x00ae, 0, "_reg_" },
-	{0x00b0, 0, "_deg_" },
-	{0x00b2, 0, "-2" },
-	{0x00b3, 0, "-3" },
-	{0x00b4, 0, "_" }, // accute accent: ´
-	{0x00b5, 0, "u" },
-	{0x00b6, 0, "_pp_" },
-	{0x00b7, 0, "_" },
-	{0x00b8, 0, " " },
-	{0x00b9, 0, "-1" },
-	{0x00ba, 0, "_o_" },
-	{0x00bb, 0, "_" },
-	{0x00bf, 0, "_" },
+	/* Letters */
 	{0x00c0, 0, "A" },
 	{0x00c1, 0, "A" },
 	{0x00c2, 0, "A" },
 	{0x00c3, 0, "A" },
-//	{0x00c4, 0, "A" },
-	{0x00c4, 0, "Ae" },
 	{0x00c5, 0, "A" },
 	{0x00c6, 0, "AE" },
 	{0x00c7, 0, "C" },
@@ -180,15 +59,11 @@ struct utable_t unitable[] = {
 	{0x00d3, 0, "O" },
 	{0x00d4, 0, "O" },
 	{0x00d5, 0, "O" },
-//	{0x00d6, 0, "O" },
-	{0x00d6, 0, "Oe" },
 	{0x00d7, 0, "x" },
 	{0x00d8, 0, "O" },
 	{0x00d9, 0, "U" },
 	{0x00da, 0, "U" },
 	{0x00db, 0, "U" },
-//	{0x00dc, 0, "U" },
-	{0x00dc, 0, "Ue" },
 	{0x00dd, 0, "Y" },
 	{0x00de, 0, "TH" },
 	{0x00df, 0, "ss" },
@@ -196,8 +71,6 @@ struct utable_t unitable[] = {
 	{0x00e1, 0, "a" },
 	{0x00e2, 0, "a" },
 	{0x00e3, 0, "a" },
-//	{0x00e4, 0, "a" },
-	{0x00e4, 0, "ae" },
 	{0x00e5, 0, "a" },
 	{0x00e6, 0, "ae" },
 	{0x00e7, 0, "c" },
@@ -215,14 +88,10 @@ struct utable_t unitable[] = {
 	{0x00f3, 0, "o" },
 	{0x00f4, 0, "o" },
 	{0x00f5, 0, "o" },
-//	{0x00f6, 0, "o" },
-	{0x00f6, 0, "oe" },
 	{0x00f8, 0, "o" },
 	{0x00f9, 0, "u" },
 	{0x00fa, 0, "u" },
 	{0x00fb, 0, "u" },
-//	{0x00fc, 0, "u" },
-	{0x00fc, 0, "ue" },
 	{0x00fd, 0, "y" },
 	{0x00fe, 0, "th" },
 	{0x00ff, 0, "y" },
@@ -545,7 +414,6 @@ struct utable_t unitable[] = {
 	{0x0240, 0, "z" },
 	{0x0243, 0, "B" },
 	{0x0244, 0, "U" },
-	{0x0245, 0, "^" },
 	{0x0246, 0, "E" },
 	{0x0247, 0, "e" },
 	{0x0248, 0, "J" },
@@ -556,8 +424,6 @@ struct utable_t unitable[] = {
 	{0x024d, 0, "r" },
 	{0x024e, 0, "Y" },
 	{0x024f, 0, "y" },
-	{0x02c6, 0, "^" },
-	{0x02dc, 0, "~" },
 	{0x03a1, 0, "P" },
 	{0x03c1, 0, "p" },
 	{0x1952, 0, "n" },
@@ -589,22 +455,34 @@ struct utable_t unitable[] = {
 	{0x1e9b, 0, "s" },
 	{0x1ef2, 0, "Y" },
 	{0x1ef3, 0, "y" },
-/*	{0x2000, 0, "_" },
-	{0x2001, 0, "_" },
-	{0x2002, 0, "_" },
-	{0x2003, 0, "_" },
-	{0x2004, 0, "_" },
-	{0x2005, 0, "_" },
-	{0x2006, 0, "_" },
-	{0x2007, 0, "_" },
-	{0x2008, 0, "_" },
-	{0x2009, 0, "_" },
-	{0x200a, 0, "_" },
-	{0x200b, 0, "" },
-	{0x200c, 0, "" },
-	{0x200d, 0, "" },
-	{0x200e, 0, "" },
-	{0x200f, 0, "" }, */
+
+	/* Symbols */
+	{0x00a1, 0, "_" }, // inverted exclamation mark
+	{0x00a2, 0, "_cent_" },
+	{0x00a3, 0, "_pound_" },
+	{0x00a4, 0, "_" },
+	{0x00a5, 0, "_yen_" },
+	{0x00a7, 0, "_ss_" },
+	{0x00a8, 0, "_" },
+	{0x00a9, 0, "_copy_" },
+	{0x00aa, 0, "_a_" },
+	{0x00ab, 0, "_" },
+	{0x00ad, 0, "-" },
+	{0x00ae, 0, "_reg_" },
+	{0x00b0, 0, "_deg_" },
+	{0x00b2, 0, "-2" },
+	{0x00b3, 0, "-3" },
+	{0x00b4, 0, "_" }, // accute accent: ´
+	{0x00b5, 0, "u" },
+	{0x00b6, 0, "_pp_" },
+	{0x00b7, 0, "_" },
+	{0x00b8, 0, "_" },
+	{0x00b9, 0, "-1" },
+	{0x00ba, 0, "_o_" },
+	{0x00bb, 0, "_" },
+	{0x00bf, 0, "_" },
+	{0x02c6, 0, "_" }, // caret
+	{0x02dc, 0, "_" }, // tilde
 	{0x2010, 0, "-" },
 	{0x2011, 0, "-" },
 	{0x2012, 0, "-" },
@@ -612,40 +490,35 @@ struct utable_t unitable[] = {
 	{0x2014, 0, "-" },
 	{0x2015, 0, "-" },
 	{0x2017, 0, "_" },
-/*	{0x2018, 0, "_" },
+	{0x2018, 0, "_" },
 	{0x2019, 0, "_" },
 	{0x201a, 0, "_" },
 	{0x201b, 0, "_" },
 	{0x201c, 0, "_" },
 	{0x201d, 0, "_" },
 	{0x201e, 0, "_" },
-	{0x201f, 0, "_" }, */
+	{0x201f, 0, "_" },
 	{0x2020, 0, "-" },
-	{0x2021, 0, "--" },
-	{0x2022, 0, "." },
-	{0x2024, 0, "." },
-	{0x2025, 0, ".." },
-	{0x2026, 0, "..." },
-	{0x2027, 0, "." },
-/*	{0x202f, 0, " " },
-	{0x2030, 0, "%" },
-	{0x2031, 0, "%" },
+	{0x2021, 0, "_" },
+	{0x2022, 0, "_" },
+	{0x2024, 0, "_" },
+	{0x2025, 0, "_" },
+	{0x2026, 0, "_" },
+	{0x2027, 0, "_" },
 	{0x2032, 0, "_" },
-	{0x2033, 0, "__" },
-	{0x2034, 0, "___" },
+	{0x2033, 0, "_" },
+	{0x2034, 0, "_" },
 	{0x2035, 0, "_" },
-	{0x2036, 0, "__" },
-	{0x2037, 0, "___" }, */
+	{0x2036, 0, "_" },
+	{0x2037, 0, "_" },
 	{0x2038, 0, "_" },
-//	{0x203b, 0, "*" },
-//	{0x203c, 0, "!!" },
 	{0x203d, 0, "_" },
 	{0x203e, 0, "-" },
 	{0x203f, 0, "_" },
 	{0x2040, 0, "-" },
 	{0x2041, 0, "_" },
-//	{0x2042, 0, "_" },
 	{0x2043, 0, "-" },
+	{0x2044, 0, "_" }, // slash
 	{0x2045, 0, "-" },
 	{0x2046, 0, "-" },
 	{0x2047, 0, "_" },
@@ -653,23 +526,19 @@ struct utable_t unitable[] = {
 	{0x2049, 0, "_" },
 	{0x204a, 0, "_and_" },
 	{0x204b, 0, "_pp_" },
-	{0x204e, 0, "_" },
 	{0x204f, 0, "_" },
-	{0x2051, 0, "_" },
 	{0x2052, 0, "_" },
 	{0x2053, 0, "_" },
 	{0x2054, 0, "_" },
 	{0x2055, 0, "_" },
-	{0x2056, 0, "..." },
+	{0x2056, 0, "_" },
 	{0x2057, 0, "_" },
-	{0x2058, 0, "...." },
-	{0x2059, 0, "....." },
-	{0x205a, 0, ".." },
-	{0x205b, 0, "...." },
+	{0x2058, 0, "_" },
+	{0x2059, 0, "_" },
+	{0x205a, 0, "_" },
+	{0x205b, 0, "_" },
 	{0x205d, 0, "_" },
 	{0x205e, 0, "_" },
-	{0x205f, 0, "_" },
-	{0x2060, 0, "_" },
 	{0x20a0, 0, "ECU" },
 	{0x20a1, 0, "CL" },
 	{0x20a2, 0, "Cr" },
@@ -694,6 +563,47 @@ struct utable_t unitable[] = {
 	{0x10348, 0, "hu" },
 	{0x1f37a, 0, "_beer_" },
 	{0x02bc, 0, "_"},
+
+	/* German vowels with umlaut */
+	{0x00f6, 0, "oe" },
+	{0x00fc, 0, "ue" },
+	{0x00e4, 0, "ae" },
+	{0x00dc, 0, "Ue" },
+	{0x00d6, 0, "Oe" },
+	{0x00c4, 0, "Ae" },
+
+	/* Non-ASCII whitespaces */
+	{0x2000, 0, "_" }, // en quad
+	{0x2001, 0, "_" }, // em quad
+	{0x2002, 0, "_" }, // en space
+	{0x2003, 0, "_" }, // em space
+	{0x2004, 0, "_" }, // three-per-em space
+	{0x2005, 0, "_" }, // four-per-em space
+	{0x2006, 0, "_" }, // six-per-em space
+	{0x2007, 0, "_" }, // figure space
+	{0x2008, 0, "_" }, // punctuation space
+	{0x2009, 0, "_" }, // thin space
+	{0x200a, 0, "_" }, // hair space
+	{0x200b, 0, "_" }, // zero width space
+	{0x200c, 0, "_" }, // zero width non-joiner
+	{0x200d, 0, "_" }, // zero width joiner
+	{0x2422, 0, "_" }, // blank symbol
+	{0x2800, 0, "_" }, // braille pattern blank
+	{0x3000, 0, "_" }, // ideographic space
+	{0xfeff, 0, "_"}, // zero width non-breaking space
+	{0x3164, 0, "_"}, // hangul filler
+	{0x205f, 0, "_" }, // medium mathematical space
+	{0x2060, 0, "_" }, // word joiner
+	{0x2028, 0, "_" }, // line separator
+	{0x2029, 0, "_" }, // paragraph separator
+	{0x202f, 0, "_" }, // narrow no-break space
+	{0x115f, 0, "_" }, // HANGUL CHOSEONG FILLER
+	{0x1160, 0, "_" }, // HANGUL JUNGSEONG FILLER
+	{0x1680, 0, "_" }, // ogham space mark
+	{0x180e, 0, "_" }, // mongolian vowel separator
+	{0x0085, 0, "_" }, // next line
+	{0x00a0, 0, "_" }, // no-break space
+
 	{0, 0, NULL},
 };
 
