@@ -29,7 +29,7 @@
 
 /* Let's fake the following macros: we won't use them anyway. */
 #ifndef AT_FDCWD
-# define AT_FDCWD -100
+# define AT_FDCWD (-100)
 #endif /* !AT_FDCWD */
 
 #ifndef AT_SYMLINK_NOFOLLOW
@@ -45,6 +45,8 @@
  * dirent.h) */
 # undef dirfd
 #endif /* dirfd */
+/* A dummy value, since we're not using file descriptors. Functions using
+ * them are replaced by functions using plain file names instead. */
 #define dirfd(d)   (0)
 
 #define alphasort  x_alphasort
@@ -67,6 +69,7 @@ int old_chown(int fd, const char *path, uid_t owner, gid_t group, int flag);
 int old_mkdir(int dirfd, const char *pathname, mode_t mode);
 ssize_t old_readlink(int dirfd, const char *restrict pathname,
 	char *restrict buf, size_t bufsiz);
+char *old_realpath(const char *restrict path, char *restrict resolved_path);
 int old_rename(int olddirfd, const char *oldpath, int newdirfd,
 	const char *newpath);
 int old_stat(int fd, const char *restrict path, struct stat *sb, int flag);
