@@ -41,6 +41,9 @@ void init_config(void);
 int  reload_config(void);
 void set_div_line(char *line);
 void set_env(const int reload);
+#ifndef _NO_FZF
+void set_fzf_border_type(char *line);
+#endif /* !_NO_FZF */
 void set_sel_file(void);
 void set_time_style(char *line, char **str, const int ptime);
 
