@@ -159,7 +159,7 @@ reload_binaries(void)
 		free(paths);
 	}
 
-	path_n = (size_t)get_path_env(1);
+	path_n = get_path_env(1);
 	get_path_programs();
 }
 #endif /* !__CYGWIN__ */
@@ -311,7 +311,7 @@ quit_func(char **args, const int exit_status)
 	if (!args || !args[0])
 		return;
 
-	if (args[1] && *args[1] == '-' && IS_HELP(args[1])) {
+	if (args[1] && IS_HELP(args[1])) {
 		puts(QUIT_HELP);
 		return;
 	}
@@ -653,7 +653,7 @@ msgs_function(const char *arg)
 		}
 
 		size_t i;
-		for (i = 0; i < (size_t)msgs_n; i++)
+		for (i = 0; i < msgs_n; i++)
 			free(messages[i]);
 
 		if (conf.autols == 1)
@@ -666,7 +666,7 @@ msgs_function(const char *arg)
 
 	if (msgs_n > 0) {
 		size_t i;
-		for (i = 0; i < (size_t)msgs_n; i++)
+		for (i = 0; i < msgs_n; i++)
 			printf("%s", messages[i]);
 	} else {
 		printf(_("%s: No messages\n"), PROGRAM_NAME);
@@ -735,17 +735,17 @@ lightmode_function(const char *arg)
 }
 
 static size_t
-get_largest_alias_name(void)
+get_longest_alias_name(void)
 {
 	int i = (int)aliases_n;
-	size_t largest = 0;
+	size_t l = 0;
 	while (--i >= 0) {
 		const size_t len = strlen(aliases[i].name);
-		if (len > largest)
-			largest = len;
+		if (len > l)
+			l = len;
 	}
 
-	return largest;
+	return l;
 }
 
 static int
@@ -757,10 +757,10 @@ list_aliases(void)
 	}
 
 	size_t i;
-	const size_t largest = get_largest_alias_name();
+	const size_t longest_name_len = get_longest_alias_name();
 
 	for (i = 0; i < aliases_n; i++) {
-		printf("%-*s %s->%s %s\n", (int)largest,
+		printf("%-*s %s->%s %s\n", (int)longest_name_len,
 			aliases[i].name, mi_c, df_c, aliases[i].cmd);
 	}
 
@@ -1197,8 +1197,7 @@ check_auto_first(char **args)
 	|| (args[1] && (*args[1] != '&' || args[1][1])))
 		return (-1);
 
-	if ((*args[0] == 'e' && strcmp(args[0], "edit") == 0)
-	|| (*args[0] == 'c' && strcmp(args[0], "config") == 0))
+	if (!(flags & FIRST_WORD_IS_ELN) && is_internal_c(args[0]))
 		return (-1);
 
 	char *deq_str = (char *)NULL;
@@ -1242,8 +1241,8 @@ check_auto_first(char **args)
 static int
 auto_open_file(char **args, char *tmp)
 {
-	char *cmd[] = {"open", tmp, (args_n >= 1) ? args[1]
-		: NULL, (args_n >= 2) ? args[2] : NULL, NULL};
+	char *cmd[] = {"open", tmp, args_n >= 1 ? args[1]
+		: NULL, args_n >= 2 ? args[2] : NULL, NULL};
 	args_n++;
 	const int ret = open_function(cmd);
 	args_n--;
@@ -1292,13 +1291,17 @@ check_auto_second(char **args)
 
 	if (conf.autocd == 1 && cdpath_n > 0 && !args[1]) {
 		const int ret = cd_function(tmp, CD_NO_PRINT_ERROR);
-		if (ret == FUNC_SUCCESS)
-			{ free(tmp); return FUNC_SUCCESS; }
+		if (ret == FUNC_SUCCESS) {
+			free(tmp);
+			return FUNC_SUCCESS;
+		}
 	}
 
 	struct stat attr;
-	if (stat(tmp, &attr) != 0)
-		{ free(tmp); return (-1); }
+	if (stat(tmp, &attr) != 0) {
+		free(tmp);
+		return (-1);
+	}
 
 	if (conf.autocd == 1 && S_ISDIR(attr.st_mode) && !args[1])
 		return autocd_dir(tmp);
@@ -2084,6 +2087,11 @@ exec_cmd(char **comm)
 	const int old_exit_code = exit_code;
 	exit_code = FUNC_SUCCESS;
 
+	int is_internal_cmd = 1;
+
+	if (dir_cmds.first_cmd_in_dir == UNSET && dir_cmds.last_cmd_ignored == 0)
+		dir_cmds.first_cmd_in_dir = (int)current_hist_n;
+
 	/* Remove backslash in front of command names: used to bypass alias names */
 	if (*comm[0] == '\\' && *(comm[0] + 1))
 		remove_backslash(&comm[0]);
@@ -2166,8 +2174,7 @@ exec_cmd(char **comm)
 	else if (*comm[0] == 'f' && (!comm[0][1] || strcmp(comm[0], "forth") == 0))
 		return (exit_code = forth_function(comm));
 
-	else if ((*comm[0] == 'b' || *comm[0] == 'f' || *comm[0] == 'd')
-	&& comm[0][1] == 'h' && !comm[0][2])
+	else if (*comm[0] == 'd' && comm[0][1] == 'h' && !comm[0][2])
 		return (exit_code = dirhist_function(comm[1]));
 
 	/*    ############### BULK REMOVE ##################     */
@@ -2354,8 +2361,7 @@ exec_cmd(char **comm)
 
 	/*     ############### SEARCH ##################     */
 	else if ( (*comm[0] == '/' && is_path(comm[0]) == 0)
-	|| (*comm[0] == '/' && !comm[0][1] && comm[1] && *comm[1] == '-'
-	&& IS_HELP(comm[1])) )
+	|| (*comm[0] == '/' && !comm[0][1] && comm[1] && IS_HELP(comm[1])) )
 		return (exit_code = search_function(comm));
 
 	/*    ############### BATCH LINK ##################     */
@@ -2535,10 +2541,8 @@ exec_cmd(char **comm)
 	else if (*comm[0] == 'a' && strcmp(comm[0], "alias") == 0)
 		return (exit_code = alias_function(comm));
 
-	/* #### EDIT, CONFIG #### */
-	/* The 'edit' command is deprecated */
-	else if ((*comm[0] == 'e' && strcmp(comm[0], "edit") == 0)
-	|| (*comm[0] == 'c' && strcmp(comm[0], "config") == 0))
+	/* #### CONFIG #### */
+	else if (*comm[0] == 'c' && strcmp(comm[0], "config") == 0)
 		return (exit_code = edit_function(comm));
 
 	/* #### HISTORY #### */
@@ -2592,7 +2596,7 @@ exec_cmd(char **comm)
 	}
 
 	/* These functions just print stuff, so that the value of exit_code
-	 * is always zero, that is to say, success */
+	 * is always zero, that is to say, success. */
 	else if (*comm[0] == 'c' && strcmp(comm[0], "colors") == 0) {
 		colors_function(comm[1]); return FUNC_SUCCESS;
 	}
@@ -2602,10 +2606,6 @@ exec_cmd(char **comm)
 		version_function();	return FUNC_SUCCESS;
 	}
 
-	else if (*comm[0] == 'f' && comm[0][1] == 's' && !comm[0][2]) {
-		free_software(); return FUNC_SUCCESS;
-	}
-
 	else if (*comm[0] == 'b' && strcmp(comm[0], "bonus") == 0) {
 		bonus_function(); return FUNC_SUCCESS;
 	}
@@ -2635,10 +2635,13 @@ exec_cmd(char **comm)
 		/* #  EXTERNAL/SHELL COMMANDS # */
 		if ((exit_code = run_shell_cmd(comm)) == FUNC_FAILURE)
 			return FUNC_FAILURE;
+		else
+			is_internal_cmd = 0;
 	}
 
 CHECK_EVENTS:
-	if (conf.autols == 0)
+	if (conf.autols == 0 || (is_internal_cmd == 0
+	&& conf.clear_screen == CLEAR_INTERNAL_CMD_ONLY))
 		return exit_code;
 
 #if defined(LINUX_INOTIFY)
