@@ -58,12 +58,12 @@ print_tips(const int all)
 	const char *TIPS[] = {
 #ifndef _BE_POSIX
 		"Add a new entry to the mimelist file: 'mm edit' or F6",
-		"Get mime information for a file. Ex: 'mm info file'",
+		"Get mime information for a file. E.g.: 'mm info file'",
 		"Manage default associated applications with the 'mime' command",
 		"Customize previewing applications: 'view edit' or F7",
 		"List mountpoints: 'mp' or Alt-m",
 		"Compress and decompress files using the 'ac' and 'ad' "
-		"commands respectively. Ex: 'ac sel' or 'ad file.zip'",
+		"commands respectively. E.g.: 'ac sel' or 'ad file.zip'",
 		"Disallow the use of shell commands with the -x option: 'clifm -x'",
 		"Don't like ELN's? Disable them using the -e command line switch",
 		"Disable file previews for TAB completion (fzf mode only) via --no-fzfpreview",
@@ -78,42 +78,42 @@ print_tips(const int all)
 		"Running in an untrusted environment? Try the --secure-env and "
 		"--secure-cmds command line switches",
 		"Run in disk usage analyzer mode using the -t command line switch",
-		"Fuzzy suggestions are supported. Ex: 'dwn > Downloads'. Enable them via --fuzzy-matching, or FuzzyMatching in the configuration file",
+		"Fuzzy suggestions are supported. E.g.: 'dwn > Downloads'. Enable them via --fuzzy-matching, or FuzzyMatching in the configuration file",
 		"Miss LS_COLORS? Run with --lscolors (GNU ls only)",
 #else
 		"Create a new profile: 'pf add PROFILE' or 'clifm -p PROFILE'",
 		"Run in incognito/private mode via the -s flag",
 		"Running in an untrusted environment? Try the -x, -X, and -Y flags",
 		"Run in disk usage analyzer mode using the -u flag",
-		"Fuzzy suggestions are supported. Ex: 'dwn > Downloads'. Enable them via the -m flag (or FuzzyMatching in the configuration file)",
+		"Fuzzy suggestions are supported. E.g.: 'dwn > Downloads'. Enable them via the -m flag (or FuzzyMatching in the configuration file)",
 #endif /* _BE_POSIX */
 		"Clear the screen: 'rf', '.', Enter (on empty line), or Ctrl-l",
 		"Try the autocd and auto-open functions: run 'FILE' instead "
 		"of 'cd FILE' or 'open FILE'",
 		"Do not forget to take a look at the manpage",
 		"Need more speed? Try the light mode ('lm' or Alt-y)",
-		"The Selection Box is shared among different instances of CliFM",
+		"The Selection Box is shared among different instances of Clifm",
 		"Use the 's' command to select files here and there: 's FILE...'",
-		"Use wildcards and regular expressions to select files. Ex: "
+		"Use wildcards and regular expressions to select files. E.g.: "
 		"'s *.c' or 's .*\\.c$'",
-		"Operate on selected files. Ex: 'p sel' or 'p s:'",
+		"Operate on selected files. E.g.: 'p sel' or 'p s:'",
 		"List selected files: 'sb' or s:<TAB>",
-		"ELN's and the 'sel' keyword work for shell commands as well. Ex: "
+		"ELN's and the 'sel' keyword work for shell commands as well. E.g.: "
 		"'ls -ld 1 sel'",
-		"Press TAB to automatically expand an ELN. Ex: 's 2<TAB>' -> 's FILENAME'",
-		"Use ranges (ELN-ELN) to easily move multiple files. Ex: 'm 3-12 dir/'",
+		"Press TAB to automatically expand an ELN. E.g.: 's 2<TAB>' -> 's FILENAME'",
+		"Use ranges (ELN-ELN) to easily move multiple files. E.g.: 'm 3-12 dir/'",
 		"Trash files with a simple 't FILE'",
 		"Too many files? Run the pager: 'pg' or Alt-0",
 		"Switch to long/detail view mode: 'll' or Alt-l",
-		"Search for files using the slash command. Ex: '/*.png'",
-		"The search function allows regular expressions. Ex: '/^c'",
+		"Search for files using the slash command. E.g.: '/*.png'",
+		"The search function allows regular expressions. E.g.: '/^c'",
 		"Add a new bookmark: 'bm add FILENAME BM_NAME'",
 		"Use c, l, m, md, and r instead of cp, ln, mv, mkdir, and rm",
 		"Access a remote file system using the 'net' command",
 		"Go back and forth in the directory history with Alt-j and Alt-k "
 		"(also Shift-Left and Shift-Right)",
 		"Run a new instance of Clifm: 'x DIR'",
-		"Send a command directly to the system shell. Ex: ';ls -l *'",
+		"Send a command directly to the system shell. E.g.: ';ls -l *'",
 		"Run the last executed command: '!!'",
 		"Access the commands history list: '!<TAB>'",
 		"Exclude commands from history using the HistIgnore option in the configuration file (F10)",
@@ -123,8 +123,8 @@ print_tips(const int all)
 		"List available aliases: 'alias'",
 		"Create aliases to easily run your preferred commands (F10)",
 		"Open and edit the configuration file: 'config' or F10",
-		"Get a brief description for each CliFM command: 'cmd<TAB>'",
-		"Print the currently used color codes: 'colors'",
+		"Get a brief description for each Clifm command: 'cmd<TAB>'",
+		"Preview the current color scheme: 'cs preview'",
 		"Toggle hidden files on/off: 'hh' or Alt-.",
 		"Toggle follow-links (long view only) on/off: 'k' or Alt-+",
 		"Go to the root directory: Alt-r",
@@ -134,17 +134,17 @@ print_tips(const int all)
 		"Open and edit the main configuration file: F10 (or 'config')",
 		"Open and edit the bookmarks file: F11 (or 'bm edit')",
 		"Open and edit the bookmarks file: F6 (or 'mm edit')",
-		"Set the starting path. Ex: 'clifm ~/media'",
-		"Use the 'o' command to open files and directories. Ex: 'o 12'",
+		"Set the starting path. E.g.: 'clifm ~/media'",
+		"Use the 'o' command to open files and directories. E.g.: 'o 12'",
 		"Open a file or directory by just entering its ELN or file name",
-		"Bypass the resource opener specifying an application. Ex: '12 leafpad'",
-		"Open a file and send it to the background. Ex: '24&'",
+		"Bypass the resource opener specifying an application. E.g.: '12 leafpad'",
+		"Open a file and send it to the background. E.g.: '24&'",
 		"Create a custom prompt by editing the prompts file ('prompt edit')",
 		"Customize your color scheme: 'cs edit' or F8",
 		"Launch the bookmarks manager: 'bm' or Alt-b",
 		"Quickly list your bookmarks: 'b:<TAB>'",
 		"Change to a bookmark: 'bm NAME' or 'b:NAME'",
-		"Chain commands using ';' and '&&'. Ex: 's 2 7-10; r sel'",
+		"Chain commands using ';' and '&&'. E.g.: 's 2 7-10; r sel'",
 		"Add emojis to your prompt by copying them to the prompt line ('prompt edit')",
 		"Switch profiles: 'pf set PROFILE'",
 		"Delete a profile: 'pf del PROFILE'",
@@ -162,9 +162,9 @@ print_tips(const int all)
 		"Launch the default system shell in CWD using ':' or ';'",
 		"Switch files sorting order: Alt-z and Alt-x",
 		"Reverse files sorting order: 'st rev'",
-		"Rename multiple files at once. Ex: 'br *.txt'",
+		"Rename multiple files at once. E.g.: 'br *.txt'",
 		"Need no more tips? Disable this feature in the configuration file",
-		"Need root privileges? Launch a new instance of CliFM as root "
+		"Need root privileges? Launch a new instance of Clifm as root "
 		"running the 'X' command (note the uppercase)",
 		"Create a fresh configuration file: 'config reset'",
 		"Use 'ln edit' (or 'le') to edit symbolic links",
@@ -172,30 +172,30 @@ print_tips(const int all)
 		"Keep in sight previous and next visited directories enabling the "
 		"DirhistMap option in the configuration file (F10)",
 		"Pin a file via the 'pin' command and then use it with the "
-		"period keyword (,). Ex: 'pin DIR' and then 'cd ,'",
+		"period keyword (,). E.g.: 'pin DIR' and then 'cd ,'",
 		"Switch color schemes using the 'cs' command",
 		"Try the 'j' command to quickly jump into any visited directory",
 		"Switch workspaces by pressing Alt-[1-4]",
 		"Use the 'ws' command to list available workspaces",
 		"Take a look at available plugins using the 'actions' command",
-		"Space is not needed. Ex: 'p12' instead of 'p 12'",
+		"Space is not needed. E.g.: 'p12' instead of 'p 12'",
 		"When searching or selecting files, use the exclamation mark "
-		"to negate a pattern. Ex: 's !*.pdf'",
+		"to negate a pattern. E.g.: 's !*.pdf'",
 		"Enable the TrashAsRm option to always send removed files to the trash can",
-		"Use the 'n' command to create multiple files/directories. Ex: 'n file dir/'",
+		"Use the 'n' command to create multiple files/directories. E.g.: 'n file dir/'",
 		"Add prompt commands via the 'promptcmd' keyword: 'config' (F10)",
 		"Need git integration? Consult the manpage",
 		"Accept a given suggestion by pressing the Right arrow key",
 		"Accept only the first suggested word by pressing Alt-f or Alt-Right",
 		"Enter 'c sel' to copy selected files into the current directory",
 		"Press Alt-q to delete the last entered word",
-		"Check ELN ranges by pressing TAB. Ex: '1-12<TAB>'",
-		"Operate on specific selected files. Ex: 'p sel<TAB>' or 'p s:<TAB>'",
+		"Check ELN ranges by pressing TAB. E.g.: '1-12<TAB>'",
+		"Operate on specific selected files. E.g.: 'p sel<TAB>' or 'p s:<TAB>'",
 		"Use the 'ow' command to open a file with a specific application",
 		"Limit the amount of files listed on the screen via the 'mf' command",
 		"Set a maximum file name length for listed files via the MaxFilenameLen "
 		"option in the configuration file (F10)",
-		"Use the 'm' command to interactively rename a file. Ex: 'm 12'",
+		"Use the 'm' command to interactively rename a file. E.g.: 'm 12'",
 		"Set options on a per directory basis via the autocommands function. Try 'help autocommands'",
 		"Clean up non-ASCII file names using the 'bleach' command",
 		"Get help for any internal command via the -h or --help parameters: 'p -h'",
@@ -210,16 +210,16 @@ print_tips(const int all)
 		"Quickly switch prompts via 'prompt NAME' (or 'prompt set <TAB>')",
 		"Press Alt-TAB to toggle the disk usage analyzer mode",
 		"Press Ctrl-Alt-l to toggle max file name length on/off",
-		"Wildcards can be expanded via TAB. Ex: 's *.c<TAB>'",
+		"Wildcards can be expanded via TAB. E.g.: 's *.c<TAB>'",
 		"Try the help topics: 'help <TAB>'",
 		"List clifm commands, together with a brief description: 'cmd<TAB>'",
 		"List symlinks in the current directory: '=l<TAB>'. Try 'help file-filters' for more information",
 		"Use PropFields in the configuration file to customize fields in long view mode",
 		"Preview files in the current directory using the 'view' command (requires fzf)",
 		"Press Alt+- to launch the files previewer (requires fzf)",
-		"Interactively select files (requires fzf, fnf, or smenu). Ex: 's /dir/*<TAB>'",
+		"Interactively select files (requires fzf, fnf, or smenu). E.g.: 's /dir/*<TAB>'",
 		"Change files permissions/ownership using the 'pc' and 'oc' commands respectively",
-		"Set a custom shell to run external commands. Ex: 'CLIFM_SHELL=/bin/dash clifm'",
+		"Set a custom shell to run external commands. E.g.: 'CLIFM_SHELL=/bin/dash clifm'",
 		"Print all tips: 'tips'",
 		NULL};
 
@@ -439,7 +439,7 @@ print_trash_topic(void)
 static int
 run_help_topic(const char *topic)
 {
-	if (*topic == '-' && IS_HELP(topic)) {
+	if (IS_HELP(topic)) {
 		puts(HELP_USAGE);
 		return FUNC_SUCCESS;
 	}
