@@ -25,11 +25,11 @@
 #ifndef HELPERS_H
 #define HELPERS_H
 
-#define PROGRAM_NAME_UPPERCASE "CliFM"
+#define PROGRAM_NAME_UPPERCASE "Clifm"
 #define PROGRAM_NAME "clifm"
 #define PROGRAM_DESC "The command line file manager"
-#define VERSION "1.19"
-#define DATE "Jun 18, 2024"
+#define VERSION "1.20"
+#define DATE "Aug 16, 2024"
 #define AUTHOR "L. Abramovich"
 #define CONTACT "https://github.com/leo-arch/clifm"
 #define LICENSE "GPL2+"
@@ -89,6 +89,7 @@
 
 #ifdef __TINYC__
 # define __STDC_NO_VLA__ 1
+//# include <sys/cdefs.h>
 #endif /* __TINYC__ */
 
 #define _FILE_OFFSET_BITS 64 /* Support large files */
@@ -128,8 +129,9 @@
 #include <limits.h>
 #include <regex.h>
 #include <stdlib.h>
-#include <sys/stat.h> /* S_BLKSIZE */
-#include <fcntl.h> /* AT_* constants (like AT_FDCWD) */
+#include <sys/stat.h>  /* S_BLKSIZE */
+#include <sys/types.h> /* ssize_t */
+#include <fcntl.h>     /* AT_* constants (like AT_FDCWD) */
 /* Included here to test _DIRENT_HAVE_D_TYPE and DT macros. */
 #include <dirent.h>
 
@@ -146,8 +148,12 @@
 #ifdef CLIFM_LEGACY
 /* Replace functions not available before POSIX-1.2008. More precisely,
  * let's try to be POSIX-1.2001 compliant. This is still experimental:
- * a crash was reported due to x_scandir(), the scandir(3) replacement. */
+ * a crash was reported due to x_scandir(), the scandir(3) replacement
+ * (see https://github.com/leo-arch/clifm/discussions/254). */
 # include "compat.h"
+# define xrealpath old_realpath
+#else
+# define xrealpath realpath
 #endif /* CLIFM_LEGACY */
 
 #ifdef __sun
@@ -245,7 +251,6 @@ if (S_ISNWK(mode)) return 'n'; // HP/UX: network special file
 #if defined(__linux__)
 # include <linux/version.h>
 # include <linux/limits.h>
-# include <sys/types.h>
 # if !defined(__GLIBC__) || (__GLIBC__ > 2 \
 || (__GLIBC__ == 2 && __GLIBC_MINOR__ >= 9)) \
 && LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,27)
@@ -253,7 +258,6 @@ if (S_ISNWK(mode)) return 'n'; // HP/UX: network special file
 # endif /* GLIBC >= 2.9 && linux >= 2.6.27 */
 #elif defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__) \
 || defined(__DragonFly__) || defined(__APPLE__)
-# include <sys/types.h>
 # include <sys/time.h>
 # include <sys/param.h>
 # include <sys/syslimits.h>
@@ -271,7 +275,6 @@ if (S_ISNWK(mode)) return 'n'; // HP/UX: network special file
 #  define HAVE_KQUEUE
 # endif /* FreeBSD >= 4.1 */
 #elif defined(__sun) || defined(__CYGWIN__)
-# include <sys/types.h>
 # include <sys/time.h>
 #elif defined(__HAIKU__)
 # include <stdint.h> /* uint8_t */
@@ -302,6 +305,25 @@ if (S_ISNWK(mode)) return 'n'; // HP/UX: network special file
 # define BSD_KQUEUE
 #endif /* HAVE_KQUEUE && !USE_GENERIC_FS_MONITOR */
 
+/* Before MacOS X 10.10, renameat(2) is declared in sys/stdio.h */
+#if defined(__APPLE__) && !defined(CLIFM_LEGACY)
+# include <AvailabilityMacros.h>
+# if MAC_OS_X_VERSION_MIN_REQUIRED < 101000
+#  define MAC_OS_X_RENAMEAT_SYS_STDIO_H
+# endif /* MACOS_X < 10.10 */
+#endif /* __APPLE__ */
+
+/* GCC < 4.6 does not allow pragmas inside functions.
+ * See https://gcc.gnu.org/gcc-4.6/changes.html */
+#if defined(__GNUC__)
+# define GCC_VERSION (__GNUC__ * 10000       \
+                      + __GNUC_MINOR__ * 100 \
+                      + __GNUC_PATCHLEVEL__)
+# if GCC_VERSION >= 40600
+#  define GCC_ALLOWS_PRAGMA_IN_FUNC
+# endif /* GCC > 4.6 */
+#endif /* __GNUC__ */
+
 #include "strings.h"
 #include "settings.h"
 
@@ -349,9 +371,9 @@ if (S_ISNWK(mode)) return 'n'; // HP/UX: network special file
 
 #ifndef ARG_MAX
 # ifdef __linux__
-#  define ARG_MAX 128 * 1024
+#  define ARG_MAX (128 * 1024)
 # else
-#  define ARG_MAX 512 * 1024
+#  define ARG_MAX (512 * 1024)
 # endif /* __linux__ */
 #endif /* !ARG_MAX */
 
@@ -558,6 +580,9 @@ extern time_t curdir_mtime;
 #define PAGER_LONG  1
 #define PAGER_SHORT 2
 
+/* ClearScreen=internal: clear screen only if command is internal */
+#define CLEAR_INTERNAL_CMD_ONLY 2
+
 /* Used by log_msg() to know wether to tell prompt() to print messages or not */
 #define PRINT_PROMPT   1
 #define NOPRINT_PROMPT 0
@@ -566,8 +591,8 @@ extern time_t curdir_mtime;
 #define FALLBACK_PROMPT_OFFSET 6
 
 /* A few macros for the err function */
-#define ERR_NO_LOG   -1 /* err prints but doesn't log */
-#define ERR_NO_STORE -2 /* err prints and logs, but doesn't store the msg into the messages array */
+#define ERR_NO_LOG   (-1) /* err prints but doesn't log */
+#define ERR_NO_STORE (-2) /* err prints and logs, but doesn't store the msg into the messages array */
 
 /* Macros for xchdir (for setting term title or not) */
 #define SET_TITLE 1
@@ -596,22 +621,17 @@ extern time_t curdir_mtime;
 #define NOEXEC_MSG   "Permission denied"
 
 /* A few fixed colors */
-#define BOLD_RED   (conf.colorize == 1 ? "\x1b[1;31m" : "")
-#define BOLD_GREEN (conf.colorize == 1 ? "\x1b[1;32m" : "")
-#define REG_CYAN   (conf.colorize == 1 ? "\x1b[0;36m" : "")
-#define BOLD       ((xargs.no_bold != 1 && conf.colorize == 1) ? "\x1b[1m" : "")
+#define BOLD ((xargs.no_bold != 1 && conf.colorize == 1) ? "\x1b[1m" : "")
 /* NC: Reset color attributes to terminal defaults */
-#define NC         (conf.colorize == 1 ? "\x1b[0m" : "")
-
-/* Colors for the prompt: */
+#define NC   (conf.colorize == 1 ? "\x1b[0m" : "")
 /* \001 and \002 tell readline that color codes between them are
  * non-printing chars. This is specially useful for the prompt, i.e.,
  * when passing color codes to readline. */
 #define RL_NC "\001\x1b[0m\002"
 
-#define UNSET  -1
+#define UNSET  (-1)
 /* Some options take -1 as a valid value. So, let's use -2 to mark it unset */
-#define UNSET2 -2
+#define UNSET2 (-2)
 
 /* Macros for the cp and mv cmds */
 #define CP_CP            0 /* cp -iRp */
@@ -628,6 +648,11 @@ extern time_t curdir_mtime;
 #define MV_ADVMV_FORCE   3 /* advmv -g */
 #define MV_CMD_AVAILABLE 4
 
+/* Macros for LinkCreationMode */
+#define LNK_CREAT_REG 0 /* Like ln -s */
+#define LNK_CREAT_REL 1 /* Like ln -rs */
+#define LNK_CREAT_ABS 2 /* Create absolute target */
+
 /* Macros for listing_mode */
 #define VERTLIST 0 /* ls-like listing mode */
 #define HORLIST  1
@@ -704,18 +729,21 @@ extern time_t curdir_mtime;
  * null byte. */
 #define MAX_COLOR 46
 
-/* Macros to control file descriptors in exec functions */
+/* Macros to control file descriptors in exec functions. */
 #define E_NOFLAG   0
 #define E_NOSTDIN  (1 << 1)
 #define E_NOSTDOUT (1 << 2)
 #define E_NOSTDERR (1 << 3)
 #define E_MUTE     (E_NOSTDOUT | E_NOSTDERR)
 
+/* Amount of available suggestion strategies (a,b,c,e,f,h,j).
+ * 'b' is deprecated (kept only for compatibility with old versions) */
+#define SUG_STRATS 7
 
 #define FZF_INTERNAL_PREVIEWER 1 /* clifm itself */
 /* --preview is set either from FzfOpts in the color scheme file or from
  * FZF_DEFAULT_OPTS environment variable. */
-#define FZF_EXTERNAL_PREVIEWER 2
+#define FZF_EXTERNAL_PREVIEWER 3
 
 /* Macros for the backdir (bd) function */
 #define BD_TAB    1
@@ -837,7 +865,7 @@ extern time_t curdir_mtime;
 #define FUZZY_HISTORY     3
 #define FUZZY_ALGO_MAX    2 /* We have two fuzzy algorithms */
 
-#define JUMP_ENTRY_PURGED        -1
+#define JUMP_ENTRY_PURGED        (-1)
 #define JUMP_ENTRY_PERMANENT     2
 #define JUMP_ENTRY_PERMANENT_CHR '+'
 
@@ -857,6 +885,9 @@ extern time_t curdir_mtime;
 #define SIMPLE_STAT 1
 #define FULL_STAT   2
 
+/* Length to be added to a filename length if icons are enabled. */
+#define ICON_LEN 3
+
 /* Function macros */
 #define atoi xatoi /* xatoi is just a secure atoi */
 
@@ -866,8 +897,6 @@ extern time_t curdir_mtime;
 # define _(String) String
 #endif /* !_GETTEXT */
 
-//#define strlen(s) xstrlen(s)
-
 /* Log the message and print it to STDERR, but do not store it into the
  * messages array. */
 #define xerror(...) err(ERR_NO_STORE, NOPRINT_PROMPT, __VA_ARGS__)
@@ -904,6 +933,17 @@ extern time_t curdir_mtime;
 #define TOUPPER(c) (((c) >= 'a' && (c) <= 'z') ? ((c) - 'a' + 'A') : (c))
 #define TOLOWER(c) (((c) >= 'A' && (c) <= 'Z') ? ((c) - 'A' + 'a') : (c))
 
+/* A yottabyte takes 26 digits, 28 if we count the negative sign and the NULL
+ * terminator, so that 32 bytes is more than enough to represent any given
+ * integer as a string. */
+#define MAX_INT_STR 32
+/* Bytes required to transform an integer of type TYPE into a string,
+ * including the ending NULL char and the negative sign. */
+/* (CHAR_BIT is defined in limits.h). */
+/*#define INT_STR_SIZE(type) (((CHAR_BIT * sizeof(type) - 1) * 10 / 33) + 3) */
+/* INT_STR_SIZE() is much more accurate than MAX_INT_STR (which is just a
+ * big number) but not fully tested. */
+
 /* UINT_MAX is 4294967295 == 10 digits */
 #define DIGINUM(n) (((n) < 10) ? 1 \
 		: ((n) < 100)        ? 2   \
@@ -976,7 +1016,8 @@ extern time_t curdir_mtime;
 #define ERASE_TO_LEFT            fputs("\x1b[1K", stdout) /* EL1 */
 #define ERASE_TO_RIGHT_AND_BELOW fputs("\x1b[J", stdout)  /* ED0 */
 
-#define	SUGGEST_BAEJ(offset, color) printf("\x1b[%dC%s>\x1b[0m ", (offset), (color))
+#define	SUGGEST_BAEJ(offset, color) printf("\x1b[%dC%s%c\x1b[0m ", \
+	(offset), (color), BAEJ_SUG_POINTER)
 /* ######## */
 
 /* Sequences used by the pad_filename function (listing.c):
@@ -1026,7 +1067,7 @@ extern time_t curdir_mtime;
 #define _CTRL(n)  ((n) & 0x1f)
 // As defined by readline: set to one the eight bit in N
 #define _META(n)  ((n) | 0x80)
-// Ex: 'A' == 01000001
+// E.g.: 'A' == 01000001
 //     ('A' | 0x80) == 11000001 == 193 == Á
  */
 
@@ -1097,6 +1138,7 @@ struct config_t {
 	int highlight;
 	int icons;
 	int light_mode;
+	int link_creat_mode;
 	int list_dirs_first;
 	int listing_mode;
 	int log_cmds;
@@ -1119,6 +1161,7 @@ struct config_t {
 	int pager_once;
 	int pager_view;
 	int purge_jumpdb;
+	int print_dir_cmds;
 	int print_selfiles;
 	int private_ws_settings;
 	int prop_fields_gap;
@@ -1138,6 +1181,8 @@ struct config_t {
 	int splash_screen;
 	int suggest_filetype_color;
 	int suggestions;
+	int time_follows_sort;
+	int timestamp_mark;
 	int tips;
 	int trim_names;
 #ifndef _NO_TRASH
@@ -1145,9 +1190,9 @@ struct config_t {
 #else
 	int pad1; /* Keep the struct alignment */
 #endif /* !_NO_TRASH */
-	int unicode;
 	int warning_prompt;
 	int welcome_message;
+	int pad2;
 };
 
 extern struct config_t conf;
@@ -1673,6 +1718,13 @@ struct ext_mnt_t {
 extern struct ext_mnt_t *ext_mnt;
 #endif /* LINUX_FSINFO */
 
+/* State info for the PrintDirCmds function. */
+struct dircmds_t {
+	int first_cmd_in_dir; /* History index of first cmd exec'ed in the cur dir */
+	int last_cmd_ignored; /* Ignored cmd (via HistIgnore) */
+};
+extern struct dircmds_t dir_cmds;
+
 struct dir_info_t {
 	unsigned long long dirs;
 	unsigned long long files;
@@ -1839,7 +1891,6 @@ extern size_t
 	ext_colors_n,
 	jump_n,
 	kbinds_n,
-	longest,
 	msgs_n,
 	P_tmpdir_len,
 	path_n,
@@ -1944,7 +1995,8 @@ extern regex_t regex_dirhist; /* Directory history */
 extern char **environ;
 
 /* A buffer to store file names to be displayed (wide string) */
-extern char name_buf[(NAME_MAX + 1) * sizeof(wchar_t)];
+#define NAME_BUF_SIZE (NAME_MAX + 1)
+extern char name_buf[NAME_BUF_SIZE * sizeof(wchar_t)];
 
 /* To store all the 39 color variables we use, with 46 bytes each, we need
  * a total of 1,8Kb. It's not much but it could be less if we'd use
@@ -1983,7 +2035,6 @@ extern char
 	uf_c[MAX_COLOR], /* Non-'stat'able file */
 
 	/* Interface */
-	bm_c[MAX_COLOR], /* Bookmarked directory */
 	df_c[MAX_COLOR], /* Default color */
 	dl_c[MAX_COLOR], /* Dividing line */
 	el_c[MAX_COLOR], /* ELN color */
@@ -2026,12 +2077,14 @@ extern char
 	db_c[MAX_COLOR],  /* File allocated blocks */
 	dd_c[MAX_COLOR],  /* Date (fixed color: no shading) */
 	de_c[MAX_COLOR],  /* Inode number */
-	dg_c[MAX_COLOR],  /* UID, GID */
+	dg_c[MAX_COLOR],  /* Group ID */
 	dk_c[MAX_COLOR],  /* Number of links */
 	dn_c[MAX_COLOR],  /* dash (none) */
 	do_c[MAX_COLOR],  /* Octal perms */
 	dp_c[MAX_COLOR],  /* Special files (SUID, SGID, etc) */
 	dr_c[MAX_COLOR],  /* Read */
+	dt_c[MAX_COLOR],  /* Timestamp mark */
+	du_c[MAX_COLOR],  /* User ID */
 	dw_c[MAX_COLOR],  /* Write */
 	dxd_c[MAX_COLOR], /* Execute (dirs) */
 	dxr_c[MAX_COLOR], /* Execute (reg files) */
