@@ -171,8 +171,11 @@ log_cmd(void)
 
 /* Write _MSG into the log file: [date] _MSG */
 static void
-write_msg_into_logfile(const char *_msg)
+write_msg_into_logfile(const char *msg_str)
 {
+	if (!msg_str || !*msg_str || !msgs_log_file || !*msgs_log_file)
+		return;
+
 	FILE *fp = open_fappend(msgs_log_file);
 	if (!fp) {
 		/* Do not log this error: We might enter into an infinite loop
@@ -185,7 +188,7 @@ write_msg_into_logfile(const char *_msg)
 	}
 
 	char *date = get_date();
-	fprintf(fp, "[%s] %s", date ? date : "unknown", _msg);
+	fprintf(fp, "[%s] %s", date ? date : "unknown", msg_str);
 	fclose(fp);
 	free(date);
 }
@@ -205,17 +208,17 @@ send_desktop_notification(char *msg)
 #if defined(__HAIKU__)
 	case ERROR: snprintf(type, sizeof(type), "error"); break;
 	case WARNING: snprintf(type, sizeof(type), "important"); break;
-	case NOTICE: snprintf(type, sizeof(type), "information"); break;
+	case NOTICE: /* fallthrough */
 	default: snprintf(type, sizeof(type), "information"); break;
 #elif defined(__APPLE__)
 	case ERROR: snprintf(type, sizeof(type), "Error"); break;
 	case WARNING: snprintf(type, sizeof(type), "Warning"); break;
-	case NOTICE: snprintf(type, sizeof(type), "Notice"); break;
+	case NOTICE: /* fallthrough */
 	default: snprintf(type, sizeof(type), "Notice"); break;
 #else
 	case ERROR: snprintf(type, sizeof(type), "critical"); break;
 	case WARNING: snprintf(type, sizeof(type), "normal"); break;
-	case NOTICE: snprintf(type, sizeof(type), "low"); break;
+	case NOTICE: /* fallthrough */
 	default: snprintf(type, sizeof(type), "low"); break;
 #endif /* __HAIKU__ */
 	}
@@ -289,37 +292,37 @@ send_desktop_notification(char *msg)
  * file as follows: "m:[date] msg", where 'date' is YYYY-MM-DDTHH:MM:SS.
  * */
 void
-log_msg(char *_msg, const int print_prompt, const int logme,
+log_msg(char *msg_str, const int print_prompt, const int logme,
 	const int add_to_msgs_list)
 {
-	if (!_msg)
+	if (!msg_str)
 		return;
 
-	const size_t msg_len = strlen(_msg);
+	const size_t msg_len = strlen(msg_str);
 	if (msg_len == 0)
 		return;
 
 	if (add_to_msgs_list == 1) {
 		msgs_n++;
 		messages = xnrealloc(messages, (size_t)(msgs_n + 1), sizeof(char *));
-		messages[msgs_n - 1] = savestring(_msg, msg_len);
+		messages[msgs_n - 1] = savestring(msg_str, msg_len);
 		messages[msgs_n] = (char *)NULL;
 	}
 
 	if (print_prompt == 1) {
 		if (conf.desktop_notifications == 1 && logme != 0)
-			send_desktop_notification(_msg);
+			send_desktop_notification(msg_str);
 		else
 			print_msg = 1;
 	} else {
-		fputs(_msg, stderr);
+		fputs(msg_str, stderr);
 	}
 
 	if (xargs.stealth_mode == 1 || config_ok == 0 || !msgs_log_file
 	|| !*msgs_log_file || logme != 1 || conf.log_msgs == 0)
 		return;
 
-	write_msg_into_logfile(_msg);
+	write_msg_into_logfile(msg_str);
 }
 
 static void
@@ -352,7 +355,7 @@ add_to_dirhist(const char *dir_path)
 		&& strcmp(dir_path, old_pwd[dirhist_total_index - 1]) == 0)
 			return;
 
-		old_pwd = xnrealloc(old_pwd, (size_t)(dirhist_total_index + 2),
+		old_pwd = xnrealloc(old_pwd, (size_t)dirhist_total_index + 2,
 			sizeof(char *));
 
 		dirhist_cur_index = dirhist_total_index;
@@ -366,7 +369,7 @@ add_to_dirhist(const char *dir_path)
 
 	/* If not at the end of dirhist, add previous AND new entry */
 	else {
-		old_pwd = xnrealloc(old_pwd, (size_t)(dirhist_total_index + 3),
+		old_pwd = xnrealloc(old_pwd, (size_t)dirhist_total_index + 3,
 			sizeof(char *));
 
 		old_pwd[dirhist_total_index] = savestring(
@@ -665,10 +668,14 @@ record_cmd(char *input)
 	if (!input || !*input)
 		return 0;
 
+	dir_cmds.last_cmd_ignored = 0;
+
 	/* Ignore entries matching HistIgnore */
 	if (conf.histignore_regex && *conf.histignore_regex
-	&& regexec(&regex_hist, input, 0, NULL, 0) == FUNC_SUCCESS)
+	&& regexec(&regex_hist, input, 0, NULL, 0) == FUNC_SUCCESS) {
+		dir_cmds.last_cmd_ignored = 1;
 		return 0;
+	}
 
 	/* Consequtively equal commands in history */
 	if (history && current_hist_n > 0 && history[current_hist_n - 1].cmd
