@@ -41,7 +41,7 @@ int  clear_logs(const int flag);
 int  get_history(void);
 int  history_function(char **args);
 int  log_cmd(void);
-void log_msg(char *_msg, const int print_prompt, const int logme,
+void log_msg(char *msg_str, const int print_prompt, const int logme,
 	const int add_to_msgs_list);
 int  print_logs(const int flag);
 int  record_cmd(char *input);
