@@ -213,6 +213,7 @@ init_conf_struct(void)
 	conf.icons = 0;
 #endif /* !_NO_ICONS */
 	conf.light_mode = UNSET;
+	conf.link_creat_mode = DEF_LINK_CREATION_MODE;
 	conf.list_dirs_first = UNSET;
 	conf.listing_mode = UNSET;
 	conf.log_cmds = UNSET;
@@ -234,6 +235,7 @@ init_conf_struct(void)
 	conf.pager = UNSET;
 	conf.pager_once = 0;
 	conf.pager_view = UNSET;
+	conf.print_dir_cmds = UNSET;
 	conf.print_selfiles = UNSET;
 	conf.private_ws_settings = UNSET;
 	conf.prop_fields_gap = UNSET;
@@ -254,12 +256,13 @@ init_conf_struct(void)
 	conf.splash_screen = UNSET;
 	conf.suggest_filetype_color = UNSET;
 	conf.suggestions = UNSET;
+	conf.time_follows_sort = DEF_TIME_FOLLOWS_SORT;
+	conf.timestamp_mark = DEF_TIMESTAMP_MARK;
 	conf.tips = UNSET;
 	conf.trim_names = UNSET;
 #ifndef _NO_TRASH
 	conf.tr_as_rm = UNSET;
 #endif /* !_NO_TRASH */
-	conf.unicode = DEF_UNICODE;
 	conf.warning_prompt = UNSET;
 	conf.welcome_message = UNSET;
 
@@ -310,7 +313,7 @@ get_sysusers(void)
 	n = 0;
 	while ((p = getpwent())) {
 #ifndef __HAIKU__
-		/* Some systems (BSD) may have multiple UIDs 0 (ex: "root" and "toor").
+		/* Some systems (BSD) may have multiple UIDs 0 (e.g.: "root" and "toor").
 		 * This is known as a root alias. Let's always use "root" for UID 0
 		 * (this is what stat(1), ls(1), and most file managers do). */
 		const char *name = p->pw_uid == 0 ? "root" : p->pw_name;
@@ -452,7 +455,7 @@ get_sys_shell(void)
 
 	char tmp[PATH_MAX + 1];
 	*tmp = '\0';
-	char *ret = realpath(user.shell, tmp);
+	char *ret = xrealpath(user.shell, tmp);
 	if (!ret || !*tmp)
 		return SHELL_POSIX;
 
@@ -688,21 +691,6 @@ get_user_groups(const char *name, const gid_t gid, int *ngroups)
 	return g;
 }
 
-/* Return the value of the environment variable S, allocated via malloc if
- * ALLOC is 1, or just a pointer to the value if 0 */
-char *
-xgetenv(const char *s, const int alloc)
-{
-	if (!s || !*s)
-		return (char *)NULL;
-
-	char *p = getenv(s);
-	if (p && *p)
-		return alloc == 1 ? strdup(p) : p;
-
-	return (char *)NULL;
-}
-
 /* The user specified a custom shell via the CLIFM_SHELL environment variable.
  * Since this will be used to run shell commands, it's better to make sure
  * we have a valid shell, that is, one of the shells specified in
@@ -739,6 +727,32 @@ check_etc_shells(const char *file, char *shells_file, int *tmp_errno)
 	return ret;
 }
 
+/* Make sure clifm is not used for $SHELL. This will brake programs using
+ * SHELL to run shell commands. For example, "fzf --preview". */
+static void
+validate_shell(void)
+{
+	char *p = xgetenv("SHELL", 0);
+	if (!p)
+		return;
+
+#ifdef _PATH_BSHELL
+	char *def_shell = _PATH_BSHELL;
+#else
+	char *def_shell = "/bin/sh";
+#endif /* _PATH_BSHELL */
+
+	char *q = strrchr(p, '/');
+	if ((!q && strcmp(p, PROGRAM_NAME) == 0)
+	|| (q && q[1] && strcmp(q + 1, PROGRAM_NAME) == 0)) {
+		err('w', PRINT_PROMPT, _("%s: '%s' is not a shell. "
+			"Setting SHELL to '%s'.\n"), PROGRAM_NAME, p,
+			def_shell);
+		unsetenv("SHELL");
+		setenv("SHELL", def_shell, 1);
+	}
+}
+
 static void
 validate_custom_shell(char **file)
 {
@@ -755,7 +769,7 @@ validate_custom_shell(char **file)
 	char *def_shell = _PATH_BSHELL;
 #else
 	char *def_shell = "/bin/sh";
-#endif
+#endif /* _PATH_BSHELL */
 
 	if (*file && check_etc_shells(*file, shells_file,
 	&tmp_errno) == FUNC_SUCCESS)
@@ -788,7 +802,7 @@ get_user_data_env(void)
 	char *t = sec_env == 0 ? xgetenv("HOME", 0) : (char *)NULL;
 
 	if (t) {
-		char *p = realpath(t, NULL);
+		char *p = xrealpath(t, NULL);
 		char *h = p ? p : t;
 		tmp_user.home = savestring(h, strlen(h));
 		free(p);
@@ -823,6 +837,8 @@ get_user_data_env(void)
 	if (p && t == p) /* CLIFM_SHELL */
 		validate_custom_shell(&tmp_user.shell);
 
+	validate_shell();
+
 	return tmp_user;
 }
 
@@ -876,10 +892,6 @@ get_user_data(void)
 		homedir = pw->pw_dir;
 	}
 
-	tmp_user.shell_basename = (char *)NULL;
-	if (is_custom_shell == 1)
-		validate_custom_shell(&tmp_user.shell);
-
 	if (homedir == pw->pw_dir && (!homedir
 	|| stat(homedir, &a) == -1 || !S_ISDIR(a.st_mode))) {
 		xerror(_("%s: '%s': Invalid home directory in the password "
@@ -897,7 +909,7 @@ get_user_data(void)
 	/* Sometimes (FreeBSD for example) the home directory, as returned by the
 	 * passwd struct, is a symlink, in which case we want to resolve it.
 	 * See https://lists.freebsd.org/pipermail/freebsd-arm/2016-July/014404.html */
-	char *r = realpath(homedir, NULL);
+	char *r = xrealpath(homedir, NULL);
 	if (r) {
 		tmp_user.home_len = strlen(r);
 		tmp_user.home = savestring(r, tmp_user.home_len);
@@ -907,6 +919,12 @@ get_user_data(void)
 		tmp_user.home = savestring(homedir, tmp_user.home_len);
 	}
 
+	tmp_user.shell_basename = (char *)NULL;
+	if (is_custom_shell == 1)
+		validate_custom_shell(&tmp_user.shell);
+
+	validate_shell();
+
 	return tmp_user;
 }
 
@@ -1632,11 +1650,11 @@ load_prompts(void)
 
 		if (*line == 'N' && strncmp(line, "Notifications=", 14) == 0) {
 			if (*ret == 't' && strcmp(ret, "true") == 0)
-				prompts[n].notifications = 1;
+				prompts[n].notifications = 1; /* NOLINT */
 			else if (*ret == 'f' && strcmp(ret, "false") == 0)
-				prompts[n].notifications = 0;
+				prompts[n].notifications = 0; /* NOLINT */
 			else
-				prompts[n].notifications = DEF_PROMPT_NOTIF;
+				prompts[n].notifications = DEF_PROMPT_NOTIF; /* NOLINT */
 			continue;
 		}
 
@@ -1653,11 +1671,11 @@ load_prompts(void)
 
 		if (strncmp(line, "EnableWarningPrompt=", 20) == 0) {
 			if (*ret == 't' && strcmp(ret, "true") == 0)
-				prompts[n].warning_prompt_enabled = 1;
+				prompts[n].warning_prompt_enabled = 1; /* NOLINT */
 			else if (*ret == 'f' && strcmp(ret, "false") == 0)
-				prompts[n].warning_prompt_enabled = 0;
+				prompts[n].warning_prompt_enabled = 0; /* NOLINT */
 			else
-				prompts[n].warning_prompt_enabled = DEF_WARNING_PROMPT;
+				prompts[n].warning_prompt_enabled = DEF_WARNING_PROMPT; /* NOLINT */
 			continue;
 		}
 
@@ -1870,14 +1888,39 @@ restore_shell(void)
 		TCSANOW, (const struct termios *)&orig_term_attrs);
 }
 
+/* Store device and inode number of each selected file to identify them
+ * later and mark them as selected in the files list. */
+static int
+set_sel_devino(void)
+{
+	free(sel_devino);
+	sel_devino = xnmalloc(sel_n + 1, sizeof(struct devino_t));
+
+	size_t i;
+	struct stat a;
+	for (i = 0; i < sel_n; i++) {
+		const char *name = sel_elements[i].name;
+		if (fstatat(XAT_FDCWD, name, &a, AT_SYMLINK_NOFOLLOW) == -1)
+			continue;
+
+		sel_devino[i].ino = a.st_ino;
+		sel_devino[i].dev = a.st_dev;
+	}
+
+	return FUNC_SUCCESS;
+}
+
 /* Get current entries in the Selection Box, if any. */
 int
 get_sel_files(void)
 {
+	if (xargs.stealth_mode == 1 && sel_n > 0)
+		return set_sel_devino();
+
 	if (selfile_ok == 0 || config_ok == 0 || !sel_file)
 		return FUNC_FAILURE;
 
-	size_t selnbk = sel_n;
+	const size_t selnbk = sel_n;
 	/* First, clear the sel array, in case it was already used. */
 	if (sel_n > 0) {
 		int i = (int)sel_n;
@@ -1918,24 +1961,22 @@ get_sel_files(void)
 		if (fstatat(XAT_FDCWD, line, &a, AT_SYMLINK_NOFOLLOW) == -1)
 			continue;
 
-		sel_elements = xnrealloc(sel_elements,
-			sel_n + 2, sizeof(struct sel_t));
+		sel_elements = xnrealloc(sel_elements, sel_n + 2, sizeof(struct sel_t));
 		sel_elements[sel_n].name = savestring(line, len);
 		sel_elements[sel_n].size = (off_t)UNSET;
-		/* Store device and inode number to identify later selected files
-		 * and mark them in the files list. */
-		sel_devino = xnrealloc(sel_devino, sel_n + 1, sizeof(struct devino_t));
-		sel_devino[sel_n].ino = a.st_ino;
-		sel_devino[sel_n].dev = a.st_dev;
 		sel_n++;
 		sel_elements[sel_n].name = (char *)NULL;
 		sel_elements[sel_n].size = (off_t)UNSET;
 	}
 
 	fclose(fp);
+
+	if (sel_n > 0)
+		set_sel_devino();
+
 	/* If previous and current amount of sel files don't match (mostly
 	 * because some selected files were removed), recreate the selections
-	 * file to reflect current state. */
+	 * file to reflect the current state. */
 	if (selnbk != sel_n)
 		save_sel();
 
@@ -1947,6 +1988,10 @@ get_sel_files(void)
 size_t
 get_cdpath(void)
 {
+	if (xargs.secure_env == 1 || xargs.secure_env_full == 1
+	|| xargs.secure_cmds == 1)
+		return 0;
+
 	char *p = getenv("CDPATH");
 	if (!p || !*p)
 		return 0;
@@ -2263,7 +2308,7 @@ skip_this_path(char *name)
 	if (!S_ISLNK(a.st_mode))
 		return 0;
 
-	char *rpath = realpath(name, NULL);
+	char *rpath = xrealpath(name, NULL);
 	if (!rpath)
 		return 1;
 
@@ -2293,10 +2338,6 @@ get_path_programs(void)
 	struct dirent ***commands_bin = (struct dirent ***)NULL;
 
 	if (conf.ext_cmd_ok == 1) {
-		/* NOTE: xchdir() is only required by skip_nonexec() */
-		char tmp[PATH_MAX + 1] = "";
-		char *cwd = get_cwd(tmp, sizeof(tmp), 0);
-
 		commands_bin = xnmalloc(path_n, sizeof(struct dirent));
 		cmd_n = xnmalloc(path_n, sizeof(int));
 
@@ -2306,16 +2347,11 @@ get_path_programs(void)
 			commands_bin[i] = (struct dirent **)NULL;
 
 			if (!paths[i].path || !*paths[i].path
-			|| skip_this_path(paths[i].path) == 1
-			|| xchdir(paths[i].path, NO_TITLE) == -1)
+			|| skip_this_path(paths[i].path) == 1)
 				continue;
 
-			cmd_n[i] = scandir(paths[i].path, &commands_bin[i],
-#ifdef __CYGWIN__
-					NULL, xalphasort);
-#else
-					conf.light_mode == 1 ? NULL : skip_nonexec, xalphasort);
-#endif /* __CYGWIN__ */
+			cmd_n[i] = scandir(paths[i].path, &commands_bin[i], NULL, xalphasort);
+
 			/* If paths[i] directory is empty, 2 is returned. If it does not
 			 * exist, scandir returns -1.
 			 * Fedora, for example, adds HOME/bin and HOME/.local/bin to
@@ -2323,8 +2359,6 @@ get_path_programs(void)
 			if (cmd_n[i] > 2)
 				total_cmd += cmd_n[i] - 2;
 		}
-
-		xchdir(cwd, NO_TITLE);
 	}
 
 	/* Add internal commands */
@@ -2623,7 +2657,7 @@ check_time_str(void)
 
 	if (conf.relative_time == 1) {
 	/* +1 = extra space to avoid hitting the screen right edge in long view. */
-		prop_fields.len += (7 + 1);
+		prop_fields.len += (7 + 1) + (conf.timestamp_mark == 1 ? 1 : 0);
 		xstrsncpy(invalid_time_str, " -     ", sizeof(invalid_time_str));
 		return;
 	}
@@ -2648,7 +2682,7 @@ check_time_str(void)
 
 	/* Append the time string length to the properties total length, so that
 	 * we can better calculate how much space left we have to print file names. */
-	prop_fields.len += (int)(l + 1);
+	prop_fields.len += (int)(l + 1) + (conf.timestamp_mark == 1 ? 1 : 0);
 }
 #pragma GCC diagnostic pop
 
@@ -3109,9 +3143,6 @@ check_options(void)
 			conf.autols = xargs.autols;
 	}
 
-	if (conf.unicode == UNSET)
-		conf.unicode = DEF_UNICODE;
-
 	if (conf.max_path == UNSET) {
 		if (xargs.max_path == UNSET)
 			conf.max_path = DEF_MAX_PATH;
