@@ -47,6 +47,10 @@ typedef char *rl_cpvfunc_t;
 
 #include <errno.h>
 
+#if defined(MAC_OS_X_RENAMEAT_SYS_STDIO_H)
+# include <sys/stdio.h> /* renameat(2) */
+#endif /* MAC_OS_X_RENAMEAT_SYS_STDIO_H */
+
 #include "aux.h"
 #include "config.h"
 #include "exec.h"
@@ -199,7 +203,7 @@ kbinds_function(char **args)
 
 	if (!args[1] || strcmp(args[1], "list") == 0) {
 		if (kbinds_n == 0) {
-			printf(_("%s: kb: No keybindings defined\n"), PROGRAM_NAME);
+			puts(_("kb: No keybindings defined\n"));
 			return FUNC_SUCCESS;
 		}
 		size_t i;
@@ -1462,7 +1466,7 @@ rl_quit(int count, int key)
 	if (kbind_busy == 1)
 		return FUNC_SUCCESS;
 
-	conf.cd_on_quit = 0;
+//	conf.cd_on_quit = 0;
 	puts("\n");
 
 	/* Reset terminal attributes before exiting. */
@@ -1550,7 +1554,7 @@ rl_profile_next(int count, int key)
 	next_prof = cur_prof + 1;
 	total_profs--;
 
-	if (next_prof > (int)total_profs || !profile_names[next_prof]
+	if (next_prof > total_profs || !profile_names[next_prof]
 	|| total_profs <= 1)
 		next_prof = 0;
 
@@ -1775,7 +1779,7 @@ run_plugin(const int num)
 	if (rl_line_buffer && *rl_line_buffer)
 		setenv("CLIFM_LINE", rl_line_buffer, 1);
 
-	char cmd[32 + 7];
+	char cmd[MAX_INT_STR + 7];
 	snprintf(cmd, sizeof(cmd), "plugin%d", num);
 	int ret = run_kb_cmd(cmd);
 
@@ -2120,7 +2124,7 @@ rl_toggle_virtualdir_full_paths(int count, int key)
 
 	filesn_t i = files;
 	while (--i >= 0) {
-		char *rp = realpath(file_info[i].name, NULL);
+		char *rp = xrealpath(file_info[i].name, NULL);
 		if (!rp) continue;
 
 		char *p = (char *)NULL;
