@@ -3,7 +3,7 @@
 /*
  * This file is part of CliFM
  *
- * Copyright (C) 2016-2023, L. Abramovich <leo.clifm@outlook.com>
+ * Copyright (C) 2016-2024, L. Abramovich <leo.clifm@outlook.com>
  * All rights reserved.
 
  * CliFM is free software; you can redistribute it and/or modify
@@ -25,18 +25,23 @@
 #ifndef KEYBINDS_H
 #define KEYBINDS_H
 
+/* Let's use these word delimiters to print first suggested word
+ * and to delete last typed word */
+#define WORD_DELIMITERS " /.-_=,:;@+*&$#<>%~|({[]})¿?¡!"
+
 __BEGIN_DECLS
 
 /*void add_func_to_rl(void); */
-int  keybind_exec_cmd(char *);
-int  kbinds_function(char **);
+int  keybind_exec_cmd(char *str);
+int  kbinds_function(char **args);
 int  load_keybinds(void);
 void readline_kbinds(void);
-int  rl_quit(int, int);
-int  rl_toggle_dirs_first(int, int);
-int  rl_toggle_long_view(int, int);
-int  rl_toggle_hidden_files(int, int);
-int  rl_toggle_light_mode(int, int);
+int  rl_quit(int count, int key);
+int  rl_toggle_dirs_first(int count, int key);
+int  rl_toggle_hidden_files(int count, int key);
+int  rl_toggle_light_mode(int count, int key);
+int  rl_toggle_long_view(int count, int key);
+int  rl_toggle_max_filename_len(int count, int key);
 
 __END_DECLS
 
