@@ -112,13 +112,13 @@
 
 #define ENTRY_N 64
 
-/* Amount of digits of the files counter of the longest directory */
-static size_t longest_fc = 0;
-static int pager_bk = 0;
-static int dir_out = 0;
-static int pager_quit = 0;
-static int pager_help = 0;
-static int long_view_bk = UNSET;
+/* Information about the longest file name in the curent list of files. */
+struct longest_t {
+	size_t fc_len;   /* Length of the files counter (if a directory). */
+	size_t name_len; /* Length of the longest name. */
+};
+
+static struct longest_t longest;
 
 struct checks_t {
 	int autocmd_files;
@@ -131,24 +131,20 @@ struct checks_t {
 	int id_names;
 	int lnk_char;
 	int min_name_trim;
+	int scanning;
+	int time_follows_sort;
 	int xattr;
 };
 
 static struct checks_t checks;
 
-/* Struct to store information about trimmed file names. Used only when
- * Unicode is disabled */
-struct trim_t {
-	int state;
-	int a; /* trimmed char */
-	int b; /* char next to trimmed char */
-	int pad;
-	size_t len; /* Lenght of file name before trimming */
-};
+static int pager_bk = 0;
+static int dir_out = 0;
+static int pager_quit = 0;
+static int pager_help = 0;
+static int long_view_bk = UNSET;
 
-static struct trim_t trim;
-
-/* Struct to store information about file names to be trimmed (Unicode) */
+/* Struct to store information about trimmed file names. */
 struct wtrim_t {
 	char *wname; /* Address to store file name with replaced control chars */
 	int type; /* Truncation type: with or without file extension. */
@@ -191,6 +187,10 @@ init_checks_struct(void)
 		&& conf.icons == 0 && conf.light_mode == 0);
 	checks.min_name_trim = (conf.long_view == 1 && conf.max_name_len != UNSET
 		&& conf.min_name_trim > conf.max_name_len);
+	checks.scanning = (xargs.disk_usage_analyzer == 1
+		|| (conf.long_view == 1 && conf.full_dir_size == 1));
+	checks.time_follows_sort = (conf.time_follows_sort == 1
+		&& conf.sort >= SATIME && conf.sort <= SMTIME);
 	checks.xattr = (conf.long_view == 1 && prop_fields.xattr == 1);
 }
 
@@ -255,20 +255,20 @@ swap_ent(const size_t id1, const size_t id2)
  * wc_xstrlen(). This gives us a little performance improvement: 3% faster
  * over 100,000 files. */
 static uint8_t
-is_utf8_name(const char *restrict name, size_t *restrict bytes)
+is_utf8_name(const char *name, size_t *bytes)
 {
 	uint8_t is_utf8 = 0;
 	const char *start = name;
 
 	while (*name) {
 #if !defined(CHAR_MIN) || CHAR_MIN >= 0 /* char is unsigned (PowerPC/ARM) */
-		if (*name >= 0xC0 || *name < ' ')
+		if (*name >= 0xC0 || *name < ' ' || *name == 127)
 #else /* char is signed (X86) */
 		/* If UTF-8 char, the first byte is >= 0xC0, whose decimal
 		 * value is 192, which is bigger than CHAR_MAX if char is signed,
 		 * becoming thus a negative value. In this way, the above two-steps
 		 * check can be written using a single comparison. */
-		if (*name < ' ')
+		if (*name < ' ' || *name == 127)
 #endif /* CHAR_MIN >= 0 */
 			is_utf8 = 1;
 
@@ -582,6 +582,17 @@ set_pager_view(void)
 	}
 }
 
+static void
+print_dir_cmds(void)
+{
+	if (!history || dir_cmds.first_cmd_in_dir > (int)current_hist_n)
+		return;
+
+	int i = dir_cmds.first_cmd_in_dir - (dir_cmds.first_cmd_in_dir > 0 ? 1 : 0);
+	for (; history[i].cmd; i++)
+		printf("%s>%s %s\n", bk_c, df_c, history[i].cmd);
+}
+
 static int
 post_listing(DIR *dir, const int reset_pager, const filesn_t excluded_files)
 {
@@ -594,6 +605,9 @@ post_listing(DIR *dir, const int reset_pager, const filesn_t excluded_files)
  * we have changed the current directory (last command) or not. */
 //	setenv("CLIFM_CHPWD", dir_changed == 1 ? "1" : "0", 1);
 
+	if (dir_changed == 1)
+		dir_cmds.first_cmd_in_dir = UNSET;
+
 	dir_changed = 0;
 
 	if (xargs.list_and_quit == 1)
@@ -641,6 +655,9 @@ post_listing(DIR *dir, const int reset_pager, const filesn_t excluded_files)
 		print_reload_msg(_("Showing %jd/%jd files\n"),
 			(intmax_t)files, (intmax_t)(files + excluded_files));
 
+	if (conf.print_dir_cmds == 1 && dir_cmds.first_cmd_in_dir != UNSET)
+		print_dir_cmds();
+
 	return FUNC_SUCCESS;
 }
 
@@ -653,10 +670,10 @@ run_pager(const int columns_n, int *reset_pager, filesn_t *i, size_t *counter)
 	fputs(PAGER_LABEL, stdout);
 
 	switch (xgetchar()) {
-
 	/* Advance one line at a time */
 	case 66: /* fallthrough */ /* Down arrow */
-	case 10: /* fallthrough */ /* Enter */
+	case 10: /* fallthrough */ /* Enter (LF) */
+	case 13: /* fallthrough */ /* Enter (CR) */
 	case ' ':
 		break;
 
@@ -710,7 +727,8 @@ run_pager(const int columns_n, int *reset_pager, filesn_t *i, size_t *counter)
 		pager_bk = conf.pager; conf.pager = 0; *reset_pager = 1;
 		putchar('\r');
 		ERASE_TO_RIGHT;
-		if (conf.long_view == 0)
+		if (conf.long_view == 0 && conf.columned == 1
+		&& conf.max_name_len != UNSET)
 			MOVE_CURSOR_UP(1);
 		return (-3);
 
@@ -825,21 +843,21 @@ get_longest_filename(const filesn_t n, const size_t pad)
 			}
 		}
 
-		if (total_len > longest) {
+		if (total_len > longest.name_len) {
 			longest_index = i;
 			if (conf.listing_mode == VERTLIST || max_files == UNSET
 			|| i < c_max_files)
-				longest = total_len;
+				longest.name_len = total_len;
 		}
 	}
 
 	if (conf.long_view == 0 && conf.icons == 1 && conf.columned == 1)
-		longest += 3;
+		longest.name_len += ICON_LEN;
 
-	/* longest_fc stores the amount of digits taken by the files counter of
+	/* LONGEST.FC_LEN stores the amount of digits taken by the files counter of
 	 * the longest file name, provided it is a directory.
-	 * We use this to trim file names up to MAX_NAME_LEN + LONGEST_FC, so
-	 * that we can make use of the space used by the files counter.
+	 * We use this to trim file names up to MAX_NAME_LEN + LONGEST.FC_LEN, so
+	 * that we can make use of the space taken by the files counter.
 	 * Example:
 	 *    longest_dirname/13
 	 *    very_long_file_na~
@@ -848,7 +866,7 @@ get_longest_filename(const filesn_t n, const size_t pad)
 	 *    very_long_file_~
 	 * */
 
-	longest_fc = 0;
+	longest.fc_len = 0;
 	if (conf.max_name_len != UNSET && longest_index != -1
 	&& file_info[longest_index].dir == 1
 	&& file_info[longest_index].filesn > 0 && conf.files_counter == 1) {
@@ -857,39 +875,39 @@ get_longest_filename(const filesn_t n, const size_t pad)
 		 * between the trimmed file name and the next column is too
 		 * tight (only one). By not adding it we get an extra space
 		 * to relax a bit the space between columns. */
-/*		longest_fc = DIGINUM(file_info[longest_index].filesn) + 1; */
-		longest_fc = DIGINUM(file_info[longest_index].filesn);
-		const size_t t = pad + c_max_name_len + 1 + longest_fc;
-		if (t > longest)
-			longest_fc -= t - longest;
-		if ((int)longest_fc < 0)
-			longest_fc = 0;
+/*		longest.fc_len = DIGINUM(file_info[longest_index].filesn) + 1; */
+		longest.fc_len = DIGINUM(file_info[longest_index].filesn);
+		const size_t t = pad + c_max_name_len + 1 + longest.fc_len;
+		if (t > longest.name_len)
+			longest.fc_len -= t - longest.name_len;
+		if ((int)longest.fc_len < 0)
+			longest.fc_len = 0;
 	}
 }
 
 /* Set a few extra properties needed for long view mode */
 static void
-set_long_attribs(const filesn_t n, const struct stat *attr)
+set_long_attribs(const filesn_t n, const struct stat *a)
 {
 	if (conf.light_mode == 1) {
 		switch (prop_fields.time) {
-		case PROP_TIME_ACCESS: file_info[n].ltime = attr->st_atime; break;
-		case PROP_TIME_CHANGE: file_info[n].ltime = attr->st_ctime; break;
-		case PROP_TIME_MOD: file_info[n].ltime = attr->st_mtime; break;
+		case PROP_TIME_ACCESS: file_info[n].ltime = a->st_atime; break;
+		case PROP_TIME_CHANGE: file_info[n].ltime = a->st_ctime; break;
+		case PROP_TIME_MOD: file_info[n].ltime = a->st_mtime; break; /* NOLINT */
 		case PROP_TIME_BIRTH:
 #ifdef ST_BTIME_LIGHT
-			file_info[n].ltime = attr->ST_BTIME.tv_sec; break;
+			file_info[n].ltime = a->ST_BTIME.tv_sec; break;
 #else
-			file_info[n].ltime = attr->st_mtime; break;
+			file_info[n].ltime = a->st_mtime; break;
 #endif /* ST_BTIME_LIGHT */
-		default: file_info[n].ltime = attr->st_mtime; break;
+		default: file_info[n].ltime = a->st_mtime; break; /* NOLINT */
 		}
 
-		file_info[n].blocks = attr->st_blocks;
-		file_info[n].linkn = attr->st_nlink;
-		file_info[n].mode = attr->st_mode;
-		file_info[n].uid = attr->st_uid;
-		file_info[n].gid = attr->st_gid;
+		file_info[n].blocks = a->st_blocks;
+		file_info[n].linkn = a->st_nlink;
+		file_info[n].mode = a->st_mode;
+		file_info[n].uid = a->st_uid;
+		file_info[n].gid = a->st_gid;
 	}
 
 	if (conf.full_dir_size == 1 && file_info[n].dir == 1
@@ -897,7 +915,7 @@ set_long_attribs(const filesn_t n, const struct stat *attr)
 		file_info[n].size = dir_size(file_info[n].name, 1,
 			&file_info[n].du_status);
 	} else {
-		file_info[n].size = FILE_SIZE_PTR(attr);
+		file_info[n].size = FILE_SIZE_PTR(a);
 	}
 }
 
@@ -908,14 +926,14 @@ get_ind_char(const filesn_t index, int *ind_chr)
 {
 	if (file_info[index].symlink == 1 && checks.lnk_char == 1) {
 		*ind_chr = file_info[index].sel == 1 ? SELFILE_CHR : LINK_CHR;
-		return file_info[index].sel == 1 ? li_cb : lc_c;
+		return lc_c;
 	} else {
 		*ind_chr = file_info[index].sel == 1 ? SELFILE_CHR : ' ';
 		return file_info[index].sel == 1 ? li_cb : "";
 	}
 }
 
-/* Return a struct maxes_t with the following information: the largest files
+/* Return a struct maxes_t with the following information: the longest files
  * counter, user ID, group ID, file size, inode, and file links in the
  * current list of files.
  * This information is required to build the properties line for each entry
@@ -1021,18 +1039,18 @@ print_long_mode(size_t *counter, int *reset_pager, const int pad,
 	int space_left = (int)term_cols - (prop_fields.len + have_xattr
 		+ maxes.files_counter + maxes.size + maxes.links + maxes.inode
 		+ maxes.id_user + (prop_fields.no_group == 0 ? maxes.id_group : 0)
-		+ maxes.blocks + (conf.icons == 1 ? 3 : 0));
+		+ maxes.blocks + (conf.icons == 1 ? ICON_LEN : 0));
 
 	if (space_left < conf.min_name_trim)
 		space_left = conf.min_name_trim;
 
-	if (conf.min_name_trim != UNSET && longest > (size_t)space_left)
-		longest = (size_t)space_left;
+	if (conf.min_name_trim != UNSET && longest.name_len > (size_t)space_left)
+		longest.name_len = (size_t)space_left;
 
-	if (longest < (size_t)space_left)
-		space_left = (int)longest;
+	if (longest.name_len < (size_t)space_left)
+		space_left = (int)longest.name_len;
 
-	maxes.name = space_left + (conf.icons == 1 ? 3 : 0);
+	maxes.name = space_left + (conf.icons == 1 ? ICON_LEN : 0);
 	pager_quit = pager_help = 0;
 
 	filesn_t i, k = files;
@@ -1060,7 +1078,7 @@ print_long_mode(size_t *counter, int *reset_pager, const int pad,
 		}
 
 		int ind_chr = 0;
-		char *ind_chr_color = get_ind_char(i, &ind_chr);
+		const char *ind_chr_color = get_ind_char(i, &ind_chr);
 
 		if (conf.no_eln == 0) {
 			printf("%s%*jd%s%s%c%s", el_c, pad, (intmax_t)i + 1, df_c,
@@ -1080,11 +1098,11 @@ print_long_mode(size_t *counter, int *reset_pager, const int pad,
 static size_t
 get_columns(void)
 {
-	/* LONGEST is size_t: it will never be less than zero. */
-	size_t n = (size_t)term_cols / (longest + 1);
+	/* LONGEST.NAME_LEN is size_t: it will never be less than zero. */
+	size_t n = (size_t)term_cols / (longest.name_len + 1);
 	/* +1 for the space between file names. */
 
-	/* If longest is bigger than terminal columns, N will zero.
+	/* If LONGEST.NAME_LEN is bigger than terminal columns, N will zero.
 	 * To avoid this: */
 	if (n < 1)
 		n = 1;
@@ -1096,29 +1114,45 @@ get_columns(void)
 	return n;
 }
 
-static void
-get_ext_info(const filesn_t i, int *trim_type, size_t *ext_len)
+static size_t
+get_ext_info(const filesn_t i, int *trim_type)
 {
 	if (!file_info[i].ext_name) {
 		char *dot = strrchr(file_info[i].name, '.');
 		if (!dot || dot == file_info[i].name || !dot[1])
-			return;
+			return 0;
 
 		file_info[i].ext_name = dot;
 	}
 
 	*trim_type = TRIM_EXT;
 
+	size_t ext_len = 0;
 	size_t bytes = 0;
-	if (is_utf8_name(file_info[i].ext_name, &bytes) == 0)
-		*ext_len = bytes;
-	else
-		*ext_len = wc_xstrlen(file_info[i].ext_name);
+	const char *e = file_info[i].ext_name;
 
-	if ((int)*ext_len >= conf.max_name_len - 1 || (int)*ext_len <= 0) {
-		*ext_len = 0;
+	if (file_info[i].utf8 == 0) {
+		/* Extension names are usually short. Let's call strlen(2) only
+		 * when it is longer than 6 (including the initial dot). */
+		ext_len = !e[1] ? 1
+			: !e[2] ? 2
+			: !e[3] ? 3
+			: !e[4] ? 4
+			: !e[5] ? 5
+			: !e[6] ? 6
+			: strlen(e);
+	} else if (is_utf8_name(e, &bytes) == 0) {
+		ext_len = bytes;
+	} else {
+		ext_len = wc_xstrlen(e);
+	}
+
+	if ((int)ext_len >= conf.max_name_len - 1 || (int)ext_len <= 0) {
+		ext_len = 0;
 		*trim_type = TRIM_NO_EXT;
 	}
+
+	return ext_len;
 }
 
 /* Construct the file name to be displayed.
@@ -1169,8 +1203,7 @@ construct_filename(const filesn_t i, struct wtrim_t *wtrim,
 	 * in file_info[i].name (this might impact on some later operation!) */
 
 	wtrim->type = TRIM_NO_EXT;
-	size_t ext_len = 0;
-	get_ext_info(i, &wtrim->type, &ext_len);
+	size_t ext_len = get_ext_info(i, &wtrim->type);
 
 	const int trim_len = max_namelen - 1 - (int)ext_len;
 
@@ -1185,7 +1218,7 @@ construct_filename(const filesn_t i, struct wtrim_t *wtrim,
 		/* If not UTF-8, let's avoid u8truncstr(). It's a bit faster this way. */
 		const char c = name[trim_len];
 		name[trim_len] = '\0';
-		mbstowcs((wchar_t *)name_buf, name, NAME_MAX + 1);
+		mbstowcs((wchar_t *)name_buf, name, NAME_BUF_SIZE);
 		name[trim_len] = c;
 	}
 
@@ -1572,7 +1605,8 @@ print_entry_nocolor_light(int *ind_char, const filesn_t i,
 	free(wtrim.wname);
 }
 
-/* Pad the current file name to equate the longest file name length */
+/* Right pad the current file name (adding spaces) to equate the longest
+ * file name length. */
 static void
 pad_filename(const int ind_char, const filesn_t i, const int pad,
 	const int termcap_move_right)
@@ -1580,7 +1614,7 @@ pad_filename(const int ind_char, const filesn_t i, const int pad,
 	int cur_len = 0;
 
 #ifndef _NO_ICONS
-	cur_len = pad + 1 + (conf.icons == 1 ? 3 : 0) + (int)file_info[i].len
+	cur_len = pad + 1 + (conf.icons == 1 ? ICON_LEN : 0) + (int)file_info[i].len
 		+ (ind_char ? 1 : 0);
 #else
 	cur_len = pad + 1 + (int)file_info[i].len + (ind_char ? 1 : 0);
@@ -1593,7 +1627,7 @@ pad_filename(const int ind_char, const filesn_t i, const int pad,
 			cur_len += DIGINUM((int)file_info[i].filesn);
 	}
 
-	const int diff = (int)longest - cur_len;
+	const int diff = (int)longest.name_len - cur_len;
 	if (termcap_move_right == 0) {
 		int j = diff + 1;
 		while (--j >= 0)
@@ -1603,38 +1637,6 @@ pad_filename(const int ind_char, const filesn_t i, const int pad,
 	}
 }
 
-/* Add spaces needed to equate the longest file name length */
-static void
-pad_filename_light(const int ind_char, const filesn_t i, const int pad,
-	const int termcap_move_right)
-{
-	int cur_len = 0;
-#ifndef _NO_ICONS
-	cur_len = pad + 1 + (conf.icons == 1 ? 3 : 0)
-		+ (int)file_info[i].len + (ind_char ? 1 : 0);
-#else
-	cur_len = pad + 1 + (int)file_info[i].len + (ind_char ? 1 : 0);
-#endif /* !_NO_ICONS */
-
-	if (conf.classify == 1) {
-		if (file_info[i].dir == 1)
-			++cur_len;
-		if (file_info[i].filesn > 0 && conf.files_counter == 1
-		&& file_info[i].ruser == 1)
-			cur_len += DIGINUM((int)file_info[i].filesn);
-	}
-
-	const int diff = (int)longest - cur_len;
-
-	if (termcap_move_right == 0) {
-		int j = diff + 1;
-		while(--j >= 0)
-			putchar(' ');
-	} else {
-		MOVE_CURSOR_RIGHT(diff + 1);
-	}
-}
-
 /* List files horizontally:
  * 1 AAA	2 AAB	3 AAC
  * 4 AAD	5 AAE	6 AAF */
@@ -1653,14 +1655,10 @@ list_files_horizontal(size_t *counter, int *reset_pager,
 		print_entry_function = conf.light_mode == 1
 			? print_entry_nocolor_light : print_entry_nocolor;
 
-	void (*pad_filename_function)(const int, const filesn_t, const int, const int);
-	pad_filename_function = conf.light_mode == 1
-		? pad_filename_light : pad_filename;
-
 	const int termcap_move_right = (xargs.list_and_quit == 1
 		|| term_caps.suggestions == 0) ? 0 : 1;
 
-	const int int_longest_fc = (int)longest_fc;
+	const int int_longest_fc_len = (int)longest.fc_len;
 	size_t cur_cols = 0;
 	filesn_t i;
 	int last_column = 0;
@@ -1713,7 +1711,7 @@ list_files_horizontal(size_t *counter, int *reset_pager,
 			 * #    PRINT THE CURRENT ENTRY    #
 			 * ################################# */
 
-		const int fc = file_info[i].dir != 1 ? int_longest_fc : 0;
+		const int fc = file_info[i].dir != 1 ? int_longest_fc_len : 0;
 		/* Displayed file name will be trimmed to MAX_NAME_LEN. */
 		const int max_namelen = conf.max_name_len + fc;
 
@@ -1722,7 +1720,7 @@ list_files_horizontal(size_t *counter, int *reset_pager,
 		print_entry_function(&ind_char, i, pad, max_namelen);
 
 		if (last_column == 0)
-			pad_filename_function(ind_char, i, pad, termcap_move_right);
+			pad_filename(ind_char, i, pad, termcap_move_right);
 		else
 			putchar('\n');
 	}
@@ -1765,14 +1763,10 @@ list_files_vertical(size_t *counter, int *reset_pager,
 		print_entry_function = conf.light_mode == 1
 			? print_entry_nocolor_light : print_entry_nocolor;
 
-	void (*pad_filename_function)(const int, const filesn_t, const int, const int);
-	pad_filename_function = conf.light_mode == 1
-		? pad_filename_light : pad_filename;
-
 	const int termcap_move_right = (xargs.list_and_quit == 1
 		|| term_caps.suggestions == 0) ? 0 : 1;
 
-	const int int_longest_fc = (int)longest_fc;
+	const int int_longest_fc_len = (int)longest.fc_len;
 	size_t cur_cols = 0;
 	size_t cc = columns_n; // Current column number
 	filesn_t x = 0; // Index of the file to be actually printed
@@ -1811,7 +1805,7 @@ list_files_vertical(size_t *counter, int *reset_pager,
 
 		if (x >= nn || !file_info[x].name) {
 			if (last_column == 1)
-				/* Last column is empty. Ex:
+				/* Last column is empty. E.g.:
 				 * 1 file  3 file3  5 file5
 				 * 2 file2 4 file4  HERE
 				 * ... */
@@ -1862,7 +1856,7 @@ list_files_vertical(size_t *counter, int *reset_pager,
 			 * #    PRINT THE CURRENT ENTRY    #
 			 * ################################# */
 
-		const int fc = file_info[x].dir != 1 ? int_longest_fc : 0;
+		const int fc = file_info[x].dir != 1 ? int_longest_fc_len : 0;
 		/* Displayed file name will be trimmed to MAX_NAMELEN. */
 		const int max_namelen = conf.max_name_len + fc;
 
@@ -1871,9 +1865,9 @@ list_files_vertical(size_t *counter, int *reset_pager,
 		print_entry_function(&ind_char, x, pad, max_namelen);
 
 		if (last_column == 0)
-			pad_filename_function(ind_char, x, pad, termcap_move_right);
+			pad_filename(ind_char, x, pad, termcap_move_right);
 		else
-			/* Last column is populated. Ex:
+			/* Last column is populated. Example:
 			 * 1 file  3 file3  5 file5HERE
 			 * 2 file2 4 file4  6 file6HERE
 			 * ... */
@@ -1955,11 +1949,14 @@ check_autocmd_file(const char *s)
 	}
 }
 
+/* If the file at offset I is largest than SIZE, store information about this
+ * file in NAME and COLOR, and update SIZE to the size of the new largest file.
+ * Also, TOTAL is increased with the size of the file under analysis. */
 static void
-get_largest(const filesn_t i, off_t *size, char **name,
+get_largest_file_info(const filesn_t i, off_t *size, char **name,
 	char **color, off_t *total)
 {
-	/* Only directories and regular files should be counted */
+	/* Only directories and regular files should be counted. */
 	if (file_info[i].type != DT_DIR && file_info[i].type != DT_REG
 	&& (file_info[i].type != DT_LNK || conf.apparent_size != 1))
 		return;
@@ -2142,7 +2139,6 @@ construct_human_sizes(void)
 				(s == 0.00f || s - (float)x == 0.00f) ? 0 : 2,
 				(double)s);
 
-		/* + 1 to take the size prefix (B, K, M, etc) into account */
 		file_info[i].human_size.len = ret > 0 ? (size_t)ret : 0;
 		/* Let's follow du(1) in using 'k' (lowercase) instead of 'K'
 		 * (uppercase) when using powers of 1000 (--si). */
@@ -2151,6 +2147,32 @@ construct_human_sizes(void)
 	}
 }
 
+#define LIST_SCANNING_MSG "Scanning... "
+static void
+print_scanning_message(void)
+{
+	UNHIDE_CURSOR;
+	fputs(LIST_SCANNING_MSG, stdout);
+	fflush(stdout);
+	if (xargs.list_and_quit != 1)
+		HIDE_CURSOR;
+}
+
+static void
+print_scanned_file(const char *name)
+{
+	printf("\r\x1b[%zuC\x1b[0K%s%s%s/", sizeof(LIST_SCANNING_MSG) - 1,
+		di_c, name, df_c);
+	fflush(stdout);
+}
+
+static void
+erase_scanning_message(void)
+{
+	fputs("\r\x1b[0K", stdout);
+	fflush(stdout);
+}
+
 /* List files in the current working directory (global variable 'path').
  * Unlike list_dir(), however, this function uses no color and runs
  * neither stat() nor count_dir(), which makes it quite faster. Return
@@ -2173,8 +2195,9 @@ list_dir_light(void)
 	int close_dir = 1;
 	int have_xattr = 0;
 
-	/* A few variables for the disk usage analyzer mode */
-	off_t largest_size = 0, total_size = 0;
+	/* Let's store information about the largest file in the list for the
+	 * disk usage analyzer mode. */
+	off_t largest_name_size = 0, total_size = 0;
 	char *largest_name = (char *)NULL, *largest_color = (char *)NULL;
 
 	if ((dir = opendir(workspaces[cur_ws].path)) == NULL) {
@@ -2192,7 +2215,7 @@ list_dir_light(void)
 	set_events_checker();
 
 	errno = 0;
-	longest = 0;
+	longest.name_len = 0;
 	filesn_t n = 0, count = 0;
 	size_t total_dents = 0;
 
@@ -2297,6 +2320,9 @@ list_dir_light(void)
 		file_info[n].symlink = (file_info[n].type == DT_LNK);
 		file_info[n].inode = ent->d_ino;
 
+		if (checks.scanning == 1 && file_info[n].dir == 1)
+			print_scanned_file(file_info[n].name);
+
 		switch (file_info[n].type) {
 		case DT_DIR:
 #ifndef _NO_ICONS
@@ -2379,7 +2405,7 @@ list_dir_light(void)
 		}
 
 		if (xargs.disk_usage_analyzer == 1) {
-			get_largest(n, &largest_size, &largest_name,
+			get_largest_file_info(n, &largest_name_size, &largest_name,
 				&largest_color, &total_size);
 		}
 
@@ -2399,11 +2425,8 @@ list_dir_light(void)
 	if (hidden_list)
 		free_dothidden(&hidden_list);
 
-	if (xargs.disk_usage_analyzer == 1
-	|| (conf.long_view == 1 && conf.full_dir_size == 1)) {
-		fputs("\r            \r", stdout); /* Erase the "Scanning ..." message */
-		fflush(stdout);
-	}
+	if (checks.scanning == 1)
+		erase_scanning_message();
 
 	if (n == 0) {
 		printf("%s. ..%s\n", di_c, df_c);
@@ -2459,7 +2482,7 @@ END:
 
 	if (xargs.disk_usage_analyzer == 1 && conf.long_view == 1
 	&& conf.full_dir_size == 1) {
-		print_analysis_stats(total_size, largest_size,
+		print_analysis_stats(total_size, largest_name_size,
 			largest_color, largest_name);
 	}
 
@@ -2628,12 +2651,22 @@ load_file_gral_info(const struct stat *a, const filesn_t n)
 	}
 
 	if (conf.long_view == 1) {
-		switch (prop_fields.time) {
-		case PROP_TIME_ACCESS: file_info[n].ltime = a->st_atime; break;
-		case PROP_TIME_CHANGE: file_info[n].ltime = a->st_ctime; break;
-		case PROP_TIME_MOD: file_info[n].ltime = a->st_mtime; break;
-		case PROP_TIME_BIRTH: file_info[n].ltime = btime; break;
-		default: file_info[n].ltime = a->st_mtime; break;
+		if (checks.time_follows_sort == 1) {
+			switch (conf.sort) {
+			case SATIME: file_info[n].ltime = a->st_atime; break;
+			case SBTIME: file_info[n].ltime = btime; break;
+			case SCTIME: file_info[n].ltime = a->st_ctime; break;
+			case SMTIME: file_info[n].ltime = a->st_mtime; break;
+			default: file_info[n].ltime = a->st_mtime; break;
+			}
+		} else {
+			switch (prop_fields.time) {
+			case PROP_TIME_ACCESS: file_info[n].ltime = a->st_atime; break;
+			case PROP_TIME_CHANGE: file_info[n].ltime = a->st_ctime; break;
+			case PROP_TIME_MOD: file_info[n].ltime = a->st_mtime; break;
+			case PROP_TIME_BIRTH: file_info[n].ltime = btime; break;
+			default: file_info[n].ltime = a->st_mtime; break;
+			}
 		}
 	}
 
@@ -2702,8 +2735,8 @@ load_link_info(const int fd, const filesn_t n)
 		return;
 	}
 
-	struct stat attrl;
-	if (fstatat(fd, file_info[n].name, &attrl, 0) == -1) {
+	struct stat a;
+	if (fstatat(fd, file_info[n].name, &a, 0) == -1) {
 		file_info[n].color = or_c;
 		file_info[n].xattr = 0;
 		stats.broken_link++;
@@ -2717,7 +2750,7 @@ load_link_info(const int fd, const filesn_t n)
 	 * this function. */
 	static char tmp[PATH_MAX + 1]; *tmp = '\0';
 	const ssize_t ret =
-		(conf.color_lnk_as_target == 1 && !S_ISDIR(attrl.st_mode))
+		(conf.color_lnk_as_target == 1 && !S_ISDIR(a.st_mode))
 		? readlinkat(XAT_FDCWD, file_info[n].name, tmp, sizeof(tmp) - 1)
 		: 0;
 	if (ret > 0)
@@ -2725,7 +2758,7 @@ load_link_info(const int fd, const filesn_t n)
 
 	const char *lname = *tmp ? tmp : file_info[n].name;
 
-	if (S_ISDIR(attrl.st_mode)) {
+	if (S_ISDIR(a.st_mode)) {
 		file_info[n].dir = 1;
 		file_info[n].filesn = conf.files_counter == 1
 			? (count_dir(file_info[n].name, NO_CPOP) - 2) : 1;
@@ -2737,13 +2770,13 @@ load_link_info(const int fd, const filesn_t n)
 		/* DFILES is negative only if count_dir() failed, which in
 		 * this case only means EACCESS error. */
 		file_info[n].color = conf.color_lnk_as_target == 1
-			? ((dfiles < 0 || check_file_access(attrl.st_mode,
-			attrl.st_uid, attrl.st_gid) == 0) ? nd_c
-			: get_dir_color(lname, attrl.st_mode, attrl.st_nlink,
+			? ((dfiles < 0 || check_file_access(a.st_mode,
+			a.st_uid, a.st_gid) == 0) ? nd_c
+			: get_dir_color(lname, a.st_mode, a.st_nlink,
 			dfiles)) : ln_c;
 	} else {
 		if (conf.color_lnk_as_target == 1)
-			get_link_target_color(lname, &attrl, n);
+			get_link_target_color(lname, &a, n);
 		else
 			file_info[n].color = ln_c;
 	}
@@ -2794,10 +2827,7 @@ load_regfile_info(const struct stat *a, const filesn_t n)
 	else if (a && IS_EXEC(a)) {
 		file_info[n].exec = 1;
 		stats.exec++;
-		if (file_info[n].size == 0)
-			file_info[n].color = ee_c;
-		else
-			file_info[n].color = ex_c;
+		file_info[n].color = file_info[n].size == 0 ? ee_c : ex_c;
 	} else if (file_info[n].linkn > 1) { /* Multi-hardlink */
 		file_info[n].color = mh_c;
 		stats.multi_link++;
@@ -2812,14 +2842,11 @@ load_regfile_info(const struct stat *a, const filesn_t n)
 		file_info[n].icon = ICON_EXEC;
 #endif /* !_NO_ICONS */
 
-	/* Unaccessible files, files with capabilities, multi-hardlink
-	 * and executable files take precedence over temp and file
-	 * extension colors. */
-	const int no_override_color = (file_info[n].color == nf_c
-	|| file_info[n].color == ca_c || file_info[n].color == mh_c
-	|| file_info[n].exec == 1);
+	/* Try temp and extension color only provided the file is a non-empty
+	 * regular file. */
+	const int override_color = (file_info[n].color == fi_c);
 
-	if (no_override_color == 0
+	if (override_color == 1
 	&& IS_TEMP_FILE(file_info[n].name, file_info[n].bytes)) {
 		file_info[n].color = bk_c;
 		return;
@@ -2836,7 +2863,7 @@ load_regfile_info(const struct stat *a, const filesn_t n)
 #endif /* !_NO_ICONS */
 
 	/* Check file extension */
-	char *ext = (no_override_color == 0 && check_ext == 1)
+	char *ext = (override_color == 1 && check_ext == 1)
 		? strrchr(file_info[n].name, '.') : (char *)NULL;
 
 	if (!ext || ext == file_info[n].name || !*(ext + 1))
@@ -2885,7 +2912,7 @@ list_dir(void)
 	clock_t start = clock();
 #endif /* LIST_SPEED_TEST */
 
-	if (conf.clear_screen == 1)
+	if (conf.clear_screen > 0)
 		{ CLEAR; fflush(stdout); }
 
 	/* Hide the cursor to minimize flickering: it will be unhidden immediately
@@ -2904,28 +2931,13 @@ list_dir(void)
 		dir_out = 0;
 	}
 
-	if (conf.clear_screen == 1) {
+	if (conf.clear_screen > 0) {
 		/* For some reason we need to clear the screen twice to prevent
 		 * a garbage first line when scrolling up */
 		CLEAR; fflush(stdout);
 	}
 
 	set_pager_view();
-
-	if (xargs.disk_usage_analyzer == 1
-	|| (conf.long_view == 1 && conf.full_dir_size == 1)) {
-		UNHIDE_CURSOR;
-		fputs(_("Scanning... "), stdout);
-		fflush(stdout);
-		if (xargs.list_and_quit != 1)
-			HIDE_CURSOR;
-	}
-
-	if (conf.unicode == 0) {
-		trim.state = trim.a = trim.b = 0;
-		trim.len = 0;
-	}
-
 	get_term_size();
 
 	virtual_dir =
@@ -2933,9 +2945,11 @@ list_dir(void)
 
 	/* Reset the stats struct */
 	stats = (struct stats_t){0};
-
 	init_checks_struct();
 
+	if (checks.scanning == 1)
+		print_scanning_message();
+
 	if (conf.long_view == 1)
 		props_now = time(NULL);
 
@@ -2954,8 +2968,9 @@ list_dir(void)
 	int close_dir = 1;
 	int have_xattr = 0;
 
-	/* A few variables for the disk usage analyzer mode */
-	off_t largest_size = 0, total_size = 0;
+	/* Let's store information about the largest file in the list for the
+	 * disk usage analyzer mode. */
+	off_t largest_name_size = 0, total_size = 0;
 	char *largest_name = (char *)NULL, *largest_color = (char *)NULL;
 
 	if ((dir = opendir(workspaces[cur_ws].path)) == NULL) {
@@ -2979,7 +2994,7 @@ list_dir(void)
 		 * ########################################## */
 
 	errno = 0;
-	longest = 0;
+	longest.name_len = 0;
 	filesn_t n = 0, count = 0;
 	size_t total_dents = 0;
 
@@ -3117,6 +3132,9 @@ list_dir(void)
 		default: file_info[n].color = df_c; break;
 		}
 
+		if (checks.scanning == 1 && file_info[n].dir == 1)
+			print_scanned_file(file_info[n].name);
+
 #ifndef _NO_ICONS
 		if (checks.icons_use_file_color == 1)
 			file_info[n].icon_color = file_info[n].color;
@@ -3124,9 +3142,10 @@ list_dir(void)
 		if (conf.long_view == 1 && stat_ok == 1)
 			set_long_attribs(n, &attr);
 
-		if (xargs.disk_usage_analyzer == 1)
-			get_largest(n, &largest_size, &largest_name,
+		if (xargs.disk_usage_analyzer == 1) {
+			get_largest_file_info(n, &largest_name_size, &largest_name,
 				&largest_color, &total_size);
+		}
 
 		n++;
 		if (n > FILESN_MAX - 1) {
@@ -3153,11 +3172,8 @@ list_dir(void)
 	file_info[n].name = (char *)NULL;
 	files = n;
 
-	if (xargs.disk_usage_analyzer == 1 || (conf.long_view == 1
-	&& conf.full_dir_size == 1)) {
-		fputs("\r            \r", stdout); /* Erase the "Scanning ..." message */
-		fflush(stdout);
-	}
+	if (checks.scanning == 1)
+		erase_scanning_message();
 
 	if (n == 0) {
 		printf("%s. ..%s\n", di_c, df_c);
@@ -3219,7 +3235,7 @@ END:
 
 	if (xargs.disk_usage_analyzer == 1 && conf.long_view == 1
 	&& conf.full_dir_size == 1) {
-		print_analysis_stats(total_size, largest_size,
+		print_analysis_stats(total_size, largest_name_size,
 			largest_color, largest_name);
 	}
 
