@@ -31,45 +31,21 @@
 #include "aux.h"    /* xitoa() */
 #include "checks.h" /* check_file_access() */
 #include "colors.h" /* remove_bold_attr() */
+#include "long_view.h" /* macros */
 #include "misc.h"   /* gen_diff_str() */
-#include "properties.h"
-
-/* These macros define the max length for each properties field.
- * These lengths are made based on how each field is built (i.e. displayed).
- * We first construct and store (in the stack, to avoid expensive heap
- * allocation) the appropeiate value, and then print them all
- * (print_entry_props()). */
-
-/* 14 colors + 15 single chars + NUL byte */
-#define PERM_STR_LEN  ((MAX_COLOR * 14) + 16) /* construct_file_perms() */
-
-#define TIME_STR_LEN  (MAX_TIME_STR + (MAX_COLOR * 2) + 2) /* construct_timestamp() */
-/* construct_human_size() returns a string of at most MAX_HUMAN_SIZE chars (helpers.h) */
-#define SIZE_STR_LEN  (MAX_HUMAN_SIZE + (MAX_COLOR * 3) + 10) /* construct_file_size() */
-/* 2 colors + 2 names + (space + NUL byte) + DIM */
-#define ID_STR_LEN    ((MAX_COLOR * 2) + (NAME_MAX * 2) + 2 + 4)
-/* Max inode number able to hold: 999 billions! Padding could be as long
- * as max inode lenght - 1 */
-#define INO_STR_LEN   ((MAX_COLOR * 2) + ((12 + 1) * 2) + 4)
-
-#define LINKS_STR_LEN ((MAX_COLOR * 2) + 32)
-/* Files counter */
-#define FC_STR_LEN    ((MAX_COLOR * 2) + 32)
-/* File allocated blocks */
-#define BLK_STR_LEN   ((MAX_COLOR * 2) + 32)
+#include "properties.h" /* get_color_age, get_color_size, get_file_perms */
 
 static char *
-get_ext_info_long(const char *name, const size_t name_len, int *trim,
-	size_t *ext_len)
+get_ext_info_long(const struct fileinfo *props, const size_t name_len,
+	int *trim, size_t *ext_len)
 {
 	char *ext_name = (char *)NULL;
-
-	char *e = strrchr(name, '.');
-	if (e && e != name && *(e + 1)) {
+	char *e = strrchr(props->name, '.');
+	if (e && e != props->name && e[1]) {
 		ext_name = e;
 		*trim = TRIM_EXT;
-		if (conf.unicode == 0)
-			*ext_len = name_len - (size_t)(ext_name - name);
+		if (props->utf8 == 0)
+			*ext_len = name_len - (size_t)(ext_name - props->name);
 		else
 			*ext_len = wc_xstrlen(ext_name);
 	}
@@ -138,22 +114,18 @@ construct_and_print_filename(const struct fileinfo *props,
 	const filesn_t n = (max_files > UNSET && files > (filesn_t)max_files)
 		? (filesn_t)max_files : files;
 
-	size_t cur_len = (size_t)DIGINUM(n) + 1 + plen;
-	if (conf.icons == 1)
-		cur_len += 3;
+	size_t cur_len = (size_t)DIGINUM(n) + 1 + plen
+		+ (conf.icons == 1 ? ICON_LEN : 0);
 
 	int diff = 0;
+	char *name = wname ? wname : props->name;
 	char *ext_name = (char *)NULL;
+
 	if (cur_len > (size_t)max_namelen) {
 		const int rest = (int)cur_len - max_namelen;
 		trim = TRIM_NO_EXT;
 		size_t ext_len = 0;
-		ext_name = get_ext_info_long(props->name, plen, &trim, &ext_len);
-
-		if (wname)
-			xstrsncpy(name_buf, wname, sizeof(name_buf));
-		else
-			memcpy(name_buf, props->name, props->bytes + 1);
+		ext_name = get_ext_info_long(props, plen, &trim, &ext_len);
 
 		int trim_point = (int)plen - rest - 1 - (int)ext_len;
 		if (trim_point <= 0) {
@@ -161,22 +133,33 @@ construct_and_print_filename(const struct fileinfo *props,
 			trim = TRIM_NO_EXT;
 		}
 
-		diff = u8truncstr(name_buf, (size_t)trim_point);
+		if (props->utf8 == 1) {
+			if (wname)
+				xstrsncpy(name_buf, name, sizeof(name_buf));
+			else /* memcpy is faster: use it whenever possible. */
+				memcpy(name_buf, name, props->bytes + 1);
+
+			diff = u8truncstr(name_buf, (size_t)trim_point);
+		} else { /* Let's avoid u8truncstr() to get some extra speed. */
+			const char c = name[trim_point];
+			name[trim_point] = '\0';
+			mbstowcs((wchar_t *)name_buf, name, NAME_BUF_SIZE);
+			name[trim_point] = c;
+		}
 
 		cur_len -= (size_t)rest;
+	} else {
+		mbstowcs((wchar_t *)name_buf, name, NAME_BUF_SIZE);
 	}
 
+	free(wname);
+
 	/* Calculate pad for each file name */
 	int pad = max_namelen - (int)cur_len;
 	if (pad < 0)
 		pad = 0;
 
-	if (!trim || !conf.unicode)
-		mbstowcs((wchar_t *)name_buf, wname ? wname : props->name, NAME_MAX + 1);
-
-	free(wname);
-
-	char *trim_diff = diff > 0 ? gen_diff_str(diff) : "";
+	const char *trim_diff = diff > 0 ? gen_diff_str(diff) : "";
 
 	static char trim_s[2] = {0};
 	*trim_s = trim > 0 ? TRIMFILE_CHR : 0;
@@ -223,7 +206,7 @@ construct_file_size(const struct fileinfo *props, char *size_str,
 		? props->size : 0;
 
 	/* Let's construct the color for the current file size */
-	char *csize = props->dir == 1 ? dz_c : df_c;
+	char *csize = dz_c;
 	static char sf[MAX_SHADE_LEN];
 	if (conf.colorize == 1) {
 		if (!*dz_c) {
@@ -277,6 +260,28 @@ construct_file_perms(const mode_t mode, char *perm_str, const char file_type,
 	}
 }
 
+static char *
+get_time_char(void)
+{
+	if (conf.time_follows_sort == 1) {
+		switch (conf.sort) {
+		case SATIME: return conf.relative_time == 1 ? "A" : "a";
+		case SCTIME: return conf.relative_time == 1 ? "C" : "c";
+		case SBTIME: return conf.relative_time == 1 ? "B" : "b";
+		case SMTIME: return conf.relative_time == 1 ? "M" : "m";
+		default: break;
+		}
+	}
+
+	switch (prop_fields.time) {
+	case PROP_TIME_ACCESS: return conf.relative_time == 1 ? "A" : "a";
+	case PROP_TIME_BIRTH: return conf.relative_time == 1 ? "B" : "b";
+	case PROP_TIME_CHANGE: return conf.relative_time == 1 ? "C" : "c";
+	case PROP_TIME_MOD: /* fallthrough */
+	default: return conf.relative_time == 1 ? "M" : "m";
+	}
+}
+
 static void
 construct_timestamp(char *time_str, const struct fileinfo *props)
 {
@@ -319,10 +324,14 @@ construct_timestamp(char *time_str, const struct fileinfo *props)
 			/* GCC (not clang) complains about tfmt being not a string
 			 * literal. Let's silence this warning until we find a better
 			 * approach. */
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wformat-nonliteral"
+#ifdef GCC_ALLOWS_PRAGMA_IN_FUNC
+# pragma GCC diagnostic push
+# pragma GCC diagnostic ignored "-Wformat-nonliteral"
+#endif /* GCC_ALLOWS_PRAGMA_IN_FUNC */
 			strftime(file_time, sizeof(file_time), tfmt, &tm);
-#pragma GCC diagnostic pop
+#ifdef GCC_ALLOWS_PRAGMA_IN_FUNC
+# pragma GCC diagnostic pop
+#endif /* GCC_ALLOWS_PRAGMA_IN_FUNC */
 		} else {
 			xstrsncpy(file_time, invalid_time_str, sizeof(file_time));
 		}
@@ -332,16 +341,17 @@ construct_timestamp(char *time_str, const struct fileinfo *props)
 		xstrsncpy(file_time, invalid_time_str, sizeof(file_time));
 	}
 
-	snprintf(time_str, TIME_STR_LEN, "%s%s%s", cdate, *file_time
-		? file_time : UNKNOWN_STR, df_c);
+	snprintf(time_str, TIME_STR_LEN, "%s%s%s%s%s", cdate, *file_time
+		? file_time : UNKNOWN_STR, dt_c,
+		conf.timestamp_mark == 1 ? get_time_char() : "", df_c);
 }
 
 static void
 construct_id_field(const struct fileinfo *props, char *id_str,
 	const struct maxes_t *maxes, const int file_perm)
 {
-	const char *id_color =
-		(file_perm == 1 && conf.colorize == 1) ? dg_c : df_c;
+	const char *uid_color =
+		(file_perm == 1 && conf.colorize == 1) ? du_c : df_c;
 
 #define USER_NAME props->uid_i.name ? props->uid_i.name \
 		: (props->stat_err == 1 ? UNKNOWN_STR : xitoa(props->uid))
@@ -351,21 +361,24 @@ construct_id_field(const struct fileinfo *props, char *id_str,
 	if (prop_fields.no_group == 1) {
 		if (prop_fields.ids == PROP_ID_NUM) {
 			if (props->stat_err == 1) {
-				snprintf(id_str, ID_STR_LEN, "%s%*s%s", id_color,
+				snprintf(id_str, ID_STR_LEN, "%s%*s%s", uid_color,
 					maxes->id_user, UNKNOWN_STR, df_c);
 			} else {
-				snprintf(id_str, ID_STR_LEN, "%s%*u%s", id_color,
+				snprintf(id_str, ID_STR_LEN, "%s%*u%s", uid_color,
 					maxes->id_user, props->uid, df_c);
 			}
 		} else { /* PROPS_ID_NAME */
-			snprintf(id_str, ID_STR_LEN, "%s%-*s%s", id_color,
+			snprintf(id_str, ID_STR_LEN, "%s%-*s%s", uid_color,
 				maxes->id_user, USER_NAME, df_c);
 		}
 
 		return;
 	}
 
-	const char *dim = conf.colorize == 0 ? "" : dim_c;
+//	const char *dim = conf.colorize == 0 ? "" : dim_c;
+	const char *gid_color = conf.colorize == 0 ? "" :
+		(file_perm == 1 ? dg_c : dim_c);
+
 	if (prop_fields.ids == PROP_ID_NUM) {
 		if (props->stat_err == 1) {
 			snprintf(id_str, ID_STR_LEN, "%s%*c %*c",
@@ -373,13 +386,13 @@ construct_id_field(const struct fileinfo *props, char *id_str,
 				maxes->id_group, UNKNOWN_CHR);
 		} else {
 			snprintf(id_str, ID_STR_LEN, "%s%*u %s%*u%s",
-				id_color, maxes->id_user, props->uid,
-				dim, maxes->id_group, props->gid, df_c);
+				uid_color, maxes->id_user, props->uid,
+				gid_color, maxes->id_group, props->gid, df_c);
 		}
 	} else { /* PROPS_ID_NAME */
 		snprintf(id_str, ID_STR_LEN, "%s%-*s %s%-*s%s",
-			id_color, maxes->id_user, USER_NAME,
-			props->stat_err == 1 ? "" : dim,
+			uid_color, maxes->id_user, USER_NAME,
+			props->stat_err == 1 ? "" : gid_color,
 			maxes->id_group, GROUP_NAME, df_c);
 	}
 }
@@ -393,7 +406,7 @@ construct_files_counter(const struct fileinfo *props, char *fc_str,
 			(int)props->filesn, df_c);
 	} else {
 		snprintf(fc_str, FC_STR_LEN, "%s%*c%s", dn_c, max,
-			props->filesn < 0 ? '?' /* Dir with no read permission */
+			props->filesn < 0 ? UNKNOWN_CHR /* Dir with no read permission */
 			: (props->dir == 1 ? '0' : '-'),
 			df_c);
 	}
