@@ -97,6 +97,7 @@ struct ext_mnt_t *ext_mnt = (struct ext_mnt_t *)NULL;
 #endif /* LINUX_FSINFO */
 struct groups_t *sys_users = (struct groups_t *)NULL;
 struct groups_t *sys_groups = (struct groups_t *)NULL;
+struct dircmds_t dir_cmds = {UNSET, 0};
 
 const struct sort_t sort_methods[] = {
     {"none", 0, 0},
@@ -223,7 +224,6 @@ size_t
 	ext_colors_n = 0,
 	jump_n = 0,
 	kbinds_n = 0,
-	longest = 0,
 	msgs_n = 0,
 	P_tmpdir_len = 0,
 	path_n = 0,
@@ -351,7 +351,6 @@ char
 	uf_c[MAX_COLOR], /* Non-'stat'able file */
 
 	/* Interface */
-	bm_c[MAX_COLOR], /* Bookmarked directory */
 	df_c[MAX_COLOR], /* Default color */
 	dl_c[MAX_COLOR], /* Dividing line index */
 	el_c[MAX_COLOR], /* ELN */
@@ -393,12 +392,14 @@ char
 	db_c[MAX_COLOR],  /* File allocated blocks */
 	dd_c[MAX_COLOR],  /* Date (fixed color: no shading) */
 	de_c[MAX_COLOR],  /* Inode number */
-	dg_c[MAX_COLOR],  /* UID, GID */
+	dg_c[MAX_COLOR],  /* Group ID */
 	dk_c[MAX_COLOR],  /* Number of links */
 	dn_c[MAX_COLOR],  /* dash (none) */
 	do_c[MAX_COLOR],  /* Octal perms */
 	dp_c[MAX_COLOR],  /* Special files (SUID, SGID, etc) */
 	dr_c[MAX_COLOR],  /* Read */
+	dt_c[MAX_COLOR],  /* Timestamp mark */
+	du_c[MAX_COLOR],  /* User ID */
 	dw_c[MAX_COLOR],  /* Write */
 	dxd_c[MAX_COLOR], /* Execute (dirs) */
 	dxr_c[MAX_COLOR], /* Execute (reg files) */
@@ -433,7 +434,7 @@ char
 	dim_c[] = "\x1b[2m";
 
 /* A buffer to store file names to be displayed (wide string) */
-char name_buf[(NAME_MAX + 1) * sizeof(wchar_t)];
+char name_buf[NAME_BUF_SIZE * sizeof(wchar_t)];
 
 /* A list of all internal commands, with short and long formats.
  * We use two more lists of commands: one of commands dealing with file names
@@ -456,8 +457,6 @@ const struct cmdslist_t internal_cmds[] = {
 	{"bb", 2},
 	{"bleach", 6},
 	{"bd", 2},
-	{"bh", 2}, // REMOVE AS SOON AS REPLACED BY DH
-	{"fh", 2}, // REMOVE AS SOON AS REPLACED BY DH
 	{"dh", 2},
 	{"bl", 2},
 	{"bm", 2},
@@ -478,7 +477,6 @@ const struct cmdslist_t internal_cmds[] = {
 	{"dup", 3},
 	{"ds", 2},
 	{"desel", 5},
-	{"edit", 4}, /* Deprecated */
 	{"config", 6},
 	{"exp", 3},
 	{"export", 6},
@@ -488,7 +486,6 @@ const struct cmdslist_t internal_cmds[] = {
 	{"fc", 2},
 	{"ff", 2},
 	{"dirs-first", 10},
-	{"fs", 2},
 	{"ft", 2},
 	{"filter", 6},
 	{"fz", 2},
@@ -629,13 +626,10 @@ const struct cmdslist_t param_str[] = {
 	{"c --force", 9},
 	{"colorschemes edit", 17},
 	{"cs edit", 7},
+	{"colorschemes preview", 20},
+	{"cs preview", 10},
 	{"desel all", 9},
 	{"ds all", 6},
-///////// Deprecated
-	{"edit", 4},
-	{"edit reset", 10},
-	{"edit dump", 9},
-/////////
 	{"config", 6},
 	{"config edit", 11},
 	{"config dump", 11},
@@ -944,8 +938,9 @@ static inline void
 set_root_indicator(void)
 {
 	if (user.uid == 0) {
+		const char *bold_red = conf.colorize == 1 ? "\x1b[1;31m" : "";
 		err(ERR_NO_LOG, PRINT_PROMPT, _("%s->%s Running as root%s\n"),
-			conf.colorize == 1 ? mi_c : "", conf.colorize == 1 ? BOLD_RED : "",
+			conf.colorize == 1 ? mi_c : "", bold_red,
 			conf.colorize == 1 ? df_c : "");
 	}
 }
@@ -1082,8 +1077,8 @@ set_locale(void)
 	setlocale(LC_ALL, "");
 	if (strcmp(nl_langinfo(CODESET), "UTF-8") != 0) {
 		err('w', PRINT_PROMPT, _("%s: Locale is not UTF-8. To avoid "
-			"encoding issues you might want to set an UTF-8 locale. Ex: "
-			"export LANG=es_AR.UTF-8\n"), PROGRAM_NAME);
+			"encoding issues you might want to set an UTF-8 locale. For "
+			"example: export LANG=es_AR.UTF-8\n"), PROGRAM_NAME);
 	}
 }
 
@@ -1103,7 +1098,7 @@ check_gui(void)
 static void
 set_security_paranoid_mode(void)
 {
-# if SECURITY_PARANOID == 0
+# if SECURITY_PARANOID <= 0
 	return;
 # elif SECURITY_PARANOID == 1
 	if (xargs.secure_env != 1 && xargs.secure_env_full != 1) {
@@ -1119,7 +1114,7 @@ set_security_paranoid_mode(void)
 #  if SECURITY_PARANOID > 2
 	xargs.stealth_mode = 1;
 #  endif /* SECURITY_PARANOID > 2 */
-# endif /* SECURITY_PARANOID == 0 */
+# endif /* SECURITY_PARANOID <= 0 */
 }
 #endif /* SECURITY_PARANOID */
 
@@ -1196,7 +1191,7 @@ main(int argc, char *argv[])
 	}
 
 	/* Make sure all initialization is made with restrictive permissions. */
-	const mode_t old_mask = umask(0077);
+	const mode_t old_mask = umask(0077); /* flawfinder: ignore */
 
 	check_term(); /* Let's check terminal capabilities. */
 
