@@ -68,7 +68,7 @@
 /* Information about devices */
 struct mnt_t {
 	char *mnt;   /* Mountpoint */
-	char *dev;   /* Device name (ex: /dev/sda1) */
+	char *dev;   /* Device name (e.g.: /dev/sda1) */
 	char *label; /* Device label */
 };
 
@@ -190,7 +190,7 @@ get_dev_label(void)
 		const char *name = labels[i]->d_name;
 		char lpath[PATH_MAX + 1];
 		snprintf(lpath, sizeof(lpath), "%s/%s", DISK_LABELS_PATH, name);
-		char *rpath = realpath(lpath, NULL);
+		char *rpath = xrealpath(lpath, NULL);
 		if (!rpath) {
 			free(labels[i]);
 			continue;
@@ -457,7 +457,7 @@ get_mnt_input(const int mode, int *info)
 	int n = -1;
 	puts(_("Enter 'q' to quit"));
 	if (xargs.mount_cmd != UNSET)
-		puts(_("Enter 'iELN' for device information. Ex: i4"));
+		puts(_("Enter 'iELN' for device information. E.g.: i4"));
 
 	char *input = (char *)NULL;
 	while (!input) {
@@ -585,7 +585,7 @@ media_menu(const int mode)
 		return FUNC_FAILURE;
 	}
 
-	if (conf.clear_screen == 1)
+	if (conf.clear_screen > 0)
 		CLEAR;
 
 #ifdef HAVE_PROC_MOUNTS
