@@ -36,14 +36,14 @@
 # include <magic.h>
 #endif /* !_NO_MAGIC */
 
-#if defined(_NO_MAGIC) && !defined(_BE_POSIX)
-# include <paths.h>
+#if defined(_NO_MAGIC)
+# if !defined(_BE_POSIX)
+#  include <paths.h>
+# endif /* !_BE_POSIX */
 # ifndef _PATH_DEVNULL
 #  define _PATH_DEVNULL "/dev/null"
 # endif /* _PATH_DEVNULL */
-#else
-# define _PATH_DEVNULL "/dev/null"
-#endif /* _NO_MAGIC && !_BE_POSIX */
+#endif /* _NO_MAGIC */
 
 #ifndef _NO_ARCHIVING
 #include "archives.h"
@@ -710,7 +710,7 @@ get_user_input(const size_t max)
 }
 
 static void
-set_exec_flags(char *str, int *exec_flags)
+set_exec_flags(const char *str, int *exec_flags)
 {
 	if (*str == 'E') {
 		*exec_flags |= E_NOSTDERR;
@@ -723,8 +723,16 @@ set_exec_flags(char *str, int *exec_flags)
 	}
 }
 
-/* Expand %f placeholder, stderr/stdout flags, and environment variables
- * in the opening application line */
+static void
+copy_field(char **dst, const char *src)
+{
+	const size_t src_len = strlen(src);
+	*dst = xnrealloc(*dst, src_len + 1, sizeof(char));
+	xstrsncpy(*dst, src, src_len + 1);
+}
+
+/* Expand %[f|x] placeholder, stderr/stdout flags, and environment variables
+ * in the opening application line. */
 static size_t
 expand_app_fields(char ***cmd, size_t *n, char *fpath, int *exec_flags)
 {
@@ -736,9 +744,7 @@ expand_app_fields(char ***cmd, size_t *n, char *fpath, int *exec_flags)
 		/* "%x" is short for "%f !EO &". It must be the last field in the
 		 * command entry (subsequent fields will be ignored). */
 		if (*a[i] == '%' && a[i][1] == 'x') {
-			const size_t fpath_len = strlen(fpath);
-			a[i] = xnrealloc(a[i], fpath_len + 1, sizeof(char));
-			xstrsncpy(a[i], fpath, fpath_len + 1);
+			copy_field(&a[i], fpath);
 			f = 1;
 			set_exec_flags("EO", exec_flags);
 			bg_proc = 1;
@@ -746,11 +752,9 @@ expand_app_fields(char ***cmd, size_t *n, char *fpath, int *exec_flags)
 			break;
 		}
 
-		/* Expand %f pĺaceholder */
-		if (*a[i] == '%' && *(a[i] + 1) == 'f') {
-			const size_t fpath_len = strlen(fpath);
-			a[i] = xnrealloc(a[i], fpath_len + 1, sizeof(char));
-			xstrsncpy(a[i], fpath, fpath_len + 1);
+		/* Expand %f placeholder */
+		if (*a[i] == '%' && a[i][1] == 'f') {
+			copy_field(&a[i], fpath);
 			f = 1;
 			continue;
 		}
@@ -764,14 +768,12 @@ expand_app_fields(char ***cmd, size_t *n, char *fpath, int *exec_flags)
 		}
 
 		/* Expand environment variable */
-		if (*a[i] == '$' && *(a[i] + 1) >= 'A' && *(a[i] + 1) <= 'Z') {
+		if (*a[i] == '$' && a[i][1] >= 'A' && a[i][1] <= 'Z') {
 			char *p = expand_env(a[i]);
 			if (!p)
 				continue;
 
-			const size_t p_len = strlen(p);
-			a[i] = xnrealloc(a[i], p_len + 1, sizeof(char *));
-			xstrsncpy(a[i], p, p_len + 1);
+			copy_field(&a[i], p);
 			free(p);
 			continue;
 		}
@@ -788,106 +790,28 @@ expand_app_fields(char ***cmd, size_t *n, char *fpath, int *exec_flags)
 	return f;
 }
 
-/* Open the file FPATH via the application APP */
+/* Open the file named FILE via the application APP, splitting APP and
+ * expanding fields to the appropriate values. */
 static int
-run_mime_app(char **app, char **fpath)
+run_mime_app(char *app, char *file)
 {
-	char **cmd = split_str(*app, NO_UPDATE_ARGS);
-	if (!cmd) {
-		free(*app);
-#ifndef __CYGWIN__
-		free(*fpath);
-#endif /* !__CYGWIN__ */
+	char **cmd = split_str(app, NO_UPDATE_ARGS);
+	if (!cmd)
 		return FUNC_FAILURE;
-	}
 
-	int exec_flags = 0;
+	int exec_flags = E_NOFLAG;
 	size_t i = 0;
-	const size_t f = expand_app_fields(&cmd, &i, *fpath, &exec_flags);
-	size_t n = i;
+	const size_t f = expand_app_fields(&cmd, &i, file, &exec_flags);
 
 	/* If no %f placeholder was found, append file name */
-	if (f == 0) {
-		cmd = xnrealloc(cmd, i + 2, sizeof(char *));
-		cmd[i] = savestring(*fpath, strlen(*fpath));
-		cmd[i + 1] = (char *)NULL;
-		n++;
-	}
-
-	const int ret = launch_execv(cmd, (bg_proc && !open_in_foreground)
-		? BACKGROUND : FOREGROUND, exec_flags);
-
-	for (i = 0; i < n; i++)
-		free(cmd[i]);
-	free(cmd);
-
-	free(*app);
-#ifndef __CYGWIN__
-	free(*fpath);
-#endif /* !__CYGWIN */
-
-	return ret;
-}
-
-static int
-split_and_run(char *app, char *file)
-{
-	size_t f = 0;
-	size_t i;
-	char **cmd = split_str(app, NO_UPDATE_ARGS);
-	int exec_flags = E_NOFLAG;
-
-	for (i = 0; cmd[i]; i++) {
-		/* "%x" is short for "%f !EO &". It must be the last field in the
-		 * command entry (subsequent fields will be ignored). */
-		if (*cmd[i] == '%' && cmd[i][1] == 'x') {
-			const size_t file_len = strlen(file);
-			cmd[i] = xnrealloc(cmd[i], file_len + 1, sizeof(char));
-			xstrsncpy(cmd[i], file, file_len + 1);
-			f = 1;
-			set_exec_flags("EO", &exec_flags);
-			bg_proc = 1;
-			break;
-		}
-
-		if (*cmd[i] == '!' && (cmd[i][1] == 'E' || cmd[i][1] == 'O')) {
-			set_exec_flags(cmd[i] + 1, &exec_flags);
-			free(cmd[i]);
-			cmd[i] = (char *)NULL;
-			continue;
-		}
-
-		if (*cmd[i] == '&') {
-			bg_proc = 1;
-			free(cmd[i]);
-			cmd[i] = (char *)NULL;
-			continue;
-		}
-		if (*cmd[i] == '%' && cmd[i][1] == 'f') {
-			const size_t file_len = strlen(file);
-			cmd[i] = xnrealloc(cmd[i], file_len + 1, sizeof(char));
-			xstrsncpy(cmd[i], file, file_len + 1);
-			f = 1;
-		}
-		if (*cmd[i] == '$' && cmd[i][1] >= 'A' && cmd[i][1] <= 'Z') {
-			char *env = expand_env(cmd[i]);
-			if (env) {
-				free(cmd[i]);
-				cmd[i] = env;
-			}
-		}
-	}
-
-	/* If file to be opened was not specified via %f, append
-	 * it to the cmd array. */
 	if (f == 0) {
 		cmd = xnrealloc(cmd, i + 2, sizeof(char *));
 		cmd[i] = savestring(file, strlen(file));
 		cmd[i + 1] = (char *)NULL;
 	}
 
-	const int ret =
-		launch_execv(cmd, bg_proc ? BACKGROUND : FOREGROUND, exec_flags);
+	const int ret = launch_execv(cmd, (bg_proc && !open_in_foreground)
+		? BACKGROUND : FOREGROUND, exec_flags);
 
 	for (i = 0; cmd[i]; i++)
 		free(cmd[i]);
@@ -896,6 +820,9 @@ split_and_run(char *app, char *file)
 	return ret;
 }
 
+/* Open the file named FILE via the application APP.
+ * No field expansion is made on APP, since it must be just an application
+ * name. If expansion is required, use run_mime_app() instead. */
 static int
 run_cmd(char *app, char *file)
 {
@@ -933,11 +860,8 @@ mime_list_open(char **apps, char *file)
 		printf("%s%*zu%s %s\n", el_c, pad, i + 1, df_c, apps[i]);
 
 	int n = get_user_input(i);
-	if (n == -1) {
-		if (conf.autols == 1)
-			reload_dirlist();
+	if (n == -1) /* 'q' or Ctrl-d */
 		return FUNC_SUCCESS;
-	}
 
 	char *app = apps[n - 1];
 	if (!app)
@@ -946,7 +870,7 @@ mime_list_open(char **apps, char *file)
 	int ret = FUNC_FAILURE;
 
 	if (strchr(app, ' '))
-		ret = split_and_run(app, file);
+		ret = run_mime_app(app, file);
 	else /* We have just a command name: no parameter nor placeholder */
 		ret = run_cmd(app, file);
 
@@ -1008,7 +932,7 @@ get_apps_from_file(FILE *fp, char *file_name, const char *mime,
 
 		while (*tmp) {
 			size_t app_len = 0;
-			/* Split the appplications line into substrings, if any */
+			/* Split the applications line into substrings, if any */
 			while (*tmp != '\0' && *tmp != ';' && *tmp != '\n' && *tmp != '\''
 			&& *tmp != '"') {
 				app[app_len] = *tmp;
@@ -1043,12 +967,11 @@ get_apps_from_file(FILE *fp, char *file_name, const char *mime,
 				if (!t)
 					continue;
 				/* appb: A copy of the original string: let's display
-				 * the env var name itself instead of its expanded
-				 * value. */
+				 * the env var name itself instead of its expanded value. */
 				appb = savestring(app, strlen(app));
 				/* app: the expanded value. */
 				const size_t tlen = strlen(t);
-				app = xnrealloc(app, app_len + tlen + 1, sizeof(char));
+				app = xnrealloc(app, app_len + tlen + 2, sizeof(char));
 				xstrsncpy(app, t, app_len + tlen + 1);
 				free(t);
 			}
@@ -1067,9 +990,10 @@ get_apps_from_file(FILE *fp, char *file_name, const char *mime,
 				}
 			}
 
-			/* Do not allow APP to be plain "clifm", since
-			 * nested executions of clifm are not allowed. */
-			else if (*app == PROGRAM_NAME[0] && strcmp(app, PROGRAM_NAME) == 0) {
+			/* If running in stealth mode, do not allow APP to be plain
+			 * "clifm", since nested executions of clifm are not allowed. */
+			else if (xargs.stealth_mode == 1 && *app == PROGRAM_NAME[0]
+			&& strcmp(app, PROGRAM_NAME) == 0) {
 				;
 			} else if (*app == '/') {
 				if (access(app, X_OK) == 0) {
@@ -1084,8 +1008,10 @@ get_apps_from_file(FILE *fp, char *file_name, const char *mime,
 			if (ret && only_names == 0)
 				*ret = ' ';
 
-			if (!file_path)
+			if (!file_path) {
+				free(appb);
 				continue;
+			}
 
 			/* If the app exists, store it into the APPS array */
 			if (*app != '/') {
@@ -1140,12 +1066,12 @@ construct_filename(char *filename)
 		}
 
 		free(name);
-		name = realpath(deq_file, NULL);
+		name = xrealpath(deq_file, NULL);
 		free(deq_file);
 	}
 
 	if (!name) {
-		name = realpath(filename, NULL);
+		name = xrealpath(filename, NULL);
 		if (!name)
 			return (char *)NULL;
 	}
@@ -1172,7 +1098,7 @@ mime_open_with_tab(char *filename, const char *prefix, const int only_names)
 #ifndef _NO_MAGIC
 	char *mime = xmagic(name, MIME_TYPE);
 #else
-	err_name = "lira";
+	err_name = "open";
 	char *mime = get_mime(name);
 #endif /* !_NO_MAGIC */
 	if (!mime) {
@@ -1369,19 +1295,20 @@ mime_open_with(char *filename, char **args)
 	if (!filename || !mime_file)
 		return FUNC_FAILURE;
 
-	err_name = "lira";
-
-	char *name = normalize_path(filename, strlen(filename));
-	if (!name)
+	err_name = "open";
+	char *deq = unescape_str(filename, 0);
+	if (!deq)
 		return FUNC_FAILURE;
 
-	struct stat a;
-	if (lstat(name, &a) == -1) {
-		xerror("%s: '%s': %s\n", err_name, filename, strerror(errno));
-		free(name);
+	char *name = xrealpath(deq, NULL);
+	if (!name) {
+		xerror("%s: '%s': %s\n", err_name, deq, strerror(errno));
+		free(deq);
 		return errno;
 	}
 
+	free(deq);
+
 	/* ow FILE APP [ARGS]
 	 * We already have the opening app. Just join the app, option
 	 * parameters, and file name, and execute the command. */
@@ -1398,12 +1325,16 @@ mime_open_with(char *filename, char **args)
 #else
 	char *mime = get_mime(name);
 #endif /* !_NO_MAGIC */
-	if (!mime)
+	if (!mime) {
+		xerror(_("%s: Error getting MIME type\n"), err_name);
 		goto FAIL;
+	}
 
 	FILE *fp = fopen(mime_file, "r");
-	if (!fp)
+	if (!fp) {
+		xerror("%s: '%s': %s\n", err_name, mime_file, strerror(errno));
 		goto FAIL;
+	}
 
 	char **apps = get_apps_from_file(fp, name, mime, NULL, 0);
 
@@ -1411,6 +1342,9 @@ mime_open_with(char *filename, char **args)
 	free(mime);
 
 	if (!apps) {
+		xerror(_("%s: No opening application found\n"
+			"Tip: Run 'APP FILE', or 'mm edit' to add an opening "
+			"application\n"), err_name);
 		free(name);
 		return FUNC_FAILURE;
 	}
@@ -1487,11 +1421,11 @@ mime_info(char *arg, char **fpath, char **deq)
 
 	if (strchr(arg, '\\')) {
 		*deq = unescape_str(arg, 0);
-		*fpath = realpath(*deq, NULL);
+		*fpath = xrealpath(*deq, NULL);
 		free(*deq);
 		*deq = (char *)NULL;
 	} else {
-		*fpath = realpath(arg, NULL);
+		*fpath = xrealpath(arg, NULL);
 	}
 
 	if (!*fpath) {
@@ -1525,13 +1459,13 @@ get_open_file_path(char **args, char **fpath, char **deq)
 	/* Only dequote the file name if coming from the mime command */
 	if (*args[0] == 'm' && strchr(f, '\\')) {
 		*deq = unescape_str(f, 0);
-		*fpath = realpath(*deq, NULL);
+		*fpath = xrealpath(*deq, NULL);
 		free(*deq);
 		*deq = (char *)NULL;
 	}
 
 	if (!*fpath) {
-		*fpath = realpath(f, NULL);
+		*fpath = xrealpath(f, NULL);
 		if (!*fpath) {
 			xerror("%s: '%s': %s\n", err_name, f, strerror(errno));
 			return errno;
@@ -1585,7 +1519,7 @@ handle_no_app(const int info, char **fpath, char **mime, const char *arg)
 static int
 print_error_no_mime(char **fpath)
 {
-	xerror(_("%s: Error getting mime-type\n"), err_name);
+	xerror(_("%s: Error getting MIME type\n"), err_name);
 	free(*fpath);
 	return FUNC_FAILURE;
 }
@@ -1728,19 +1662,23 @@ mime_open(char **args)
 		return run_archiver(&file_path, &app);
 #endif /* !_NO_ARCHIVING */
 
+	int ret = 0;
 #ifdef __CYGWIN__
-	// Some Windows programs, like Word and Powerpoint (but not Excel!!), do
-	// not like absolute paths when the file name contains spaces. So, let's
-	// pass the file name as it was passed to this function, without
-	// expanding it to an absolute path.
-	// This hack must be removed as soon as the real cause is discovered:
-	// why Word/Powerpoint fails to open absolute paths when the file name
-	// contains spaces?
-	free(file_path);
-	return run_mime_app(&app, &args[file_index]);
+	/* Some Windows programs, like Word and Powerpoint (but not Excel!!), do
+	 * not like absolute paths when the file name contains spaces. So, let's
+	 * pass the file name as it was passed to this function, without
+	 * expanding it to an absolute path.
+	 * This hack must be removed as soon as the real cause is discovered:
+	 * why Word/Powerpoint fails to open absolute paths when the file name
+	 * contains spaces? */
+	ret = run_mime_app(app, args[file_index]);
 #else
-	return run_mime_app(&app, &file_path);
+	ret = run_mime_app(app, file_path);
 #endif /* __CYGWIN__ */
+
+	free(app);
+	free(file_path);
+	return ret;
 }
 #else
 void *_skip_me_lira;
