@@ -426,8 +426,6 @@ read_inotify(void)
 		/* Reset the inotify watch list */
 		reset_inotify();
 	}
-
-	return;
 }
 #elif defined(BSD_KQUEUE)
 /* Insert the following lines in the for loop to debug kqueue:
@@ -1424,7 +1422,7 @@ free_stuff(void)
 	}
 
 	if (dirhist_total_index) {
-		i = (int)dirhist_total_index;
+		i = dirhist_total_index;
 		while (--i >= 0)
 			free(old_pwd[i]);
 		free(old_pwd);
@@ -1757,12 +1755,12 @@ handle_stdin(void)
 	/* Max input size: 512 * (512 * 1024)
 	 * 512 chunks of 524288 bytes (512KiB) each
 	 * == (65535 * PATH_MAX)
-	 * == 262MiB of data ((65535 * PATH_MAX) / 1024) */
+	 * == 262MiB of data ((65535 * PATH_MAX) / 1024). */
 
-	size_t chunk = 512 * 1024,
-		   chunks_n = 1,
-		   total_len = 0,
-		   max_chunks = 512;
+	size_t chunk = (size_t)512 * 1024;
+	size_t chunks_n = 1;
+	size_t total_len = 0;
+	size_t max_chunks = 512;
 
 	ssize_t input_len = 0;
 
@@ -1990,30 +1988,44 @@ unpin_dir(void)
 	return FUNC_SUCCESS;
 }
 
-void
-free_software(void)
-{
-	puts(_(FREE_SOFTWARE));
-}
-
 void
 version_function(void)
 {
-#ifndef _BE_POSIX
-	const char *posix = "";
-#else
-	const char *posix = "-POSIX";
+	char *posix = "";
+	char *legacy = "";
+	char *suckless = "";
+	char *paranoid = "";
+
+#ifdef _BE_POSIX
+	posix = "-POSIX";
 #endif /* _BE_POSIX */
-	printf(_("%s %s%s (%s)\n%s\nLicense %s\nWritten by %s\n"), PROGRAM_NAME,
-		VERSION, posix, DATE, CONTACT, LICENSE, AUTHOR);
+
+#ifdef CLIFM_LEGACY
+	legacy = "-LEGACY";
+#endif /* CLIFM_LEGACY */
+
+#ifdef CLIFM_SUCKLESS
+	suckless = "-SUCKLESS";
+#endif /* CLIFM_SUCKLESS */
+
+#ifdef SECURITY_PARANOID
+# if SECURITY_PARANOID > 0
+	paranoid = "-PARANOID";
+# endif
+#endif /* SECURITY_PARANOID */
+
+	printf(_("%s %s%s%s%s%s (%s)\n%s\nLicense %s\nWritten by %s\n"),
+		PROGRAM_NAME, VERSION, posix, legacy, suckless, paranoid,
+		DATE, CONTACT, LICENSE, AUTHOR);
 }
 
 void
 splash(void)
 {
+	const char *reg_cyan = conf.colorize == 1 ? "\x1b[0;36m" : "";
 	printf("\n%s%s\n\n%s%s\t\t       %s%s\n           %s\n",
-		conf.colorize ? REG_CYAN : "", ASCII_LOGO_BIG, df_c,
-		BOLD, df_c, PROGRAM_NAME_UPPERCASE, _(PROGRAM_DESC));
+		reg_cyan, ASCII_LOGO_BIG, df_c, BOLD, df_c,
+		PROGRAM_NAME_UPPERCASE, PROGRAM_DESC);
 
 	HIDE_CURSOR;
 	if (conf.splash_screen) {
