@@ -37,6 +37,10 @@
 #include <time.h>
 #include <errno.h>
 
+#if defined(MAC_OS_X_RENAMEAT_SYS_STDIO_H)
+# include <sys/stdio.h> /* renameat(2) */
+#endif /* MAC_OS_X_RENAMEAT_SYS_STDIO_H */
+
 #include "aux.h"
 #include "cleaner_table.h"
 #include "file_operations.h"
@@ -74,11 +78,11 @@
 # Edit replacement file names as you wish, save, and close the editor.\n\
 # You will be asked for confirmation at exit.\n\n"
 
-#define check_width(chr, size) if ((chr & UTF_8_ENCODED_ ## size ## _BYTES_MASK) == UTF_8_ENCODED_ ## size ## _BYTES) { return size; }
-#define unpack_start(chr, size) ((unsigned char) chr & ~UTF_8_ENCODED_ ## size ## _BYTES_MASK)
-#define unpack_cont(chr) ((unsigned char) chr & ~UTF_8_ENCODED_MASK)
+#define check_width(chr, size) if (((chr) & UTF_8_ENCODED_ ## size ## _BYTES_MASK) == UTF_8_ENCODED_ ## size ## _BYTES) { return size; }
+#define unpack_start(chr, size) ((unsigned char)(chr) & ~UTF_8_ENCODED_ ## size ## _BYTES_MASK)
+#define unpack_cont(chr) ((unsigned char)(chr) & ~UTF_8_ENCODED_MASK)
 
-struct  bleach_t {
+struct bleach_t {
 	char *original;
 	char *replacement;
 };
@@ -102,9 +106,9 @@ get_utf_8_width(const char c)
 }
 
 /* Replace unsafe characters by safe, portable ones.
- * a-zA-Z0-9._- (Portable Filename Character Set) are kept
- * {[()]} are replaced by a dash (-)
- * Everything else is replaced by an underscore (_) */
+ * a-zA-Z0-9._- (Portable Filename Character Set) are kept.
+ * {[()]} are replaced by a dash (-).
+ * Everything else is replaced by an underscore (_). */
 static int
 translate_unsafe_char(const unsigned char c)
 {
@@ -122,12 +126,12 @@ translate_unsafe_char(const unsigned char c)
 }
 
 static int
-get_uft8_dec_value(size_t *i, char *str)
+get_uft8_dec_value(size_t *i, const char *str)
 {
 	unsigned char c = (unsigned char)str[*i];
 	int new_value = 0;
 
-	int utf8_width = get_utf_8_width((char)c);
+	const int utf8_width = get_utf_8_width((char)c);
 	switch (utf8_width) {
 		case 1: new_value = (unsigned char)str[0]; break;
 		case 2: new_value = unpack_start(c, 2); break;
@@ -212,7 +216,7 @@ clean_file_name(char *restrict name)
 			continue;
 		}
 
-		if (n <= 126) {
+		if (n <= 127) {
 			int ret = translate_unsafe_char(n);
 			if (ret == -1)
 				continue;
@@ -496,6 +500,7 @@ bleach_files(char **names)
 		return FUNC_SUCCESS;
 	}
 
+	int do_edit = 0, edited_names = 0;
 	struct bleach_t *bfiles = (struct bleach_t *)NULL;
 
 	size_t f = 0, i = 1;
@@ -548,19 +553,20 @@ bleach_files(char **names)
 		return FUNC_SUCCESS;
 	}
 
-	int rename = 0;
+	int rename = 0, quit_func = 0;
 	char *input = (char *)NULL;
 
 CONFIRM:
-	putchar('\n');
-	int _edit = 0, edited_names = 0;
-
 	while (!input) {
 		input = rl_no_hist(_("Is this OK? [y/n/(e)dit] "));
 
 		if (!input)
 			continue;
 
+		if (strcmp(input, "yes") == 0 || strcmp(input, "no") == 0
+		|| strcmp(input, "edit") == 0)
+			input[1] = '\0';
+
 		if (input[1] || !strchr("yYnNeEq", *input)) {
 			free(input);
 			input = (char *)NULL;
@@ -570,8 +576,11 @@ CONFIRM:
 		switch (*input) {
 		case 'y': /* fallthrough */
 		case 'Y': rename = 1; break;
+		case 'q': /* fallthrough */
+		case 'n': /* fallthrough */
+		case 'N': quit_func = 1; break;
 		case 'e':
-			_edit = 1;
+			do_edit = 1;
 			bfiles = edit_replacements(bfiles, &f, &edited_names);
 			if (!bfiles || edited_names == -1)
 				break;
@@ -600,19 +609,19 @@ CONFIRM:
 		return FUNC_SUCCESS;
 	}
 
-	if (edited_names == -1) { /* ERROR */
+	if (edited_names == -1 || quit_func == 1) { /* ERROR or quit */
 		for (i = 0; i < f; i++) {
 			free(bfiles[i].original);
 			free(bfiles[i].replacement);
 		}
 		free(bfiles);
-		return FUNC_FAILURE;
+		return (quit_func == 1 ? FUNC_SUCCESS : FUNC_FAILURE);
 	}
 
 	/* The user entered 'e' to edit the file, but nothing was modified
 	 * Ask for confirmation in case the user just wanted to see what would
 	 * be done. */
-	if (_edit == 1) {
+	if (do_edit == 1) {
 		printf(_("%zu file name(s) will be bleached\n"), f);
 		if (rl_get_y_or_n(_("Continue? [y/n] ")) != 1) {
 			for (i = 0; i < f; i++) {
@@ -642,8 +651,9 @@ CONFIRM:
 			while (lstat(r, &a) == 0) {
 				char tmp[PATH_MAX + 1];
 				xstrsncpy(tmp, r, sizeof(tmp));
-				r = xnrealloc(r, PATH_MAX + 32, sizeof(char));
-				snprintf(r, PATH_MAX + 31, "%s-%zu", tmp, rep_suffix);
+				const size_t len = PATH_MAX + MAX_INT_STR + 2;
+				r = xnrealloc(r, len, sizeof(char));
+				snprintf(r, len, "%s-%zu", tmp, rep_suffix);
 				rep_suffix++;
 			}
 
