@@ -32,6 +32,10 @@
 #include <unistd.h>
 #include <readline/history.h>
 
+#if defined(MAC_OS_X_RENAMEAT_SYS_STDIO_H)
+# include <sys/stdio.h> /* renameat(2) */
+#endif /* MAC_OS_X_RENAMEAT_SYS_STDIO_H */
+
 #include "aux.h"
 #include "bookmarks.h"
 #include "checks.h"
@@ -128,6 +132,8 @@ profile_set(const char *prof)
 	if (!prof)
 		return FUNC_FAILURE;
 
+	dir_cmds.first_cmd_in_dir = UNSET;
+
 	/* Check if prof is a valid profile */
 	int found = check_profile(prof);
 	if (found == -1) {
@@ -178,13 +184,6 @@ profile_set(const char *prof)
 	}
 	usrvar_n = 0;
 
-	i = (int)kbinds_n;
-	while (--i >= 0) {
-		free(kbinds[i].function);
-		free(kbinds[i].key);
-	}
-	kbinds_n = 0;
-
 	i = (int)actions_n;
 	while (--i >= 0) {
 		free(usr_actions[i].name);
@@ -238,7 +237,7 @@ profile_set(const char *prof)
 		free(paths);
 	}
 
-	path_n = (size_t)get_path_env(1);
+	path_n = get_path_env(1);
 	get_path_programs();
 
 	if (conf.restore_last_path == 1)
