@@ -60,7 +60,7 @@ gen_time(const int c)
 	struct tm tm;
 
 	if (!localtime_r(&rawtime, &tm)) {
-		temp = savestring("?", 1);
+		temp = savestring(UNKNOWN_STR, sizeof(UNKNOWN_STR) - 1);
 	} else if (c == 't') {
 		char time[9] = "";
 		strftime(time, sizeof(time), "%H:%M:%S", &tm);
@@ -184,7 +184,7 @@ static inline char *
 gen_exit_status(void)
 {
 	const size_t code_len = (size_t)DIGINUM(exit_code);
-	const size_t len = code_len + 3 + (MAX_COLOR * 2);
+	const size_t len = code_len + 3 + ((size_t)MAX_COLOR * 2);
 
 	char *temp = xnmalloc(len, sizeof(char));
 	snprintf(temp, len, "%s%d\001%s\002",
@@ -256,7 +256,7 @@ gen_user_name(void)
 	char *temp = (char *)NULL;
 
 	if (!user.name)
-		temp = savestring("?", 1);
+		temp = savestring(UNKNOWN_STR, sizeof(UNKNOWN_STR) - 1);
 	else
 		temp = savestring(user.name, strlen(user.name));
 
@@ -282,7 +282,7 @@ static inline char *
 gen_user_flag(void)
 {
 	char *temp = xnmalloc(2, sizeof(char));
-	*temp = user.uid == 0 ? '#' : '$';
+	*temp = user.uid == 0 ? ROOT_USR_CHAR : NON_ROOT_USR_CHAR;
 	temp[1] = '\0';
 
 	return temp;
@@ -294,7 +294,7 @@ gen_mode(void)
 	char *temp = xnmalloc(2, sizeof(char));
 
 	if (conf.light_mode == 1) {
-		*temp = 'L';
+		*temp = LIGHT_MODE_CHAR;
 		temp[1] = '\0';
 	} else {
 		*temp = '\0';
@@ -385,16 +385,18 @@ substitute_cmd(char **line, char **res, size_t *len)
 	tmp_str[tmp + 2] = '\0';
 	*line += tmp + 1;
 
-	const char *old_value = getenv("IFS");
+	char *old_value = xgetenv("IFS", 1);
 	setenv("IFS", "", 1);
 
 	wordexp_t wordbuf;
 	if (wordexp(tmp_str, &wordbuf, 0) != FUNC_SUCCESS) {
 		free(tmp_str);
 		reset_ifs(old_value);
+		free(old_value);
 		return;
 	}
 	reset_ifs(old_value);
+	free(old_value);
 	free(tmp_str);
 
 	if (wordbuf.we_wordc) {
@@ -411,7 +413,6 @@ substitute_cmd(char **line, char **res, size_t *len)
 	}
 
 	wordfree(&wordbuf);
-	return;
 }
 #endif /* !__HAIKU__ && !__OpenBSD__ && !__ANDROID__ */
 
@@ -424,8 +425,7 @@ gen_emergency_prompt(void)
 		xerror("%s: %s\n", PROGRAM_NAME, EMERGENCY_PROMPT_MSG);
 	}
 
-	char *_prompt = savestring(EMERGENCY_PROMPT, sizeof(EMERGENCY_PROMPT) - 1);
-	return _prompt;
+	return savestring(EMERGENCY_PROMPT, sizeof(EMERGENCY_PROMPT) - 1);
 }
 
 static inline char *
@@ -462,8 +462,8 @@ gen_stats_str(const int flag)
 
 	char *p = (char *)NULL;
 	if (val != 0) {
-		p = xnmalloc(32, sizeof(char));
-		snprintf(p, 32, "%zu", val);
+		p = xnmalloc(MAX_INT_STR, sizeof(char));
+		snprintf(p, MAX_INT_STR, "%zu", val);
 	} else {
 		p = xnmalloc(2, sizeof(char));
 		*p = '-';
@@ -476,7 +476,7 @@ gen_stats_str(const int flag)
 static inline char *
 gen_notification(const int flag)
 {
-	const size_t len = 32;
+	const size_t len = MAX_INT_STR + 1;
 
 	char *p = xnmalloc(len, sizeof(char));
 	*p = '\0';
@@ -500,7 +500,7 @@ gen_notification(const int flag)
 		break;
 	case NOTIF_SEL:
 		if (sel_n > 0)
-			snprintf(p, len, "*%zu", sel_n);
+			snprintf(p, len, "%c%zu", SELFILE_CHR, sel_n);
 		break;
 	case NOTIF_TRASH:
 		if (trash_n > 0)
@@ -518,8 +518,8 @@ gen_nesting_level(const int mode)
 	char *p = (char *)NULL;
 
 	if (mode == 'i') {
-		p = xnmalloc(32, sizeof(char));
-		snprintf(p, 32, "%d", nesting_level);
+		p = xnmalloc(MAX_INT_STR, sizeof(char));
+		snprintf(p, MAX_INT_STR, "%d", nesting_level);
 		return p;
 	}
 
@@ -530,7 +530,7 @@ gen_nesting_level(const int mode)
 		return p;
 	}
 
-	const size_t len = (MAX_COLOR * 2) + 32;
+	const size_t len = (MAX_COLOR * 2) + MAX_INT_STR;
 	p = xnmalloc(len, sizeof(char));
 	snprintf(p, len, "(%d)", nesting_level);
 
@@ -550,11 +550,11 @@ decode_prompt(char *line)
 	size_t result_len = 0;
 	int c;
 
-	while ((c = *line++)) {
+	while ((c = (int)*line++)) {
 		/* We have an escape char */
 		if (c == '\\') {
 			/* Now move on to the next char */
-			c = *line;
+			c = (int)*line;
 			switch (c) {
 			/* Files statistics */
 			case 'B': temp = gen_stats_str(STATS_BLK); goto ADD_STRING;
@@ -740,22 +740,63 @@ trim_final_slashes(void)
 	}
 }
 
+static void
+print_user_message(void)
+{
+	char *s = conf.welcome_message_str;
+
+	if (!strchr(s, '\\')) {
+		printf("%s%s%s\n", wc_c, s, df_c);
+		return;
+	}
+
+	int c = 0;
+	char *tmp = (char *)NULL;
+
+	fputs(wc_c, stdout);
+
+	while (*s) {
+		if (*s == '\\' && *(s + 1)) {
+			s++;
+			if (*s >= '0' && *s <= '7' && (tmp = gen_octal(&s, &c))) {
+				fputs(tmp, stdout);
+				free(tmp);
+			} else if (*s == 'e' && (tmp = gen_escape_char(&s, &c))) {
+				fputs(tmp, stdout);
+				free(tmp);
+			} else if (*s == 'n') {
+				putchar('\n');
+				s++;
+			} else {
+				putchar(*s);
+				s++;
+			}
+		} else {
+			putchar(*s);
+			s++;
+		}
+	}
+
+	putchar('\n');
+	fputs(df_c, stdout);
+}
+
 static inline void
 print_welcome_msg(void)
 {
-	static int wm = UNSET;
+	static int message_shown = 0;
 
-	if (wm == 0 || conf.welcome_message == 0)
+	if (message_shown == 1 || conf.welcome_message == 0)
 		return;
 
-	if (conf.welcome_message_str)
-		printf("%s%s%s\n", wc_c, conf.welcome_message_str, df_c);
+	if (conf.welcome_message_str != NULL)
+		print_user_message();
 	else
 		printf("%s%s\n%s", wc_c, DEF_WELCOME_MESSAGE_STR, df_c);
 
 	printf("%s\n", _(HELP_MESSAGE));
 
-	wm = 0;
+	message_shown = 1;
 }
 
 static inline void
@@ -825,7 +866,7 @@ setenv_prompt(void)
 	/* Set environment variables with CliFM state information
 	 * (sel files, trash, stealth mode, messages) to be handled by
 	 * the prompt itself. */
-	char t[32];
+	char t[MAX_INT_STR];
 	snprintf(t, sizeof(t), "%d", (int)sel_n);
 	setenv("CLIFM_STAT_SEL", t, 1);
 #ifndef _NO_TRASH
@@ -887,9 +928,10 @@ construct_prompt(const char *decoded_prompt)
 			snprintf(notice_ind, N_IND, "%sN%zu%s", nm_c, msgs.notice, RL_NC);
 		if (trash_n > 0)
 			snprintf(trash_ind, N_IND, "%sT%zu%s",
-				ti_c, (size_t)trash_n, RL_NC);
+				ti_c, trash_n, RL_NC);
 		if (sel_n > 0)
-			snprintf(sel_ind, N_IND, "%s*%zu%s", li_c, sel_n, RL_NC);
+			snprintf(sel_ind, N_IND, "%s%c%zu%s", li_c, SELFILE_CHR,
+				sel_n, RL_NC);
 	}
 
 	const size_t prompt_len = set_prompt_length(strlen(decoded_prompt));
