@@ -33,8 +33,14 @@
 #define CTLESC '\001'
 #define CTLNUL '\177'
 
-#define ROOT_IND "\001\x1b[1;31m\002R\001\x1b[0m\002"
-#define ROOT_IND_NO_COLOR "R"
+#ifdef __HAIKU__
+/* No need for a root indicator on Haiku: it always runs as root. */
+# define ROOT_IND ""
+# define ROOT_IND_NO_COLOR ""
+#else
+# define ROOT_IND "\001\x1b[1;31m\002R\001\x1b[0m\002"
+# define ROOT_IND_NO_COLOR "R"
+#endif /* __HAIKU__ */
 #define ROOT_IND_SIZE 17
 #define RDONLY_IND "RO\001\x1b[0m\002"
 #define RDONLY_IND_SIZE (MAX_COLOR + 8 + 1)
@@ -77,9 +83,10 @@ emergency prompt"
 #define NOTIF_NOTICE  4
 #define NOTIF_ROOT    5
 
-/* Size of the indicator for msgs, trash, and sel */
-#define N_IND MAX_COLOR + 1 + sizeof(size_t) + 6 + 1 + 13
-/* Color + 1 letter + plus unsigned integer + RL_NC size + nul char */
+/* Size of the indicator for msgs, trash, and sel. */
+#define N_IND (MAX_COLOR + 1 + 21 + (sizeof(RL_NC) - 1) + 1)
+/* Color + 1 letter + plus unsigned integer (20 digits max)
+ * + RL_NC length + nul char. */
 
 __BEGIN_DECLS
 
