@@ -860,15 +860,15 @@ get_color_age(const time_t t, char *str, const size_t len)
 	 * for 8 color shades type. This check should be removed in the future. */
 	if (date_shades_old_style == 1) {
 		if      (age <         0LL) n = 0;
-		else if (age <=    60*60LL) n = 1; /* One hour or less */
-		else if (age <= 24*60*60LL) n = 2; /* One day or less */
+		else if (age <=    60LL*60) n = 1; /* One hour or less */
+		else if (age <= 24LL*60*60) n = 2; /* One day or less */
 		else                        n = 3; /* Older */
 	} else {
 		if      (age <             0LL) n = 0;
-		else if (age <=        60*60LL) n = 1; /* One hour or less */
-		else if (age <=     24*60*60LL) n = 2; /* One day or less */
-		else if (age <=   7*24*60*60LL) n = 3; /* One weak or less */
-		else if (age <= 4*7*24*60*60LL) n = 4; /* One month or less */
+		else if (age <=        60LL*60) n = 1; /* One hour or less */
+		else if (age <=     24LL*60*60) n = 2; /* One day or less */
+		else if (age <=   7LL*24*60*60) n = 3; /* One weak or less */
+		else if (age <= 4LL*7*24*60*60) n = 4; /* One month or less */
 		else                            n = 5; /* Older */
 	}
 
@@ -1083,7 +1083,7 @@ print_file_name(char *filename, const char *color, const int follow_link,
 		? replace_invalid_chars(filename) : (char *)NULL;
 
 	char name[(NAME_MAX * sizeof(wchar_t)) + 3]; *name = '\0';
-	if (strchr(wname ? wname : filename, ' '))
+	if (detect_space(wname ? wname : filename) == 1)
 		snprintf(name, sizeof(name), "'%s'", wname ? wname : filename);
 
 	char *n = *name ? name : (wname ? wname : filename);
@@ -1091,7 +1091,7 @@ print_file_name(char *filename, const char *color, const int follow_link,
 	if (follow_link == 1) { /* 'pp' command */
 		if (link_target && *link_target) {
 			char t[PATH_MAX * sizeof(wchar_t) + 3]; *t = '\0';
-			if (strchr(link_target, ' '))
+			if (detect_space(link_target) == 1)
 				snprintf(t, sizeof(t), "'%s'", link_target);
 			printf(_("\tName: %s%s%s %s<-%s %s%s%s\n"), color,
 				*t ? t : link_target, df_c, dn_c, df_c, ln_c, n, df_c);
@@ -1115,7 +1115,7 @@ print_file_name(char *filename, const char *color, const int follow_link,
 		xreadlink(XAT_FDCWD, filename, target, sizeof(target));
 
 	char t[PATH_MAX * sizeof(wchar_t) + 3]; *t = '\0';
-	if (tlen != -1 && *target && strchr(target, ' '))
+	if (tlen != -1 && *target && detect_space(target) == 1)
 		snprintf(t, sizeof(t), "'%s'", target);
 
 	struct stat a;
@@ -1161,7 +1161,7 @@ print_capabilities(const char *filename, const int xattr)
 
 #if defined(HAVE_ACL) && defined(__linux__)
 static void
-list_acl(const acl_t acl, int *found, const acl_type_t type)
+list_acl(acl_t acl, int *found, const acl_type_t type)
 {
 	acl_entry_t entry;
 	int entryid;
@@ -1262,8 +1262,10 @@ print_file_details(char *filename, const struct stat *attr, const char file_type
 	struct passwd *owner = getpwuid(attr->st_uid);
 	struct group *group = getgrgid(attr->st_gid);
 
-	const char *id_color =
+	const char *gid_color =
 		conf.colorize == 0 ? "" : (file_perm == 1 ? dg_c : BOLD);
+	const char *uid_color =
+		conf.colorize == 0 ? "" : (file_perm == 1 ? du_c : BOLD);
 	const char *cend = conf.colorize == 1 ? df_c : "";
 
 	if (conf.colorize == 1)
@@ -1304,9 +1306,9 @@ print_file_details(char *filename, const struct stat *attr, const char file_type
 		(uintmax_t)minor(attr->st_dev), cend);
 	printf(_("\tInode: %s%ju%s"), BOLD, (uintmax_t)attr->st_ino, cend);
 
-	printf(_("  Uid: %s%u (%s)%s"), id_color, attr->st_uid, !owner
+	printf(_("  Uid: %s%u (%s)%s"), uid_color, attr->st_uid, !owner
 		? _("UNKNOWN") : owner->pw_name, cend);
-	printf(_("  Gid: %s%u (%s)%s"), id_color, attr->st_gid, !group
+	printf(_("  Gid: %s%u (%s)%s"), gid_color, attr->st_gid, !group
 		? _("UNKNOWN") : group->gr_name, cend);
 
 	if (S_ISCHR(attr->st_mode) || S_ISBLK(attr->st_mode)) {
@@ -1375,10 +1377,14 @@ gen_user_time_str(char *buf, size_t buf_size, struct tm *t, const size_t nsec)
 	if (!ptr) {
 		/* GCC (not clang) complains about format being not a string literal.
 		 * Let's silence this warning until we find a better approach. */
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wformat-nonliteral"
+#ifdef GCC_ALLOWS_PRAGMA_IN_FUNC
+# pragma GCC diagnostic push
+# pragma GCC diagnostic ignored "-Wformat-nonliteral"
+#endif /* GCC_ALLOWS_PRAGMA_IN_FUNC */
 		strftime(buf, buf_size, conf.ptime_str, t);
-#pragma GCC diagnostic pop
+#ifdef GCC_ALLOWS_PRAGMA_IN_FUNC
+# pragma GCC diagnostic pop
+#endif /* GCC_ALLOWS_PRAGMA_IN_FUNC */
 		return;
 	}
 
@@ -1391,10 +1397,14 @@ gen_user_time_str(char *buf, size_t buf_size, struct tm *t, const size_t nsec)
 	size_t len = 0;
 	*ptr = '\0';
 	if (ptr != conf.ptime_str)
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wformat-nonliteral"
+#ifdef GCC_ALLOWS_PRAGMA_IN_FUNC
+# pragma GCC diagnostic push
+# pragma GCC diagnostic ignored "-Wformat-nonliteral"
+#endif /* GCC_ALLOWS_PRAGMA_IN_FUNC */
 		len = strftime(buf, buf_size, conf.ptime_str, t);
-#pragma GCC diagnostic pop
+#ifdef GCC_ALLOWS_PRAGMA_IN_FUNC
+# pragma GCC diagnostic pop
+#endif /* GCC_ALLOWS_PRAGMA_IN_FUNC */
 
 	*ptr = '%';
 	if (len == 0 && ptr != conf.ptime_str) /* Error or exhausted space in BUF. */
@@ -1408,12 +1418,14 @@ gen_user_time_str(char *buf, size_t buf_size, struct tm *t, const size_t nsec)
 	if (!*ptr)
 		return;
 
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wformat-nonliteral"
+#ifdef GCC_ALLOWS_PRAGMA_IN_FUNC
+# pragma GCC diagnostic push
+# pragma GCC diagnostic ignored "-Wformat-nonliteral"
+#endif /* GCC_ALLOWS_PRAGMA_IN_FUNC */
 	strftime(buf + len, buf_size - len, ptr, t);
-#pragma GCC diagnostic pop
-
-	return;
+#ifdef GCC_ALLOWS_PRAGMA_IN_FUNC
+# pragma GCC diagnostic pop
+#endif /* GCC_ALLOWS_PRAGMA_IN_FUNC */
 }
 
 /* Write into BUF, whose size is SIZE, the timestamp TIM, with nanoseconds NSEC,
@@ -1585,7 +1597,7 @@ print_file_mime(const char *name)
 	return;
 #else
 	fputs("MIME type:\t", stdout);
-	char *n = xmagic(name, 1);
+	char *n = xmagic(name, MIME_TYPE);
 	if (n) {
 		printf("%s\n", n);
 		free(n);
@@ -1819,7 +1831,7 @@ print_dir_info(const char *dir, const int file_perm)
 		snprintf(read_err, sizeof(read_err), "%s%c%s", xf_cb, DU_ERR_CHAR, df_c);
 
 	char *cend = conf.colorize == 1 ? df_c : "";
-	char *size_color = (char *)NULL;
+	char *size_color = dz_c;
 	char sf[MAX_SHADE_LEN]; *sf = '\0';
 	if (conf.colorize == 1 && !*dz_c) {
 		get_color_size(info.size, sf, sizeof(sf));
@@ -2035,35 +2047,44 @@ print_analysis_stats(const off_t total, const off_t largest,
 	if (prop_fields.size == PROP_SIZE_HUMAN) {
 		const char *p_total = construct_human_size(total);
 		t = savestring(p_total, strlen(p_total));
-		const char *p_largest = construct_human_size(largest);
-		l = savestring(p_largest, strlen(p_largest));
+		if (conf.sort != STSIZE) {
+			const char *p_largest = construct_human_size(largest);
+			l = savestring(p_largest, strlen(p_largest));
+		}
 	} else {
-		t = xnmalloc(32, sizeof(char));
-		l = xnmalloc(32, sizeof(char));
-		snprintf(t, 32, "%ju", (uintmax_t)total);
-		snprintf(l, 32, "%ju", (uintmax_t)largest);
+		t = xnmalloc(MAX_INT_STR, sizeof(char));
+		snprintf(t, MAX_INT_STR, "%ju", (uintmax_t)total);
+		if (conf.sort != STSIZE) {
+			l = xnmalloc(MAX_INT_STR, sizeof(char));
+			snprintf(l, MAX_INT_STR, "%ju", (uintmax_t)largest);
+		}
 	}
 
-	char *tsize = BOLD_GREEN, *lsize = BOLD_GREEN;
+	char *tsize = dz_c, *lsize = dz_c;
 
 	char ts[MAX_SHADE_LEN], ls[MAX_SHADE_LEN];
-	if (term_caps.color > 0 && !*dz_c) {
+	if (!*dz_c) {
 		get_color_size(total, ts, sizeof(ts));
 		tsize = ts;
-		get_color_size(largest, ls, sizeof(ls));
-		lsize = ls;
+		if (conf.sort != STSIZE) {
+			get_color_size(largest, ls, sizeof(ls));
+			lsize = ls;
+		}
 	}
 
-	printf(_("Total size:   %s%s%s\n"
-		"Largest file: %s%s%s %c%s%s%s%c\n"),
+	printf(_("Total size: %s%s%s%s\n"), conf.sort != STSIZE ? "  " : "",
 		conf.colorize == 1 ? tsize : "" , t ? t : UNKNOWN_STR,
-		conf.colorize == 1 ? tx_c : "",
-		conf.colorize == 1 ? lsize : "" , l ? l : UNKNOWN_STR,
-		conf.colorize == 1 ? tx_c : "",
-		name ? '[' : 0,
-		(conf.colorize == 1 && color) ? color : "",
-		name ? name : "", tx_c,
-		name ? ']' : 0);
+		conf.colorize == 1 ? tx_c : "");
+
+	if (conf.sort != STSIZE) {
+		printf(_("Largest file: %s%s%s %s%s%s%s%s\n"),
+			conf.colorize == 1 ? lsize : "" , l ? l : UNKNOWN_STR,
+			conf.colorize == 1 ? tx_c : "",
+			name ? "[" : "",
+			(conf.colorize == 1 && color) ? color : "",
+			name ? name : "", tx_c,
+			name ? "]" : "");
+	}
 
 	free(t);
 	free(l);
