@@ -40,18 +40,18 @@
  * /usr/local/share/clifm/colors/). */
 #define DEF_FILE_COLORS "bd=1;33:ca=30;41:cd=1:di=1;34:ed=2;34:\
 ee=32:ef=2:ex=1;32:fi=0:ln=1;36:mh=30;46:nd=4;1;31:nf=2;4;31:\
-no=31;47:or=2;4;36:ow=34;42:pi=35:so=1;35:su=37;41:sg=30;43:st=37;44:\
-tw=30;42:uf=2;4;37:"
+no=31;47:or=2;4;36:ow=34;40:pi=4;45;37:so=45;37:su=37;41:sg=30;43:st=37;44:\
+tw=37;42:uf=2;4;37:"
 
-#define DEF_IFACE_COLORS "bm=1;36:db=:dd=:de=:df=0:dg=:dk=:dl=2;37:\
-dn=0;2;37:do=:dp=:dr=:dw=:dxd=:dxr=:dz=:\
-el=0;36:em=1;31:fc=0;2;37:hb=0;36:hc=2;31:lc=:\
-hd=0;36:he=0;36:hn=0:hp=0;36:hq=0;33:hr=0;31:hs=0;32:hv=0;32:\
-li=1;32:mi=1;36:nm=1;32:ro=:sb=0;2;33:sc=2;36:sd=0;2;37:\
-sf=4;2;36:sh=2;35:si=1;34:sp=02;31:sx=02;32:sz=0;2;4;35:\
+#define DEF_IFACE_COLORS "db=:dd=:de=:df=0:dg=2;35:dk=:dl=2;37:\
+dn=2;37:do=:dp=:dr=:dt=:du=35:dw=:dxd=:dxr=:dz=:\
+el=36:em=1;31:fc=2;37:hb=36:hc=2;31:lc=:\
+hd=36:he=0;36:hn=0:hp=36:hq=33:hr=31:hs=32:hv=32:\
+li=1;32:mi=1;36:nm=1;32:ro=:sb=2;33:sc=2;36:sd=2;37:\
+sf=4;2;36:sh=2;37:si=1;34:sp=2;31:sx=2;32:sz=4;2;36:\
 ti=1;36:ts=4;35:tt=2;1;36:tx=0:\
 wc=1;36:wm=1;33:ws1=34:ws2=31:ws3=33:ws4=32:ws5=36:ws6=36:ws7=36:ws8=36:\
-xf=1;31:xs=0;32:"
+xf=1;31:xs=32:"
 
 /* If ExtColors is not defined in the color scheme file (or if this file isn't
  * found), DEF_EXT_COLORS is used instead. */
@@ -110,18 +110,17 @@ xf=1;31:xs=0;32:"
 #ifdef __sun
 #define DEF_OO_C  "\x1b[0;35m"    /* Solaris door/port (ls default is 1;35) */
 #endif /* __sun */
-#define DEF_OR_C  "\x1b[2;4;36m" /* Orphaned/broken symlink */
-#define DEF_OW_C  "\x1b[34;42m"  /* Other-writable */
-#define DEF_PI_C  "\x1b[0;35m"   /* FIFO/pipe */
-#define DEF_SG_C  "\x1b[30;43m"  /* SGID file */
-#define DEF_SO_C  "\x1b[1;35m"   /* Socket */
-#define DEF_ST_C  "\x1b[37;44m"  /* Sticky bit set */
-#define DEF_SU_C  "\x1b[37;41m"  /* SUID file */
-#define DEF_TW_C  "\x1b[30;42m"  /* Sticky and other-writable */
-#define DEF_UF_C  "\x1b[2;4;37m" /* Un'stat'able file */
+#define DEF_OR_C  "\x1b[2;4;36m"  /* Orphaned/broken symlink */
+#define DEF_OW_C  "\x1b[34;40m"   /* Other-writable */
+#define DEF_PI_C  "\x1b[4;45;37m" /* FIFO/pipe */
+#define DEF_SG_C  "\x1b[30;43m"   /* SGID file */
+#define DEF_SO_C  "\x1b[45;37m"   /* Socket */
+#define DEF_ST_C  "\x1b[37;44m"   /* Sticky bit set */
+#define DEF_SU_C  "\x1b[37;41m"   /* SUID file */
+#define DEF_TW_C  "\x1b[37;42m"   /* Sticky and other-writable */
+#define DEF_UF_C  "\x1b[2;4;37m"  /* Un'stat'able file */
 
 /* Interface */
-#define DEF_BM_C  "\x1b[1;36m"   /* Bookmarked dirs in bookmarks screen */
 #define DEF_DF_C  "\x1b[0m"      /* Reset attributes: default terminal color */
 #define DEF_DL_C  "\x1b[2;37m"   /* Dividing line */
 #define DEF_EL_C  "\x1b[0;36m"   /* ELN's */
@@ -140,7 +139,6 @@ xf=1;31:xs=0;32:"
 
 /* Symlink char indicator (for ColorLinksAsTarget only) */
 #define DEF_LC_C  "\x1b[1;36m"
-//#define DEF_LC_C_256  "\x1b[0;38;5;43m"
 
 #define DEF_TS_C  "\x1b[4;35m" /* Matching prefix for TAB completed possible entries */
 #define DEF_TT_C  "\x1b[1;2;36m" /* Tilde for trimmed file names */
@@ -163,11 +161,11 @@ xf=1;31:xs=0;32:"
 #define DEF_SB_C  "\x1b[2;33m"   /* Shell built-ins */
 #define DEF_SC_C  "\x1b[2;36m"   /* Aliases and binaries in PATH */
 #define DEF_SD_C  "\x1b[2;37m"   /* Internal commands description */
-#define DEF_SH_C  "\x1b[2;35m"   /* Commands history */
+#define DEF_SH_C  "\x1b[2;37m"   /* Commands history */
 #define DEF_SF_C  "\x1b[2;4;36m" /* ELN's, bookmark, file, and directory names */
 #define DEF_SP_C  "\x1b[2;31m"   /* Suggestions pointer (12 > filename) */
 #define DEF_SX_C  "\x1b[2;32m"   /* Internal commands and parameters */
-#define DEF_SZ_C  "\x1b[2;4;35m" /* File names (fuzzy) */
+#define DEF_SZ_C  "\x1b[2;4;36m" /* File names (fuzzy) */
 
 /* Highlight */
 #define DEF_HB_C  "\x1b[0;36m" /* Parenthesis, Brackets ( {[()]} ) */
@@ -183,22 +181,22 @@ xf=1;31:xs=0;32:"
 #define DEF_HW_C  "\x1b[1;31m" /* Backslash (aka whack) */
 
 /* Colors for the properties and long/detail view functions */
-#define DEF_DB_C  "\x1b[0;33m" /* File allocated blocks */
-#define DEF_DD_C  "\x1b[0;36m" /* Modification date */
-#define DEF_DE_C  "\x1b[0;36m" /* Inode number (long view only) */
-#define DEF_DG_C  "\x1b[0;35m" /* UID, GID */
-#define DEF_DK_C  "\x1b[0;31m" /* Number of links (long view only) */
+#define DEF_DB_C  "\x1b[0;33m"   /* File allocated blocks */
+#define DEF_DD_C  "\x1b[0;36m"   /* Modification date */
+#define DEF_DE_C  "\x1b[0;36m"   /* Inode number (long view only) */
+#define DEF_DG_C  "\x1b[0;2;35m" /* Group ID */
+#define DEF_DK_C  "\x1b[0;31m"   /* Number of links (long view only) */
 #define DEF_DN_C  "\x1b[0;2;37m" /* Dash (no attribute) */
-#define DEF_DO_C  "\x1b[0;36m" /* Perms in octal */
-#define DEF_DP_C  "\x1b[0;35m" /* SUID, SGID, Sticky */
-#define DEF_DR_C  "\x1b[0;33m" /* Read perm */
-#define DEF_DW_C  "\x1b[0;31m" /* Write perm */
-#define DEF_DXD_C "\x1b[0;32m" /* Execute perm (dirs) */
-#define DEF_DXR_C "\x1b[0;36m" /* Execute perm (reg files) */
-#define DEF_DZ_C  "\x1b[0;32m" /* Size (only for dirs) */
+#define DEF_DO_C  "\x1b[0;36m"   /* Perms in octal */
+#define DEF_DP_C  "\x1b[0;35m"   /* SUID, SGID, Sticky */
+#define DEF_DR_C  "\x1b[0;33m"   /* Read perm */
+#define DEF_DU_C  "\x1b[0;35m"   /* User ID */
+#define DEF_DW_C  "\x1b[0;31m"   /* Write perm */
+#define DEF_DXD_C "\x1b[0;32m"   /* Execute perm (dirs) */
+#define DEF_DXR_C "\x1b[0;36m"   /* Execute perm (reg files) */
 
 /* Default color shades for date field in file properties */
-#define DEF_DATE_SHADES_8   "1,31-2,36-1,36,36-2,36-2,36-2"
+#define DEF_DATE_SHADES_8   "1,31-2,37-1,37,37-2,36,36-2"
 
 /* Default color shades for size field in file properties */
 #define DEF_SIZE_SHADES_8   "1,31-2,36,32,33,31,35"
@@ -211,14 +209,14 @@ xf=1;31:xs=0;32:"
 
 #define DEF_FILE_COLORS_256 "bd=1;38;5;229:ca=30;41:cd=1;38;5;214:di=1;34:\
 ed=2;34:ee=32:ef=2:ex=1;32:fi=0:ln=1;36:mh=7;36:nd=1;31:nf=2;31:no=4;31;47:\
-or=4;2;36:ow=34;42:pi=35:sg=30;43:so=1;35:st=37;44:su=37;41:tw=30;42:\
-uf=4;2;37:"
+or=4;2;36:ow=48;5;235;38;5;33:pi=38;5;5;48;5;238:sg=30;43:so=1;38;5;5;48;5;238:\
+st=37;44:su=37;41:tw=37;42:uf=4;2;37:"
 
-#define DEF_IFACE_COLORS_256 "bm=1;32:db=:dd=:de=:df=0:dg=38;5;140:\
-dk=:dl=2;37:dn=:do=:dp=:dr=:dw=:dxd=:dxr=:dz=:el=36:em=1;31:fc=38;5;246:hb=36:\
-hc=2;37:hd=36:he=36:hn=:hp=36:hq=LY:hr=31:hs=32:hv=32:lc=38;5;43:li=1;32:\
-mi=1;36:nm=1;32:ro=:si=1;34:sb=2;33:sc=2;36:sd=2;37:sf=4;2;36:sh=2;35:sp=2;31:\
-sx=2;32:sz=4;2;35:ti=1;36:ts=4;35:tt=1;2;36:tx=0:wc=1;36:wm=38;5;228:ws1=34:\
+#define DEF_IFACE_COLORS_256 "db=:dd=:de=:df=0:dg=2;35:dk=:dl=38;5;243:dn=:\
+do=:dp=:dr=:dt=:du=35:dw=:dxd=:dxr=:dz=:el=36:em=1;31:fc=38;5;246:hb=36:hc=2;37:\
+hd=36:he=36:hn=:hp=36:hq=LY:hr=31:hs=32:hv=32:lc=38;5;43:li=1;32:mi=1;36:\
+nm=1;32:ro=:si=1;34:sb=2;33:sc=2;36:sd=38;5;243:sf=4;2;36:sh=38;5;243:sp=2;31:\
+sx=2;32:sz=4;2;36:ti=1;36:ts=4;35:tt=1;2;36:tx=0:wc=1;36:wm=38;5;228:ws1=34:\
 ws2=31:ws3=38;5;228:ws4=32:ws5=36:ws6=38;5;214:ws7=35:ws8=2;37:xf=1;31:xs=32:"
 
 #define DEF_EXT_COLORS_256 "*.tar=1;31:*.tgz=1;31:*.arc=1;31:*.arj=1;31:\
@@ -258,37 +256,36 @@ ws2=31:ws3=38;5;228:ws4=32:ws5=36:ws6=38;5;214:ws7=35:ws8=2;37:xf=1;31:xs=32:"
 *.old=38;5;247:*.orig=38;5;247:*.rej=38;5;247:*.swp=38;5;247:*.pid=38;5;247:"
 
 /* File types */
-#define DEF_BD_C256  "\x1b[1;38;5;229m"    /* Block device */
-#define DEF_CA_C256  "\x1b[30;41m"   /* File with capabilities */
-#define DEF_CD_C256  "\x1b[1;38;5;214m"     /* Character device */
-#define DEF_DI_C256  "\x1b[1;34m"    /* Dir */
-#define DEF_ED_C256  "\x1b[2;34m"    /* Empty dir */
-#define DEF_EE_C256  "\x1b[0;32m"    /* Empty executable file */
-#define DEF_EF_C256  "\x1b[0;2m"     /* Empty regular file */
-#define DEF_EX_C256  "\x1b[1;32m"    /* Executable file */
-#define DEF_FI_C256  "\x1b[0m"       /* Regular file */
-#define DEF_LN_C256  "\x1b[1;36m"    /* Symbolic link */
-#define DEF_MH_C256  "\x1b[7;36m"    /* Multi-link */
-#define DEF_ND_C256  "\x1b[1;31m"    /* Unaccessible dir */
-#define DEF_NF_C256  "\x1b[2;31m"    /* Unaccessible file */
-#define DEF_NO_C256  "\x1b[4;31;47m" /* Unknown file type */
+#define DEF_BD_C256  "\x1b[1;38;5;229m" /* Block device */
+#define DEF_CA_C256  "\x1b[30;41m"      /* File with capabilities */
+#define DEF_CD_C256  "\x1b[1;38;5;214m" /* Character device */
+#define DEF_DI_C256  "\x1b[1;34m"       /* Dir */
+#define DEF_ED_C256  "\x1b[2;34m"       /* Empty dir */
+#define DEF_EE_C256  "\x1b[0;32m"       /* Empty executable file */
+#define DEF_EF_C256  "\x1b[0;2m"        /* Empty regular file */
+#define DEF_EX_C256  "\x1b[1;32m"       /* Executable file */
+#define DEF_FI_C256  "\x1b[0m"          /* Regular file */
+#define DEF_LN_C256  "\x1b[1;36m"       /* Symbolic link */
+#define DEF_MH_C256  "\x1b[7;36m"       /* Multi-link */
+#define DEF_ND_C256  "\x1b[1;31m"       /* Unaccessible dir */
+#define DEF_NF_C256  "\x1b[2;31m"       /* Unaccessible file */
+#define DEF_NO_C256  "\x1b[4;31;47m"    /* Unknown file type */
 #ifdef __sun
 #define DEF_OO_C256  "\x1b[0;35m"    /* Solaris door/port (ls default is 1;35) */
 #endif /* __sun */
 #define DEF_OR_C256  "\x1b[2;4;36m" /* Orphaned/broken symlink */
-#define DEF_OW_C256  "\x1b[34;42m"  /* Other-writable */
-#define DEF_PI_C256  "\x1b[35m"     /* FIFO/pipe */
+#define DEF_OW_C256  "\x1b[48;5;235;38;5;33m" /* Other-writable */
+#define DEF_PI_C256  "\x1b[38;5;5;48;5;238m" /* FIFO/pipe */
 #define DEF_SG_C256  "\x1b[30;43m"  /* SGID file */
-#define DEF_SO_C256  "\x1b[1;35m"   /* Socket */
+#define DEF_SO_C256  "\x1b[1;38;5;5;48;5;238m"  /* Socket */
 #define DEF_ST_C256  "\x1b[37;44m"  /* Sticky bit set */
 #define DEF_SU_C256  "\x1b[37;41m"  /* SUID file */
-#define DEF_TW_C256  "\x1b[30;42m"  /* Sticky and other-writable */
+#define DEF_TW_C256  "\x1b[37;42m"  /* Sticky and other-writable */
 #define DEF_UF_C256  "\x1b[2;4;37m" /* Un'stat'able file */
 
 /* Interface */
-#define DEF_BM_C256  "\x1b[1;32m"   /* Bookmarked dirs in bookmarks screen */
 #define DEF_DF_C256  "\x1b[0m"      /* Reset attributes: default terminal color */
-#define DEF_DL_C256  "\x1b[2;37m"   /* Dividing line */
+#define DEF_DL_C256  "\x1b[38;5;243m"   /* Dividing line */
 #define DEF_EL_C256  "\x1b[0;36m"   /* ELN's */
 #define DEF_EM_C256  "\001\x1b[1;31m\002" /* Error msg indicator */
 #define DEF_FC_C256  "\x1b[0;38;5;246m" /* Files counter */
@@ -326,12 +323,12 @@ ws2=31:ws3=38;5;228:ws4=32:ws5=36:ws6=38;5;214:ws7=35:ws8=2;37:xf=1;31:xs=32:"
 /* Suggestions */
 #define DEF_SB_C256  "\x1b[2;33m"   /* Shell built-ins */
 #define DEF_SC_C256  "\x1b[2;36m"   /* Aliases and binaries in PATH */
-#define DEF_SD_C256  "\x1b[2;37m"   /* Internal commands description */
-#define DEF_SH_C256  "\x1b[2;35m"   /* Commands history */
+#define DEF_SD_C256  "\x1b[38;5;243m"   /* Internal commands description */
+#define DEF_SH_C256  "\x1b[38;5;243m"   /* Commands history */
 #define DEF_SF_C256  "\x1b[2;4;36m" /* ELN's, bookmark, file, and directory names */
 #define DEF_SP_C256  "\x1b[2;31m"   /* Suggestions pointer (12 > filename) */
 #define DEF_SX_C256  "\x1b[2;32m"   /* Internal commands and parameters */
-#define DEF_SZ_C256  "\x1b[2;4;35m" /* File names (fuzzy) */
+#define DEF_SZ_C256  "\x1b[2;4;36m" /* File names (fuzzy) */
 
 /* Highlight */
 #define DEF_HB_C256  "\x1b[0;36m" /* Parenthesis, Brackets ( {[()]} ) */
@@ -350,16 +347,16 @@ ws2=31:ws3=38;5;228:ws4=32:ws5=36:ws6=38;5;214:ws7=35:ws8=2;37:xf=1;31:xs=32:"
 #define DEF_DB_C256  "\x1b[0;38;5;214m" /* File allocated blocks */
 #define DEF_DD_C256  "\x1b[0;36m"       /* Modification date */
 #define DEF_DE_C256  "\x1b[0;38;5;79m"  /* Inode number (long view only) */
-#define DEF_DG_C256  "\x1b[0;38;5;140m" /* UID, GID */
+#define DEF_DG_C256  "\x1b[0;2;35m"     /* Group ID */
 #define DEF_DK_C256  "\x1b[0;38;5;197m" /* Number of links (long view only) */
 #define DEF_DN_C256  "\x1b[0;2;37m"     /* Dash (no attribute) */
 #define DEF_DO_C256  "\x1b[0;38;5;79m"  /* Perms in octal */
 #define DEF_DP_C256  "\x1b[0;38;5;140m" /* SUID, SGID, Sticky */
 #define DEF_DR_C256  "\x1b[0;38;5;228m" /* Read perm */
+#define DEF_DU_C256  "\x1b[0;35m"       /* User ID */
 #define DEF_DW_C256  "\x1b[0;38;5;197m" /* Write perm */
 #define DEF_DXD_C256 "\x1b[0;38;5;77m"  /* Execute perm (dirs) */
 #define DEF_DXR_C256 "\x1b[0;38;5;79m"  /* Execute perm (reg files) */
-#define DEF_DZ_C256  "\x1b[0;32m"       /* Size (only for dirs) */
 
 /* Default color shades for date field in file properties */
 #define DEF_DATE_SHADES_256 "2,197-2,231,253,250,247,244"
@@ -373,7 +370,6 @@ ws2=31:ws3=38;5;228:ws4=32:ws5=36:ws6=38;5;214:ws7=35:ws8=2;37:xf=1;31:xs=32:"
 #define UNKNOWN_CHR     '?'
 /* Same as UNKNOWN_CHR, but as a string */
 #define UNKNOWN_STR     "?"
-#define UNKNOWN_STR_LEN 1
 
 /* Characters used to classify files when running colorless (and classify
  * is enabled) */
@@ -419,10 +415,18 @@ ws2=31:ws3=38;5;228:ws4=32:ws5=36:ws6=38;5;214:ws7=35:ws8=2;37:xf=1;31:xs=32:"
  * invalid UTF-8 char) in file names. */
 #define INVALID_CHR '^'
 
-/* String used for the messages pointer (ex: "-> 2 file(s) removed")
+/* A few identifiers used in the prompt */
+#define ROOT_USR_CHAR     '#'
+#define NON_ROOT_USR_CHAR '$'
+#define LIGHT_MODE_CHAR   'L'
+
+/* String used for the messages pointer (e.g.: "-> 2 file(s) removed")
  * Note: The color used for this string is 'mi' (in the color scheme file). */
 #define MSG_PTR_STR "->"
 
+/* Character used to print non-matching suggestions, e.g. "12 > filename". */
+#define BAEJ_SUG_POINTER '>'
+
 #define MNT_UDEVIL 	0
 #define MNT_UDISKS2 1
 
@@ -472,6 +476,8 @@ ws2=31:ws3=38;5;228:ws4=32:ws5=36:ws6=38;5;214:ws7=35:ws8=2;37:xf=1;31:xs=32:"
 #define DEF_ICONS 0
 #define DEF_INT_VARS 0
 #define DEF_LIGHT_MODE 0
+/* Possible values: LNK_CREAT_REG, LNK_CREAT_ABS, and LNK_CREAT_REL */
+#define DEF_LINK_CREATION_MODE LNK_CREAT_REG
 #define DEF_LIST_DIRS_FIRST 1
 #define DEF_LISTING_MODE VERTLIST
 #define DEF_LOG_MSGS 0
@@ -494,6 +500,7 @@ ws2=31:ws3=38;5;228:ws4=32:ws5=36:ws6=38;5;214:ws7=35:ws8=2;37:xf=1;31:xs=32:"
 #define DEF_PAGER 0
 /* Possible values: PAGER_AUTO, PAGER_LONG, and PAGER_SHORT */
 #define DEF_PAGER_VIEW PAGER_AUTO
+#define DEF_PRINT_DIR_CMDS 0
 #define DEF_PRINTSEL 0
 #define DEF_PRINT_REMOVED_FILES 1
 #define DEF_PRIVATE_WS_SETTINGS 0
@@ -530,16 +537,16 @@ ws2=31:ws3=38;5;228:ws4=32:ws5=36:ws6=38;5;214:ws7=35:ws8=2;37:xf=1;31:xs=32:"
 # define DEF_SUDO_CMD "sudo"
 #endif /* __OpenBSD__ */
 #define DEF_SUG_FILETYPE_COLOR 0
-#define DEF_SUG_STRATEGY "ehfj-ac"
+#define DEF_SUG_STRATEGY "ehfjac"
 #define DEF_SUGGESTIONS 1
+#define DEF_TIME_FOLLOWS_SORT 1
 #define DEF_TIME_STYLE_RECENT "%b %e %H:%M" /* Timestamps in long view mode */
 #define DEF_TIME_STYLE_OLDER  "%b %e  %Y"
 #define DEF_TIME_STYLE_LONG   "%a %b %d %T %Y %z" /* Used by history and trash */
+#define DEF_TIMESTAMP_MARK 0
 #define DEF_TIPS 1
-#define DEF_TOGGLE_WORKSPACES 1
 #define DEF_TRASRM 0
 #define DEF_TRIM_NAMES 1
-#define DEF_UNICODE 1
 #define DEF_WELCOME_MESSAGE 1
 
 /* This expands to "CliFM > The command line file manager" */
@@ -568,7 +575,6 @@ ws2=31:ws3=38;5;228:ws4=32:ws5=36:ws6=38;5;214:ws7=35:ws8=2;37:xf=1;31:xs=32:"
 
 #define DEF_RM_FORCE 0
 
-#define SUG_STRATS 7
 #define MAX_WS 8
 #define MIN_SCREEN_WIDTH 20
 #define MIN_SCREEN_HEIGHT 5
@@ -578,8 +584,8 @@ ws2=31:ws3=38;5;228:ws4=32:ws5=36:ws6=38;5;214:ws7=35:ws8=2;37:xf=1;31:xs=32:"
 #define DEF_PROMPT_NO_COLOR_NAME "clifm-no-color"
 #define DEF_PROMPT_NOTIF 1
 #define DEFAULT_PROMPT "\\[\\e[0m\\]\\I[\\S\\[\\e[0m\\]]\\l \
-\\A \\u:\\H \\[\\e[00;36m\\]\\w\\n\\[\\e[0m\\]<\\z\\[\\e[0m\\]\
->\\[\\e[00;34m\\] \\$\\[\\e[0m\\] "
+\\A \\u:\\H \\[\\e[0;36m\\]\\w\\n\\[\\e[0m\\]<\\z\\[\\e[0m\\]\
+>\\[\\e[0;34m\\] \\$\\[\\e[0m\\] "
 #define DEFAULT_PROMPT_NO_COLOR "\\I[\\S]\\l \\A \\u:\\H \\w\\n<\\z> \\$ "
 
 #define DEF_WARNING_PROMPT 1
@@ -587,7 +593,7 @@ ws2=31:ws3=38;5;228:ws4=32:ws5=36:ws6=38;5;214:ws7=35:ws8=2;37:xf=1;31:xs=32:"
 #if defined(RL_READLINE_VERSION) && RL_READLINE_VERSION < 0x0700
 # define DEF_WPROMPT_STR DEF_WPROMPT_STR_NO_COLOR
 #else
-# define DEF_WPROMPT_STR "\\[\\e[00;02;31m\\](!) > "
+# define DEF_WPROMPT_STR "\\[\\e[0;1;31m\\](!)\\[\\e[0;2m\\] > "
 #endif /* READLINE < 7.0 */
 
 /* These options, except --preview-window=border-left (fzf 0.27), work with at
