@@ -383,7 +383,7 @@ xstrverscmp(const char *s1, const char *s2)
 		state += (c1 == '0') + (IS_DIGIT(c1) != 0);
 	}
 
-	state = result_type[state * 3 + (((c2 == '0') + (IS_DIGIT(c2) != 0)))];
+	state = (int)result_type[state * 3 + (((c2 == '0') + (IS_DIGIT(c2) != 0)))];
 
 	switch (state) {
 	case VCMP: return diff;
@@ -417,7 +417,7 @@ wc_xstrlen(const char *restrict str)
 	 * command line: a history entry involving several paths might easily be
 	 * longer than PATH_MAX. */
 	static wchar_t wbuf[ARG_MAX];
-	const size_t len = mbstowcs(wbuf, str, ARG_MAX);
+	const size_t len = mbstowcs(wbuf, str, (size_t)ARG_MAX);
 	if (len == (size_t)-1) /* Invalid multi-byte sequence found */
 		return 0;
 
@@ -442,9 +442,9 @@ int
 u8truncstr(char *restrict str, const size_t max)
 {
 	int len = 0;
-	static wchar_t buf[NAME_MAX + 1];
+	static wchar_t buf[NAME_BUF_SIZE];
 	*buf = L'\0';
-	if (mbstowcs(buf, str, NAME_MAX + 1) == (size_t)-1)
+	if (mbstowcs(buf, str, NAME_BUF_SIZE) == (size_t)-1)
 		return 0;
 
 	int i, bmax = (int)max;
@@ -460,11 +460,107 @@ u8truncstr(char *restrict str, const size_t max)
 		len += l;
 	}
 
-	wcsncpy((wchar_t *)str, buf, (size_t)bmax * sizeof(wchar_t)); /* flawfinder: ignore */
+	wcsncpy((wchar_t *)str, buf, NAME_BUF_SIZE); /* flawfinder: ignore */
 
 	return bmax - len;
 }
 
+/* Return 1 if the string S contains at least one whitespace char (ASCII or
+ * Unicode), or 0 otherwise.
+ * The list of available whitespaces is taken from:
+ * https://en.wikipedia.org/wiki/Whitespace_character */
+int
+detect_space(char *s)
+{
+	if (!s || !*s)
+		return 0;
+
+	unsigned char s0, s1, s2;
+
+	while (*s) {
+		s0 = (unsigned char)*s;
+
+		if (s0 == ' ' || s0 == '\t')
+			return 1;
+
+		if (s0 != 0xc2 && (s0 < 0xe1 || s0 > 0xe3))
+			goto CONT;
+
+		if ((s1 = (unsigned char)s[1]) == '\0')
+			return 0;
+
+		if (s0 == 0xc2 && (s1 == 0x85 || s1 == 0xa0))
+			return 1; /* Unnamed control char or NO-BREAK SPACE. */
+
+		if ((s2 = (unsigned char)s[2]) == '\0')
+			return 0;
+
+		if (s0 == 0xe1) {
+			if (s1 == 0x9a && s2 == 0x80)
+				return 1; /* OGHAM SPACE MARK. */
+			if (s1 == 0xa0 && s2 == 0x8e)
+				return 1; /* MONGOLIAN VOWEL SEPARATOR. */
+		}
+
+		if (s0 == 0xe3 && s1 == 0x80 && s2 == 0x80)
+			return 1; /* IDEOGRAPHIC SPACE. */
+
+		if (s0 != 0xe2)
+			goto CONT;
+
+		if (s1 == 0x81 && s2 == 0x9f)
+			return 1; /* MEDIUM MATHEMATICAL SPACE. */
+
+		if (s1 != 0x80)
+			goto CONT;
+
+		switch (s2) {
+		case 0x80: /* fallthrough */ /* EN QUAD. */
+		case 0x81: /* fallthrough */ /* EM QUAD. */
+		case 0x82: /* fallthrough */ /* EN SPACE. */
+		case 0x83: /* fallthrough */ /* EM SPACE. */
+		case 0x84: /* fallthrough */ /* THREE-PER-EM SPACE. */
+		case 0x85: /* fallthrough */ /* FOUR-PER-EM SPACE. */
+		case 0x86: /* fallthrough */ /* SIX-PER-EM SPACE. */
+		case 0x87: /* fallthrough */ /* FIGURE SPACE. */
+		case 0x88: /* fallthrough */ /* PUNCTUATION SPACE. */
+		case 0x89: /* fallthrough */ /* THIN SPACE. */
+		case 0x8a: /* fallthrough */ /* HAIR SPACE. */
+		case 0xa8: /* fallthrough */ /* LINE SEPARATOR. */
+		case 0xa9: /* fallthrough */ /* PARAGRAPH SEPARATOR. */
+		case 0xaf: /* NARROW NO-BREAK SPACE. */
+			return 1;
+		}
+
+CONT:
+		s++;
+	}
+
+	return 0;
+}
+
+/* Check whether the string S begins with a control character.
+ * Return 0 if not, or the number of bytes of the control character. */
+static int
+check_control_char(const unsigned char *s)
+{
+	if (*s < ' ' || *s == 127)
+		return 1; /* C0 control characters and DEL char */
+
+	if (*s == 0xc2 && *(s + 1) >= 0x80 && *(s + 1) <= 0x9f)
+		return 2; /* C1 controls characters */
+
+	if (*s == 0xe2 && *(s + 1) == 0x80
+	&& (*(s + 2) == 0xa8 || *(s + 2) == 0xa9))
+		return 3; /* Line separator (xa8) / Paragraph separator (xa9) */
+
+	if (*s == 0xf3 && *(s + 1) == 0xa9 && *(s + 2) == 0x80
+	&& *(s + 3) == 0x81)
+		return 4; /* Language tag */
+
+	return 0;
+}
+
 /* Replace invalid characters in NAME by INVALID_CHAR ('^').
  * This function is called only if wc_xstrlen() returns zero, in which case
  * we have either a non-printable char or an invalid multi-byte sequence. */
@@ -486,13 +582,10 @@ replace_invalid_chars(const char *name)
 			continue;
 		}
 
-#if defined(CHAR_MIN) && CHAR_MIN < 0
-		if (*q >= '\0' && *q < ' ') { /* Control char */
-#else
-		if (*q < ' ') {
-#endif /* CHAR_MIN < 0 */
+		const int ret = check_control_char((unsigned char *)q);
+		if (ret > 0) {
 			*n = INVALID_CHR;
-			n++; q++;
+			n++; q += ret;
 			continue;
 		}
 
@@ -755,7 +848,7 @@ init_quoted_words(void)
 /* After expanding multiple fields from an expandable expression, say 'sel',
  * we lost track of quoted words, because the old indices point now to
  * expanded fields.
- * Ex: 'p sel "12"' -> the quoted word index is originally 2, but after the
+ * E.g.: 'p sel "12"' -> the quoted word index is originally 2, but after the
  * expansion of the 'sel' keyword, the index 2 points now to a selected file.
  *
  * This function updates quoted word indices taking into account the starting
@@ -831,7 +924,7 @@ split_str(char *str, const int update_args)
 
 	size_t buf_len = 0, words = 0, str_len = 0;
 	char *buf = xnmalloc(1, sizeof(char));
-	int close = 0;
+	char close = 0;
 	char **substr = (char **)NULL;
 
 	int keep_quotes = cmd_keeps_quotes(str);
@@ -862,7 +955,7 @@ split_str(char *str, const int update_args)
 				} else {
 					/* If '`' advance one char. Otherwise the while
 					 * below will stop at first char, which is not
-					 * what we want */
+					 * what we want. */
 					close = *str;
 					str++;
 					buf = xnrealloc(buf, buf_len + 1, sizeof(char *));
@@ -871,7 +964,7 @@ split_str(char *str, const int update_args)
 				}
 			}
 
-			/* Copy everything until null byte or closing char */
+			/* Copy everything until null byte or closing char. */
 			while (*str && *str != close) {
 				buf = xnrealloc(buf, buf_len + 1, sizeof(char *));
 				buf[buf_len] = *str;
@@ -880,7 +973,7 @@ split_str(char *str, const int update_args)
 			}
 
 			/* If the while loop stopped with a null byte, there was
-			 * no ending close (either ')' or '`')*/
+			 * no ending close (either ')' or '`'). */
 			if (!*str) {
 				xerror(_("%s: Missing '%c'\n"), PROGRAM_NAME, close);
 				free(buf);
@@ -896,7 +989,7 @@ split_str(char *str, const int update_args)
 
 			/* Copy the closing char and add an space: this function
 			 * takes space as word breaking char, so that everything
-			 * in the buffer will be copied as one single word */
+			 * in the buffer will be copied as one single word. */
 			buf = xnrealloc(buf, buf_len + 2, sizeof(char *));
 			buf[buf_len] = *str;
 			buf_len++;
@@ -966,19 +1059,19 @@ split_str(char *str, const int update_args)
 
 			break;
 
-		/* TAB, new line char, and space are taken as word breaking characters */
+		/* TAB, new line char, and space are taken as word breaking characters. */
 		case '\t': /* fallthrough */
 		case '\n': /* fallthrough */
 		case ' ':
-			/* If escaped, just copy it into the buffer */
+			/* If escaped, just copy it into the buffer. */
 			if (str_len && *(str - 1) == '\\') {
 				buf = xnrealloc(buf, buf_len + 1, sizeof(char *));
 				buf[buf_len] = *str;
 				buf_len++;
 			} else {
-				/* If not escaped, break the string */
+				/* If not escaped, break the string. */
 				/* Add a terminating null byte to the buffer, and, if not empty,
-				 * dump the buffer into the substrings array */
+				 * dump the buffer into the substrings array. */
 				buf[buf_len] = '\0';
 
 				if (buf_len > 0) {
@@ -987,7 +1080,7 @@ split_str(char *str, const int update_args)
 					words++;
 				}
 
-				/* Clear the buffer to get a new string */
+				/* Clear the buffer to get a new string. */
 				memset(buf, '\0', buf_len);
 				buf_len = 0;
 			}
@@ -1010,7 +1103,7 @@ split_str(char *str, const int update_args)
 
 	/* The while loop stops when the null byte is reached, so that the last
 	 * substring is not printed, but still stored in the buffer. Therefore,
-	 * we need to add it, if not empty, to our substrings array */
+	 * we need to add it, if not empty, to our substrings array. */
 	buf[buf_len] = '\0';
 
 	if (buf_len > 0) {
@@ -1027,7 +1120,7 @@ split_str(char *str, const int update_args)
 	buf = (char *)NULL;
 
 	if (words > 0) {
-		/* Add a final null string to the array */
+		/* Add a final null string to the array. */
 		substr = xnrealloc(substr, words + 1, sizeof(char *));
 		substr[words] = (char *)NULL;
 
@@ -1036,7 +1129,7 @@ split_str(char *str, const int update_args)
 		return substr;
 	} else {
 		if (update_args == 1)
-			args_n = 0; /* Just in case, but I think it's not needed */
+			args_n = 0; /* Just in case, but I think it's not required. */
 		return (char **)NULL;
 	}
 }
@@ -1279,7 +1372,7 @@ expand_tag(char ***args, const int tag_index)
 
 		char rpath[PATH_MAX + 1];
 		*rpath = '\0';
-		char *ret = realpath(filename, rpath);
+		char *ret = xrealpath(filename, rpath);
 		if (!ret || !*rpath) {
 			/* This tagged file points to a non-existent file. Just copy
 			 * the tag path. */
@@ -1605,7 +1698,7 @@ eln_expand(char ***substr, const size_t i)
 	char *abs_path = (char *)NULL;
 	if (file_info[j].name && *file_info[j].name == '-'
 	&& !is_internal_c((*substr)[0]))
-		abs_path = realpath(file_info[j].name, NULL);
+		abs_path = xrealpath(file_info[j].name, NULL);
 
 	char *esc_str = (char *)NULL;
 	if (conf.quoting_style == QUOTING_STYLE_BACKSLASH
@@ -2765,7 +2858,7 @@ parse_input_str(char *str)
 
 		/* should_expand_eln() will check rl_line_buffer looking for the
 		 * command name. Now, if the command name has a fused ELN plus space
-		 * and at least a second parameter (ex: CMD1 2), should_expand_eln()
+		 * and at least a second parameter (E.g.: CMD1 2), should_expand_eln()
 		 * will fail. Let's redirect rl_line_buffer to the buffered command
 		 * name (CMD) so that the check will be properly performed. */
 		char *lb_tmp = rl_line_buffer;
@@ -2819,7 +2912,8 @@ parse_input_str(char *str)
 		if ((*substr[i] == '.' && (!substr[i][1] || (substr[i][1] == '.'
 		&& (!substr[i][2] || substr[i][2] == '/'))))
 		|| strstr(substr[i], "/..")) {
-			char *tmp = is_internal_cmd == 1
+			char *tmp = (is_internal_cmd == 1
+			&& (*substr[0] != 'l' || substr[0][1])) /* Exclude 'l' command. */
 				? normalize_path(substr[i], strlen(substr[i])) : NULL;
 			if (tmp) {
 				free(substr[i]);
@@ -2990,7 +3084,7 @@ parse_input_str(char *str)
 			 * expansion is made by wordexp(3) */
 			if (is_escaped == 0 && IS_WORD(substr[i][j], substr[i][j + 1])) {
 				/* Unlike glob() and tilde_expand(), wordexp() can expand tilde
-				 * and env vars even in the middle of a string. Ex: $HOME/Downloads */
+				 * and env vars even in the middle of a string. E.g.: $HOME/Downloads */
 				if (word_n < INT_ARRAY_MAX) {
 					word_array[word_n] = (int)i;
 					word_n++;
