@@ -69,6 +69,9 @@ static char *last_word = (char *)NULL;
 static int last_word_offset = 0;
 static int point_is_first_word = 0;
 
+/* A big enough buffer to hold temporary data. */
+static char tmp_buf[PATH_MAX + 2];
+
 /*
 #ifndef _NO_HIGHLIGHT
 // Change the color of the word _LAST_WORD, at offset OFFSET, to COLOR
@@ -145,7 +148,6 @@ check_int_cmd_desc(const char *s, const size_t l)
 		else if (*s == 'f') {
 			if (*(s + 1) == 'c') return FC_DESC;
 			if (*(s + 1) == 'f') return FF_DESC;
-			if (*(s + 1) == 's') return FS_DESC;
 			if (*(s + 1) == 't') return FT_DESC;
 			if (*(s + 1) == 'z') return FZ_DESC;
 		}
@@ -249,8 +251,6 @@ check_int_cmd_desc(const char *s, const size_t l)
 			return B_DESC;
 		if (*s == 'b' && strcmp(s + 1, "ulk") == 0)
 			return BR_DESC;
-		if (*s == 'e' && strcmp(s + 1, "dit") == 0)
-			return EDIT_DESC;
 		if (*s == 'm' && strcmp(s + 1, "ime") == 0)
 			return MM_DESC;
 		if (*s == 'o' && strcmp(s + 1, "pen") == 0)
@@ -365,7 +365,7 @@ recover_from_wrong_cmd(void)
 	 * in which case we should skip this check. */
 	if (rl_line_buffer && (rl_dispatching == 0
 	|| (words_num > 1 && point_is_first_word == 0))) {
-		char *p = (strrchr(rl_line_buffer, ' '));
+		const char *p = (strrchr(rl_line_buffer, ' '));
 		if (p && p != rl_line_buffer && *(p - 1) != '\\' && *(p + 1) != ' ')
 			return FUNC_FAILURE;
 	}
@@ -377,7 +377,7 @@ recover_from_wrong_cmd(void)
 
 #ifndef _NO_HIGHLIGHT
 	if (conf.highlight == 1) {
-		int p = rl_point;
+		const int p = rl_point;
 		rl_point = 0;
 		recolorize_line();
 		rl_point = p;
@@ -421,21 +421,6 @@ clear_suggestion(const int sflag)
 	}
 }
 
-/* THIS FUNCTION SHOULD BE REMOVED */
-void
-remove_suggestion_not_end(void)
-{
-/*	if (conf.highlight != 0) {
-		MOVE_CURSOR_RIGHT(rl_end - rl_point);
-		fflush(stdout);
-	}
-
-	ERASE_TO_RIGHT; */
-	clear_suggestion(CS_FREEBUF);
-/*	MOVE_CURSOR_LEFT(rl_end - rl_point);
-	fflush(stdout); */
-}
-
 static inline void
 restore_cursor_position(const size_t slines)
 {
@@ -532,7 +517,7 @@ check_conditions(const size_t offset, const size_t wlen, int *baej,
 	 * it equals ARG_MAX, in which case we most probably have a truncated
 	 * suggestion (mbstowcs will convert only up to ARG_MAX chars), exit. */
 	const size_t suggestion_len = wlen - offset;
-	if (suggestion_len == 0 || suggestion_len == ARG_MAX
+	if (suggestion_len == 0 || suggestion_len == (size_t)ARG_MAX
 	|| (int)suggestion_len > (term_cols * term_lines) - curcol)
 		return FUNC_FAILURE;
 
@@ -593,7 +578,7 @@ print_suggestion(const char *str, size_t offset, char *color)
 	flags &= ~BAEJ_SUGGESTION;
 
 	/* Let's check for baej suggestions, mostly in case of fuzzy matches. */
-	size_t wlen = last_word ? strlen(last_word) : 0;
+	const size_t wlen = last_word ? strlen(last_word) : 0;
 	/* An alias name can be the same as the beginning of the alias definition,
 	 * so that this check must always be true in case of aliases. */
 	if (suggestion.type == ALIAS_SUG || (last_word && cur_comp_type == TCMP_PATH
@@ -607,7 +592,7 @@ print_suggestion(const char *str, size_t offset, char *color)
 	if (conf.highlight == 0)
 		rl_redisplay();
 	curcol = prompt_offset + (rl_line_buffer
-			? (int)wc_xstrlen(rl_line_buffer) : 0);
+		? (int)wc_xstrlen(rl_line_buffer) : 0);
 
 	if (term_cols > 0) {
 		while (curcol > term_cols)
@@ -659,7 +644,7 @@ get_reg_file_color(const char *filename, const struct stat *attr,
 	if (attr->st_mode & S_ISGID) return sg_c;
 
 #ifdef LINUX_FILE_CAPS
-	const cap_t cap = cap_get_file(filename);
+	cap_t cap = cap_get_file(filename);
 	if (cap) {
 		cap_free(cap);
 		return ca_c;
@@ -709,7 +694,7 @@ get_comp_color(const char *filename, const struct stat *attr, int *free_color)
 
 	case S_IFLNK: {
 		if (conf.light_mode == 1) return ln_c;
-		char *linkname = realpath(filename, (char *)NULL);
+		char *linkname = xrealpath(filename, NULL);
 		if (linkname) {
 			free(linkname);
 			return ln_c;
@@ -781,13 +766,13 @@ skip_leading_backslashes(char **str, size_t *len)
 static void
 match_print(char *match, const size_t len, char *color, const int append_slash)
 {
-	char t[PATH_MAX + 2];
-	*t = '\0';
+//	char t[PATH_MAX + 2];
+	*tmp_buf = '\0';
 
 	if (append_slash == 1)
-		snprintf(t, sizeof(t), "%s/", match);
+		snprintf(tmp_buf, sizeof(tmp_buf), "%s/", match);
 
-	char *tmp = escape_str(*t ? t : match);
+	char *tmp = escape_str(*tmp_buf ? tmp_buf : match);
 	if (!tmp || !*tmp) {
 		print_suggestion(match, len, color);
 		return;
@@ -917,17 +902,18 @@ print_directory_suggestion(const filesn_t i, const size_t len, char *color)
 
 	suggestion.filetype = DT_DIR;
 
-	char name[NAME_MAX + 2];
-	snprintf(name, sizeof(name), "%s/", file_info[i].name);
+//	char name[NAME_MAX + 2];
+	*tmp_buf = '\0';
+	snprintf(tmp_buf, sizeof(tmp_buf), "%s/", file_info[i].name);
 
-	char *tmp = escape_str(name);
+	char *tmp = escape_str(tmp_buf);
 	if (tmp) {
 		print_suggestion(tmp, len, color);
 		free(tmp);
 		return;
 	}
 
-	print_suggestion(name, len, color);
+	print_suggestion(tmp_buf, len, color);
 }
 
 static inline void
@@ -949,9 +935,10 @@ print_reg_file_suggestion(char *str, const filesn_t i, size_t len,
 		}
 
 		if (dot_slash) { /* Reinsert './', removed to check file name. */
-			char t[NAME_MAX + 2];
-			snprintf(t, sizeof(t), "./%s", tmp);
-			print_suggestion(t, len + 2, color);
+//			char t[NAME_MAX + 2];
+			*tmp_buf = '\0';
+			snprintf(tmp_buf, sizeof(tmp_buf), "./%s", tmp);
+			print_suggestion(tmp_buf, len + 2, color);
 		} else {
 			print_suggestion(tmp, len, color);
 		}
@@ -961,9 +948,10 @@ print_reg_file_suggestion(char *str, const filesn_t i, size_t len,
 	}
 
 	if (dot_slash) {
-		char t[NAME_MAX + 2];
-		snprintf(t, sizeof(t), "./%s", file_info[i].name);
-		print_suggestion(t, len + 2, color);
+//		char t[NAME_MAX + 2];
+		*tmp_buf = '\0';
+		snprintf(tmp_buf, sizeof(tmp_buf), "./%s", file_info[i].name);
+		print_suggestion(tmp_buf, len + 2, color);
 		return;
 	}
 
@@ -1213,7 +1201,7 @@ check_cmds(char *str, size_t len, const int print)
 		if (strncmp(cmd, bin_commands[i], len) != 0)
 			continue;
 
-		int ret = print_cmd_suggestion(i, len);
+		const int ret = print_cmd_suggestion(i, len);
 		if (ret == NO_MATCH)
 			continue;
 		return ret;
@@ -1245,18 +1233,19 @@ check_jumpdb(const char *str, const size_t len, const int print)
 		if (len && (conf.case_sens_path_comp
 		? strncmp(str, jump_db[i].path, len)
 		: strncasecmp(str, jump_db[i].path, len)) == 0) {
-			if (jump_db[i].len <= len) return FULL_MATCH;
+			if (jump_db[i].len <= len)
+				return FULL_MATCH;
 
 			suggestion.type = FILE_SUG;
 			suggestion.filetype = DT_DIR;
-			char tmp[PATH_MAX + 2];
-			*tmp = '\0';
+//			char tmp[PATH_MAX + 2];
+			*tmp_buf = '\0';
 
 			if (jump_db[i].len > 0
 			&& jump_db[i].path[jump_db[i].len - 1] != '/')
-				snprintf(tmp, sizeof(tmp), "%s/", jump_db[i].path);
+				snprintf(tmp_buf, sizeof(tmp_buf), "%s/", jump_db[i].path);
 
-			print_suggestion(*tmp ? tmp : jump_db[i].path, len, color);
+			print_suggestion(*tmp_buf ? tmp_buf : jump_db[i].path, len, color);
 			return PARTIAL_MATCH;
 		}
 	}
@@ -1304,16 +1293,16 @@ check_eln(const char *str, const int print)
 	if (conf.suggest_filetype_color)
 		color = file_info[n].color;
 
-	char tmp[NAME_MAX + 1];
-	*tmp = '\0';
+//	char tmp[NAME_MAX + 1];
+	*tmp_buf = '\0';
 	if (file_info[n].dir) {
-		snprintf(tmp, sizeof(tmp), "%s/", file_info[n].name);
+		snprintf(tmp_buf, sizeof(tmp_buf), "%s/", file_info[n].name);
 		suggestion.filetype = DT_DIR;
 	} else {
 		suggestion.filetype = DT_REG;
 	}
 
-	print_suggestion(!*tmp ? file_info[n].name : tmp, 0, color);
+	print_suggestion(*tmp_buf ? tmp_buf : file_info[n].name, 0, color);
 
 	return PARTIAL_MATCH;
 }
@@ -1431,9 +1420,10 @@ check_users(const char *str, const size_t len)
 		if (len == 0 || (*str == *p->pw_name
 		&& strncmp(str, p->pw_name, len) == 0)) {
 			suggestion.type = USER_SUG;
-			char t[NAME_MAX + 1];
-			snprintf(t, sizeof(t), "~%s", p->pw_name);
-			print_suggestion(t, len + 1, sf_c);
+//			char t[NAME_MAX + 1];
+			*tmp_buf = '\0';
+			snprintf(tmp_buf, sizeof(tmp_buf), "~%s", p->pw_name);
+			print_suggestion(tmp_buf, len + 1, sf_c);
 			endpwent();
 			return PARTIAL_MATCH;
 		}
@@ -1459,9 +1449,10 @@ check_variables(const char *str, const size_t len)
 
 		*ret = '\0';
 		suggestion.type = VAR_SUG;
-		char t[NAME_MAX + 1];
-		snprintf(t, sizeof(t), "$%s", environ[i]);
-		print_suggestion(t, len + 1, sh_c);
+//		char t[NAME_MAX + 1];
+		*tmp_buf = '\0';
+		snprintf(tmp_buf, sizeof(tmp_buf), "$%s", environ[i]);
+		print_suggestion(tmp_buf, len + 1, sh_c);
 		*ret = '=';
 		return PARTIAL_MATCH;
 	}
@@ -1475,9 +1466,10 @@ check_variables(const char *str, const size_t len)
 			continue;
 
 		suggestion.type = CMD_SUG;
-		char t[NAME_MAX + 1];
-		snprintf(t, sizeof(t), "$%s", usr_var[i].name);
-		print_suggestion(t, len + 1, sh_c);
+//		char t[NAME_MAX + 1];
+		*tmp_buf = '\0';
+		snprintf(tmp_buf, sizeof(tmp_buf), "$%s", usr_var[i].name);
+		print_suggestion(tmp_buf, len + 1, sh_c);
 		return PARTIAL_MATCH;
 	}
 
@@ -1967,7 +1959,7 @@ check_dirhist(char *word, const size_t len)
 		} else {
 			int s = fuzzy_match(word, old_pwd[i], len, fuzzy_str_type);
 			if (s > best_fz_score) {
-				fuzzy_index = (int)i;
+				fuzzy_index = i;
 				if (s == TARGET_BEGINNING_BONUS)
 					break;
 				best_fz_score = s;
@@ -2183,18 +2175,6 @@ rl_suggestions(const unsigned char c)
 				if ((printed = check_backdir()) != NO_MATCH)
 					goto SUCCESS;
 		}
-
-		/* REMOVE AS SOON AS BH IS REPLACED BY DH!! */
-		else if (words_num == 2 && old_pwd && dirhist_total_index > 0 && wlen > 0
-		&& lb[1] == 'h' && lb[2] == ' ' && !strchr(word, '/')) {
-			if (lb[1] == 'h' && lb[2] == ' ' && (lb[3] == '-'
-			|| strncmp(lb + 3, "--help", strlen(lb + 3)) == 0))
-				break;
-			if ((printed = check_dirhist(word, wlen)) != NO_MATCH)
-				goto SUCCESS;
-			else
-				goto FAIL;
-		}
 		break;
 
 	case 'c': /* Color schemes */
@@ -2205,11 +2185,7 @@ rl_suggestions(const unsigned char c)
 		}
 		break;
 
-	case 'f': /* fallthrough */ /* REMOVE AS SOON AS FH CMD IS REMOVED! */
 	case 'd': /* Dirhist command (dh) */
-		if (lb[1] == 'h' && lb[2] == ' ' && (lb[3] == '-'
-		|| strncmp(lb + 3, "--help", strlen(lb + 3)) == 0))
-			break;
 		if (words_num == 2 && old_pwd && dirhist_total_index > 0 && wlen > 0
 		&& lb[1] == 'h' && lb[2] == ' ' && !strchr(word, '/')) {
 			if ((printed = check_dirhist(word, wlen)) != NO_MATCH)
@@ -2220,10 +2196,6 @@ rl_suggestions(const unsigned char c)
 		break;
 
 	case 'j': /* j command */
-		if (lb[1] == ' ' && lb[2] == '-' && (lb[3] == 'h'
-		|| strncmp(lb + 2, "--help", strlen(lb + 2)) == 0))
-			break;
-
 		if (lb[1] == ' '  || ((lb[1] == 'c'	|| lb[1] == 'p') && lb[2] == ' ')) {
 			if ((printed = check_jcmd(full_line)) != NO_MATCH) {
 				zero_offset = 1;
@@ -2333,7 +2305,7 @@ rl_suggestions(const unsigned char c)
 	/* Let's find out whether the last entered character is escaped. */
 	int escaped = (wlen > 1 && word[wlen - 2] == '\\') ? 1 : 0;
 
-	for (st = 0; st < SUG_STRATS; st++) {
+	for (st = 0; conf.suggestion_strategy[st]; st++) {
 		switch (conf.suggestion_strategy[st]) {
 
 		case 'a': /* 3.e.1) Aliases */
@@ -2432,7 +2404,12 @@ rl_suggestions(const unsigned char c)
 
 			if (words_num == 1) {
 				word = (first_word && *first_word) ? first_word : last_word;
+				if (*word == '/') /* Absolute path: nothing to do here. */
+					break;
 				wlen = strlen(word);
+			} else {
+				if (*word == '/')
+					break;
 			}
 
 			/* If "./FILE" check only "FILE" */
@@ -2442,9 +2419,6 @@ rl_suggestions(const unsigned char c)
 				last_word_offset += 2;
 			}
 
-			if (*word == '/') /* Absolute path: nothing to do here. */
-				break;
-
 			/* If we have a slash, we're not looking for files in the CWD. */
 			char *p = strchr(word, '/');
 			if (p && *(p + 1))
@@ -2505,7 +2479,6 @@ rl_suggestions(const unsigned char c)
 
 			break;
 
-		case '-': break; /* Ignore check */
 		default: break;
 		}
 	}
