@@ -113,7 +113,7 @@ enable_raw_mode(const int fd)
 	raw.c_oflag &= (tcflag_t)~(OPOST);
 	/* control modes - set 8 bit chars */
 	raw.c_cflag |= (CS8);
-	/* local modes - choing off, canonical off, no extended functions,
+	/* local modes - echoing off, canonical off, no extended functions,
 	 * no signal chars (^Z,^C) */
 	raw.c_lflag &= (tcflag_t)~(ECHO | ICANON | IEXTEN | ISIG);
     /* control chars - set return condition: min number of bytes and timer. */
@@ -141,7 +141,7 @@ disable_raw_mode(const int fd)
 
 /* Use the "ESC [6n" escape sequence to query the cursor position (both
  * vertical and horizontal) and store both values into C (columns) and L (lines).
- * Returns 0 on success and 1 on error */
+ * Returns 0 on success and 1 on error. */
 static int
 get_cursor_position(int *c, int *l)
 {
@@ -245,7 +245,7 @@ static int
 get_y_or_n(void)
 {
 	for (;;) {
-		int c = fgetc(stdin);
+		int c = fgetc(stdin); /* Flawfinder: ignore */
 		if (c == 'y' || c == 'Y' || c == ' ')
 			return (1);
 		if (c == 'n' || c == 'N' || c == RUBOUT || c == EOF) {
@@ -384,11 +384,8 @@ fzftab_color(char *filename, const struct stat *attr)
 			return nf_c;
 
 		char *cl = get_file_color(filename, attr);
-
-		if (cl && (check_ext == 0 || cl == nf_c || cl == ca_c
-		|| (attr->st_mode & 00100) || (attr->st_mode & 00010)
-		|| (attr->st_mode & 00001)))
-			return cl;
+		if (check_ext == 0 || cl != fi_c)
+			return (cl ? cl : fi_c);
 
 		/* If trashed file, remove the trash extension, so we can get the
 		 * color according to the actual file extension. */
@@ -406,7 +403,7 @@ fzftab_color(char *filename, const struct stat *attr)
 
 		if (te) *te = '.';
 
-		return ext_cl ? ext_cl : (cl ? cl : df_c);
+		return ext_cl ? ext_cl : (cl ? cl : fi_c);
 		}
 
 	case S_IFSOCK: return so_c;
@@ -419,7 +416,7 @@ fzftab_color(char *filename, const struct stat *attr)
 }
 
 static char *
-get_entry_color(char *entry, const char *norm_prefix)
+get_comp_entry_color(char *entry, const char *norm_prefix)
 {
 	if (conf.colorize == 0)
 		return (char *)NULL;
@@ -730,7 +727,7 @@ set_fzf_env_vars(const int height)
 	default: break;
 	}
 
-	char p[32];
+	char p[MAX_INT_STR];
 	snprintf(p, sizeof(p), "%d", y > 0 ? y - 1 : 0);
 	setenv("CLIFM_FZF_LINE", p, 1);
 	snprintf(p, sizeof(p), "%d", x > 0 ? x : 0);
@@ -789,6 +786,20 @@ cd_trashdir(const int prev)
 #endif /* !_NO_TRASH */
 }
 
+static void
+warn_fzf_error(void)
+{
+	fprintf(stderr, _("%s: Fzf failed. Check the FzfTabOptions "
+		"line by running 'cs edit'\n(some parameter may not "
+		"be supported by the installed fzf version).\n"), PROGRAM_NAME);
+	press_any_key_to_continue(0);
+	if (term_caps.suggestions == 1) {
+		MOVE_CURSOR_UP(3);
+		ERASE_TO_RIGHT_AND_BELOW;
+		MOVE_CURSOR_DOWN(1);
+	}
+}
+
 static int
 run_finder(const size_t height, const int offset, const char *lw,
 	const int multi)
@@ -796,9 +807,9 @@ run_finder(const size_t height, const int offset, const char *lw,
 	int prev = (conf.fzf_preview > 0 && SHOW_PREVIEWS(cur_comp_type) == 1)
 		? FZF_INTERNAL_PREVIEWER : 0;
 
-	int restore_cwd = cd_trashdir(prev);
+	const int restore_cwd = cd_trashdir(prev);
+	const int prev_hidden = conf.fzf_preview == 2 ? 1 : 0;
 
-	int prev_hidden = conf.fzf_preview == 2 ? 1 : 0;
 	if (conf.fzf_preview == FZF_EXTERNAL_PREVIEWER)
 		prev = FZF_EXTERNAL_PREVIEWER;
 
@@ -810,7 +821,7 @@ run_finder(const size_t height, const int offset, const char *lw,
 
 	/* If height was not set in FZF_DEFAULT_OPTS nor in the config
 	 * file, let's define it ourselves. */
-	char height_str[10 + 32];
+	char height_str[10 + MAX_INT_STR];
 	*height_str = '\0';
 	if (fzf_height_set == 0)
 		snprintf(height_str, sizeof(height_str), "--height=%zu", height);
@@ -836,13 +847,13 @@ run_finder(const size_t height, const int offset, const char *lw,
 
 	} else { /* FZF */
 		/* All fixed parameters are compatible with at least fzf 0.16.11 (Aug 1, 2017) */
-		char prev_opts[18 + 32];
+		char prev_opts[18 + MAX_INT_STR];
 		*prev_opts = '\0';
 		const char prev_str[] = "--preview \"clifm --preview {}\"";
 
 		if (prev > 0) { /* Either internal of external previewer */
 			set_fzf_env_vars((int)height);
-			size_t s = get_preview_win_width(offset);
+			const size_t s = get_preview_win_width(offset);
 			if (s != (size_t)-1)
 				snprintf(prev_opts, sizeof(prev_opts), "--preview-window=%zu", s);
 		}
@@ -867,14 +878,16 @@ ctrl-d:deselect-all,ctrl-t:toggle-all" : "",
 		/* Skim is a nice alternative, but it currently (0.10.4) fails
 		 * clearing the screen when --height is set, which makes it unusable
 		 * for us. The issue has been reported, but there was no response.
-		 * See https://github.com/lotabout/skim/issues/494 */
+		 * See https://github.com/lotabout/skim/issues/494
+		 * As a workaround, run with --no-clear-start */
 /*		snprintf(cmd, sizeof(cmd), "sk %s " // skim
-			"%s --margin=0,0,0,%d --color=16 "
-			"--read0 --ansi --inline-info "
-			"--layout=reverse-list --query=\"%s\" %s %s %s %s %s "
+			"%s %s --margin=0,0,0,%d "
+			"--read0 --ansi "
+			"--query=\"%s\" %s %s %s %s %s "
 			"< %s > %s",
 			conf.fzftab_options,
-			*height_str ? height_str : "", *offset,
+			*height_str ? height_str : "",
+			*height_str ? "--no-clear-start" : "", offset,
 			lw ? lw : "", conf.colorize == 0 ? "--no-color" : "",
 			multi == 1 ? "--multi --bind tab:toggle+down,ctrl-s:select-all,\
 ctrl-d:deselect-all,ctrl-t:toggle-all" : "",
@@ -885,10 +898,10 @@ ctrl-d:deselect-all,ctrl-t:toggle-all" : "",
 			finder_in_file, finder_out_file); */
 	}
 
-	int dr = (flags & DELAYED_REFRESH) ? 1 : 0;
+	const int dr = (flags & DELAYED_REFRESH) ? 1 : 0;
 	flags &= ~DELAYED_REFRESH;
-	const mode_t old_mask = umask(0077);
-	int ret = launch_execl(cmd);
+	const mode_t old_mask = umask(0077); /* flawfinder: ignore */
+	const int ret = launch_execl(cmd);
 	umask(old_mask);
 
 	if (restore_cwd == 1)
@@ -899,7 +912,11 @@ ctrl-d:deselect-all,ctrl-t:toggle-all" : "",
 
 	if (prev == 1)
 		clear_fzf();
-	if (dr == 1) flags |= DELAYED_REFRESH;
+	if (dr == 1)
+		flags |= DELAYED_REFRESH;
+	if (ret == 2 && tabmode == FZF_TAB)
+		warn_fzf_error();
+
 	return ret;
 }
 
@@ -936,7 +953,7 @@ get_tagged_file_target(char *filename)
 	snprintf(dir, sizeof(dir), "%s/%s/%s", tags_dir, cur_tag, p ? p : filename);
 	free(p);
 
-	char *rpath = realpath(dir, NULL);
+	char *rpath = xrealpath(dir, NULL);
 	char *s = rpath ? rpath : filename;
 	int free_tmp = 0;
 	char *q = home_tilde(s, &free_tmp);
@@ -1089,7 +1106,7 @@ write_comp_to_file(char *entry, const char *color, FILE *fp)
 }
 
 /* Return a normalized (absolute) path for the query string PREFIX.
- * Ex: "./b<TAB>" -> /parent/dir
+ * E.g., "./b<TAB>" -> /parent/dir
  * The partially typed basename, here 'b', is excluded, since it will be added
  * later using the list of matches passed to store_completions(). */
 static char *
@@ -1181,7 +1198,7 @@ store_completions(char **matches)
 
 		} else if (ct != TCMP_HIST && ct != TCMP_FILE_TYPES_OPTS
 		&& ct != TCMP_MIME_LIST && ct != TCMP_CMD_DESC) {
-			char *cl = get_entry_color(entry, norm_prefix);
+			char *cl = get_comp_entry_color(entry, norm_prefix);
 			*tmp_color = '\0';
 
 			/* If color does not start with escape, then we have a color
@@ -1822,7 +1839,7 @@ finder_tabcomp(char **matches, const char *text, char *original_query)
 	set_finder_paths();
 
 	/* Store possible completions in FINDER_IN_FILE to pass them to the finder. */
-	size_t num_matches = store_completions(matches);
+	const size_t num_matches = store_completions(matches);
 	if (num_matches == (size_t)-1)
 		return FUNC_FAILURE;
 
@@ -1839,7 +1856,7 @@ finder_tabcomp(char **matches, const char *text, char *original_query)
 	size_t height = 0;
 
 	if (fzf_height_set == 0 || tabmode == FNF_TAB) {
-		size_t max_height = set_fzf_max_win_height();
+		const size_t max_height = set_fzf_max_win_height();
 		height = (num_matches + 1 > max_height) ? max_height : num_matches;
 	}
 
@@ -1861,7 +1878,7 @@ finder_tabcomp(char **matches, const char *text, char *original_query)
 	char *deq = q ? (strchr(q, '\\') ? unescape_str(q, 0) : q) : (char *)NULL;
 
 	/* Run the finder application and store the ouput into FINDER_OUT_FILE. */
-	int ret = run_finder(height, finder_offset, deq, multi);
+	const int ret = run_finder(height, finder_offset, deq, multi);
 
 	if (deq && deq != q)
 		free(deq);
@@ -1996,7 +2013,7 @@ tab_complete(const int what_to_do)
 		 * completion, so use the word break characters to find the
 		 * substring on which to complete. */
 			while (--rl_point) {
-				scan = rl_line_buffer[rl_point];
+				scan = (int)rl_line_buffer[rl_point];
 
 				if (strchr(rl_completer_word_break_characters, scan) == 0
 				|| (scan == ' '	&& rl_point
@@ -2010,7 +2027,7 @@ tab_complete(const int what_to_do)
 		}
 
 		/* If we are at an unquoted word break, then advance past it. */
-		scan = rl_line_buffer[rl_point];
+		scan = (int)rl_line_buffer[rl_point];
 		if (strchr(rl_completer_word_break_characters, scan)) {
 		/* If the character that caused the word break was a quoting
 		 * character, then remember it as the delimiter. */
@@ -2089,7 +2106,7 @@ AFTER_USUAL_COMPLETION:
 		for (i = 0; matches[i + 1]; i++) {
 			if (strcmp(matches[i], matches[i + 1]) == 0) {
 				free(matches[i]);
-				matches[i] = (char *)&dead_slot;
+				matches[i] = &dead_slot;
 			} else {
 				newlen++;
 			}
@@ -2099,14 +2116,14 @@ AFTER_USUAL_COMPLETION:
 		 * Copy all the non-dead entries into a new array. */
 		temp_array = xnmalloc(3 + newlen, sizeof (char *));
 		for (i = j = 1; matches[i]; i++) {
-			if (matches[i] != (char *)&dead_slot) {
+			if (matches[i] != &dead_slot) {
 				temp_array[j] = matches[i];
 				j++;
 			}
 		}
 		temp_array[j] = (char *)NULL;
 
-		if (matches[0] != (char *)&dead_slot)
+		if (matches[0] != &dead_slot)
 			free(matches[0]);
 		free(matches);
 
@@ -2252,7 +2269,7 @@ AFTER_USUAL_COMPLETION:
 						}
 						continue;
 					}
-					t[0] = (char)replacement[k];
+					t[0] = replacement[k];
 					t[1] = '\0';
 					rl_insert_text(t);
 
@@ -2503,7 +2520,7 @@ DISPLAY_MATCHES:
 				goto CALC_OFFSET;
 
 			char *dd = (char *)NULL;
-			// MATCHES[0] SHOULD BE DIR!!
+			/* MATCHES[0] SHOULD BE DIR!! */
 			if (strstr(matches[0], "/..")) {
 				dd = normalize_path(matches[0], strlen(matches[0]));
 				if (dd) {
@@ -2548,12 +2565,12 @@ CALC_OFFSET:
 			goto RESET_PATH;
 		}
 #else
-		if (1) {} /* This just silences a warning */
+		if (1) {} /* This just silences a warning. */
 #endif /* !_NO_FZF */
 
-		/* Standard TAB completion */
+		/* Standard TAB completion. */
 		char *ptr = matches[0];
-		/* Skip leading backslashes */
+		/* Skip leading backslashes. */
 		while (*ptr) {
 			if (*ptr != '\\')
 				break;
@@ -2615,8 +2632,8 @@ CALC_OFFSET:
 		for (i = 1; i <= (size_t)count; i++) {
 			if (i >= term_lines) {
 				/* A little pager */
-				fputs("\x1b[7;97m--Mas--\x1b[0;49m", stdout);
-				int c = 0;
+				fputs("\x1b[7m--Mas--\x1b[0m", stdout);
+				char c = 0;
 				while ((c = xgetchar()) == KEY_ESC);
 				if (c == 'q') {
 					/* Delete the --Mas-- label */
@@ -2695,7 +2712,7 @@ RESTART:
 					continue;
 				}
 
-				t[0] = (char)ss[k];
+				t[0] = ss[k];
 				t[1] = '\0';
 				rl_insert_text(t);
 				rl_redisplay();
