@@ -288,6 +288,7 @@ const struct terms_t TERM_INFO[] = {
 	{"cons60r", 7, 8, 1, 1, 1, 0, 0, 1, 0},
 	{"cons60r-m", 9, -1, 1, 1, 1, 0, 0, 1, 0},
 	{"contour", 7, 256, 1, 1, 1, 1, 1, 1, 0},
+	{"contour-direct", 14, 16777216, 1, 1, 1, 1, 1, 1, 0},
 	{"contour-latest", 14, 256, 1, 1, 1, 1, 1, 1, 0},
 	{"crt", 3, 8, 1, 1, 1, 0, 0, 1, 1},
 	{"crt-vt220", 9, 8, 1, 1, 1, 0, 0, 1, 1},
@@ -575,9 +576,9 @@ const struct terms_t TERM_INFO[] = {
 	{"jaixterm", 8, 8, 1, 1, 1, 0, 0, 1, 0},
 	{"jaixterm-m", 10, -1, 1, 1, 1, 0, 0, 1, 0},
 	{"jfbterm", 7, 8, 1, 1, 1, 1, 0, 1, 1},
-	{"kitty", 5, 256, 1, 1, 1, 1, 0, 1, 1},
-	{"kitty+common", 12, -1, 1, 1, 1, 1, 0, 1, 1},
-	{"kitty-direct", 12, 16777216, 1, 1, 1, 1, 0, 1, 1},
+	{"kitty", 5, 256, 1, 1, 1, 1, 1, 1, 1},
+	{"kitty+common", 12, -1, 1, 1, 1, 1, 1, 1, 1},
+	{"kitty-direct", 12, 16777216, 1, 1, 1, 1, 1, 1, 1},
 	{"klone+color", 11, 8, 0, 0, 0, 0, 0, 0, 0},
 	{"kon", 3, 8, 1, 1, 1, 1, 0, 1, 1},
 	{"kon2", 4, 8, 1, 1, 1, 1, 0, 1, 1},
@@ -655,11 +656,13 @@ const struct terms_t TERM_INFO[] = {
 	{"morphos", 7, -1, 1, 1, 1, 1, 0, 1, 0},
 	{"mosh", 4, 8, 1, 1, 1, 1, 0, 1, 1},
 	{"mosh-256color", 13, 256, 1, 1, 1, 1, 0, 1, 1},
+	{"mostlike", 8, -1, 1, 1, 1, 0, 0, 1, 1},
 	{"mrxvt", 5, 8, 1, 1, 1, 1, 0, 1, 1},
 	{"mrxvt-256color", 14, 256, 1, 1, 1, 1, 0, 1, 1},
 	{"ms-terminal", 11, 256, 1, 1, 1, 1, 1, 1, 1},
 	{"ms-vt100", 8, -1, 1, 1, 1, 0, 0, 1, 1},
 	{"ms-vt100+", 9, 8, 1, 1, 1, 0, 0, 1, 1},
+	{"ms-vt100-16color", 16, 16, 1, 1, 1, 1, 0, 1, 1},
 	{"ms-vt100-color", 14, 8, 1, 1, 1, 0, 0, 1, 1},
 	{"ms-vt-utf8", 10, 8, 1, 1, 1, 0, 0, 1, 1},
 	{"mt4520-rv", 9, -1, 1, 1, 1, 0, 0, 1, 0},
@@ -895,6 +898,7 @@ const struct terms_t TERM_INFO[] = {
 	{"rcons-color", 11, 8, 0, 1, 1, 0, 0, 0, 0},
 	{"rio", 3, 256, 1, 1, 1, 1, 1, 1, 1},
 	{"rio+base", 8, 8, 1, 1, 1, 1, 1, 1, 1},
+	{"rio-direct", 10, 16777216, 1, 1, 1, 1, 1, 1, 1},
 	{"rt6221", 6, -1, 1, 1, 1, 1, 0, 1, 0},
 	{"rt6221-w", 8, -1, 1, 1, 1, 1, 0, 1, 0},
 	{"rxvt", 4, 8, 1, 1, 1, 1, 0, 1, 1},
@@ -961,8 +965,8 @@ const struct terms_t TERM_INFO[] = {
 	{"screen.rxvt", 11, 8, 1, 1, 1, 1, 0, 1, 1},
 	{"screen-s", 8, 8, 1, 1, 1, 1, 0, 1, 1},
 	{"screen.teraterm", 15, 8, 1, 1, 1, 1, 0, 1, 1},
-	{"screen.vte", 10, 8, 1, 1, 1, 1, 0, 1, 1},
-	{"screen.vte-256color", 19, 256, 1, 1, 1, 1, 0, 1, 1},
+	{"screen.vte", 10, 8, 1, 1, 1, 1, 1, 1, 1},
+	{"screen.vte-256color", 19, 256, 1, 1, 1, 1, 1, 1, 1},
 	{"screen-w", 8, 8, 1, 1, 1, 1, 0, 1, 1},
 	{"screen.xterm-256color", 21, 256, 1, 1, 1, 1, 0, 1, 1},
 	{"screen.xterm-new", 16, 8, 1, 1, 1, 1, 0, 1, 1},
@@ -1128,20 +1132,21 @@ const struct terms_t TERM_INFO[] = {
 	{"vt520", 5, -1, 1, 1, 1, 1, 0, 1, 1},
 	{"vt520ansi", 9, -1, 1, 1, 1, 1, 0, 1, 1},
 	{"vt525", 5, -1, 1, 1, 1, 1, 0, 1, 1},
-	{"vte", 3, 8, 1, 1, 1, 1, 0, 1, 1},
+	{"vte", 3, 8, 1, 1, 1, 1, 1, 1, 1},
 	{"vte-2007", 8, 8, 1, 1, 1, 1, 0, 1, 1},
 	{"vte-2008", 8, 8, 1, 1, 1, 1, 0, 1, 1},
 	{"vte-2012", 8, 8, 1, 1, 1, 1, 0, 1, 1},
 	{"vte-2014", 8, 8, 1, 1, 1, 1, 0, 1, 1},
-	{"vte-2017", 8, 8, 1, 1, 1, 1, 0, 1, 1},
-	{"vte-2018", 8, 8, 1, 1, 1, 1, 0, 1, 1},
-	{"vte-256color", 12, 256, 1, 1, 1, 1, 0, 1, 1},
-	{"vte-direct", 10, 16777216, 1, 1, 1, 1, 0, 1, 1},
+	{"vte-2017", 8, 8, 1, 1, 1, 1, 1, 1, 1},
+	{"vte-2018", 8, 8, 1, 1, 1, 1, 1, 1, 1},
+	{"vte-256color", 12, 256, 1, 1, 1, 1, 1, 1, 1},
+	{"vte-direct", 10, 16777216, 1, 1, 1, 1, 1, 1, 1},
 	{"vtnt", 4, 8, 1, 1, 1, 0, 0, 1, 1},
 	{"vt-utf8", 7, 8, 1, 1, 1, 0, 0, 1, 1},
 	{"vv100", 5, 8, 1, 1, 1, 0, 0, 1, 0},
 	{"vwmterm", 7, 8, 1, 1, 1, 1, 0, 1, 0},
-	{"wezterm", 7, 256, 1, 1, 1, 1, 0, 1, 1},
+	{"wezterm", 7, 256, 1, 1, 1, 1, 1, 1, 1},
+	{"winconsole", 10, 8, 1, 1, 1, 1, 0, 1, 0},
 	{"wren", 4, -1, 1, 1, 1, 0, 0, 1, 0},
 	{"wrenw", 5, -1, 1, 1, 1, 0, 0, 1, 0},
 	{"wsvt25", 6, 8, 1, 1, 1, 1, 0, 1, 1},
@@ -1316,7 +1321,7 @@ const struct terms_t TERM_INFO[] = {
 	{"xterm-hp", 8, 8, 1, 1, 1, 1, 1, 1, 1},
 	{"xterm+indirect", 14, 16777216, 0, 0, 0, 0, 0, 0, 0},
 	{"xterm.js", 8, 256, 1, 1, 1, 1, 1, 1, 1},
-	{"xterm-kitty", 11, 256, 1, 1, 1, 1, 0, 1, 1},
+	{"xterm-kitty", 11, 256, 1, 1, 1, 1, 1, 1, 1},
 	{"xtermm", 6, -1, 1, 1, 1, 0, 0, 1, 1},
 	{"xterm-mono", 10, -1, 1, 1, 1, 0, 0, 1, 1},
 	{"xterm-new", 9, 8, 1, 1, 1, 1, 1, 1, 1},
