@@ -32,6 +32,10 @@
 #include <unistd.h> /* access, unlinkat */
 /* <time.h>, required by time(2) and localtime_r(2), is included by "aux.h" */
 
+#if defined(MAC_OS_X_RENAMEAT_SYS_STDIO_H)
+# include <sys/stdio.h> /* renameat(2) */
+#endif /* MAC_OS_X_RENAMEAT_SYS_STDIO_H */
+
 #include "aux.h"        /* gen_date_suffix, count_dir, open_fwrite, open_fread,
 xatoi, url_encode, xnmalloc */
 #include "checks.h"     /* is_file_in_cwd, is_number */
@@ -419,7 +423,7 @@ static char **
 list_and_get_input(struct dirent ***trash_files, const int files_n,
 	const int is_undel)
 {
-	if (conf.clear_screen == 1)
+	if (conf.clear_screen > 0)
 		CLEAR;
 
 	const int ret = print_trashfiles(trash_files, files_n);
@@ -428,7 +432,7 @@ list_and_get_input(struct dirent ***trash_files, const int files_n,
 
 	/* Get input */
 	printf(_("\n%sEnter 'q' to quit\n"
-		"File(s) to be %s (ex: 1 2-6, or *):\n"), df_c,
+		"File(s) to be %s (e.g.: 1 2-6, or *):\n"), df_c,
 		is_undel == 1 ? _("restored") : _("removed"));
 
 	char *line = (char *)NULL;
@@ -495,8 +499,8 @@ load_trashed_files(int *n, int *status)
 
 	struct dirent **tfiles = (struct dirent **)NULL;
 	*n = scandir(trash_files_dir, &tfiles,
-		skip_files, conf.unicode == 1 ? alphasort
-		: (conf.case_sens_list == 1 ? xalphasort : alphasort_insensitive));
+		skip_files, conf.case_sens_list == 1 ? xalphasort
+		: alphasort_insensitive);
 
 	if (*n <= -1) {
 		*status = errno;
@@ -910,7 +914,7 @@ untrash_function(char **args)
 	/* If some trashed file still remains, reload the undel screen */
 	const size_t n = count_trashed_files();
 	if (n > 0) {
-		if (conf.clear_screen == 1) CLEAR;
+		if (conf.clear_screen > 0) CLEAR;
 		untrash_function(args);
 	} else {
 		if (conf.autols == 1) reload_dirlist();
@@ -958,8 +962,8 @@ list_trashed_files(void)
 
 	struct dirent **trash_files = (struct dirent **)NULL;
 	const int files_n = scandir(trash_files_dir, &trash_files,
-			skip_files, conf.unicode ? alphasort : (conf.case_sens_list
-			? xalphasort : alphasort_insensitive));
+		skip_files, conf.case_sens_list == 1
+		? xalphasort : alphasort_insensitive);
 
 	if (files_n == -1) {
 		xerror("trash: %s\n", strerror(errno));
@@ -970,7 +974,7 @@ list_trashed_files(void)
 		return FUNC_SUCCESS;
 	}
 
-	if (conf.clear_screen == 1)
+	if (conf.clear_screen > 0)
 		CLEAR;
 
 	HIDE_CURSOR;
